/*
 * SG host definition header file
 *
 * Copyright (C) 2013 Rohde & Schwarz
 * written by Stefani Seibold <stefani@seibold.net>
 */

#ifndef __HOST_H
#define __HOST_H

#include <linux/kernel.h>
#include <linux/interrupt.h>
#include <linux/wait.h>
#include <linux/pci.h>
#include <linux/version.h>
#include <linux/sched.h>

#include "sgpcie.h"
#include "rfifo.h"

#define DEVICE_NAME	"sgs"

#define	LO32(x)	(((unsigned long)(x)) & 0xffffffff)
#ifdef CONFIG_64BIT
#define	HI32(x)	((((unsigned long)(x)) >> 32) & 0xffffffff)
#else
#define	HI32(x)	(0)
#endif

#define	PRINTK(level, fmt, args...)	printk(level DEVICE_NAME ": " fmt "\n" ,##args)
#define	PRINTK_ERR(fmt, args...)	PRINTK(KERN_ERR, fmt ,##args)
#define	PRINTK_INFO(fmt, args...)	PRINTK(KERN_INFO, fmt ,##args)
#define	PRINTK_DEBUG(fmt, args...)	if (debug) PRINTK(KERN_DEBUG, "%s:%d " fmt, __FUNCTION__, __LINE__,##args)

#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,18)
typedef unsigned long resource_size_t;
#endif

#ifndef IRQF_NO_THREAD
#define IRQF_NO_THREAD 0
#endif

union iomem_t {
	struct sgpcie_iomem		new;
	struct sgpcie_iomem_old	old;
};

struct devdata {
	struct pci_dev		*dev;
	struct sg_dev		*sg_dev;
	union iomem_t __iomem	*iomem;
	void __iomem		*pciexp;
	u32			*fpgamsg;
	u32			ib_phys_addr;
	u32			read_irqs;
	u32			write_irqs;
	u32			reg_bits;
	resource_size_t		iobar;
	resource_size_t		pciexbar;
	resource_size_t		fpgabar;
	wait_queue_head_t	read_wq;
	wait_queue_head_t	write_wq;
	wait_queue_head_t	io_wq;
	struct mutex		read_mutex;
	struct mutex		write_mutex;
	spinlock_t		lock;
	struct kref		kref;
	unsigned int		minor;
	struct rfifo		*host2dev;
	__le32			*host_read_wait;
	__le32			*host_write_wait;
	struct rfifo		*dev2host;
	__le32			*dev_read_wait;
	__le32			*dev_write_wait;
	int			linked;
    struct cdev             *sgsCdev;
};

struct sg_dev {
	void (*setup)(struct devdata *devdata);
	void (*reset)(struct devdata *devdata);
	void (*link)(struct devdata *devdata, struct devdata *linkdev);
	void (*unlink)(struct devdata *devdata);
	void (*gen_inbound_mbox_irq)(struct devdata * devdata);
#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,19)
	irqreturn_t (*isr)(int irq, void *dev_id, struct pt_regs *regs);
#else
	irqreturn_t (*isr)(int irq, void *dev_id);
#endif
};

extern int debug;

#endif


