/*******************************************************************************
CallLogger.h

Logging functions for instrument drivers
Wilhelm Kurz, 2020

copyright    (c) Rohde & Schwarz GmbH & Co. KG, Munich
******************************************************************************/

#pragma once

#include "visa.h"

typedef ViStatus(*DecodeErrorCallback_f)(
  ViStatus statusCode,
  ViChar _VI_FAR errName[],
  ViChar _VI_FAR errMessage[]);

ViBoolean LogLoggingEnabled(void);
void LogSetDecodeErrorCallback(DecodeErrorCallback_f f);

void LogOpenLog(const char* type, ViInt32 historydepth, ViBoolean enablewrap, ViBoolean stoponerror);

void LogAddCall(const char* szDescription);
void LogCloseCall(ViStatus status);

void LogCloseLog(void);
void LogDiscardLog(void);
ViStatus LogSaveLog(const ViString filename);
void LogSetMaxCallDepth(ViUInt32 depth);
void LogSetWrapStartIndex(ViUInt32 wrapstartindex);


// Bool
void LogAddBoolArg2(const char* szName, ViBoolean value);
#define LogAddBoolArg(szName) LogAddBoolArg2(#szName, szName)

void LogAddBoolOut2(const char* szName, ViBoolean* pValue);
#define LogAddBoolOut(szName) LogAddBoolOut2(#szName, szName)

// Session
void LogAddSessionArg2(const char* szName, ViSession session);
#define LogAddSessionArg(szName) LogAddSessionArg2(#szName, szName)

void LogAddSessionOut2(const char* szName, ViSession* pSession);
#define LogAddSessionOut(szName) LogAddSessionOut2(#szName, szName)

// String
void LogAddStringArg2(const char* szName, const ViChar* value);
#define LogAddStringArg(szName) LogAddStringArg2(#szName, szName)

void LogAddStringOut2(const char* szName, ViChar* pValue);
#define LogAddStringOut(szName) LogAddStringOut2(#szName, szName)

// Int32
void LogAddInt32Arg2(const char* szName, ViInt32 value);
#define LogAddInt32Arg(szName) LogAddInt32Arg2(#szName, szName)
 
void LogAddInt32Out2(const char* szName, ViInt32* pValue);
#define LogAddInt32Out(szName) LogAddInt32Out2(#szName, szName)


// UInt32
void LogAddUInt32Arg2(const char* szName, ViUInt32 value);
#define LogAddUInt32Arg(szName) LogAddUInt32Arg2(#szName, szName)

void LogAddUInt32Out2(const char* szName, ViUInt32* pValue);
#define LogAddUInt32Out(szName) LogAddUInt32Out2(#szName, szName)


// Int64
void LogAddInt64Arg2(const char* szName, ViInt64 value);
#define LogAddInt64Arg(szName) LogAddInt64Arg2(#szName, szName)

void LogAddInt64Out2(const char* szName, ViInt64* pValue);
#define LogAddInt64Out(szName) LogAddInt64Out2(#szName, szName)

// Select
void LogAddSelectArg2(const char* szName, ViInt32 value, const char* selectlist);
#define LogAddSelectArg(szName, selectlist) LogAddSelectArg2(#szName, szName, #selectlist)

// AttrState
void LogAddAttrStateArg2(const char* szName, ViUInt32 value);
#define LogAddAttrStateArg(szName) LogAddAttrStateArg2(#szName, (ViUInt32)szName)

void LogAddAttrStateOut2(const char* szName, ViUInt32* pValue, ViAttr attr);
#define LogAddAttrStateOut(szName, attr) LogAddAttrStateOut2(#szName, szName, attr)

// Real64
void LogAddReal64Arg2(const char* szName, ViReal64 value);
#define LogAddReal64Arg(szName) LogAddReal64Arg2(#szName, szName)

void LogAddReal64Out2(const char* szName, ViReal64* pValue);
#define LogAddReal64Out(szName) LogAddReal64Out2(#szName, szName)

// Real64Arr
void LogAddReal64ArrArg2(const char* szName, ViReal64* value, ViInt32* count);
#define LogAddReal64ArrArg(szName, count) LogAddReal64ArrArg2(#szName, szName, count)

void LogAddReal64ArrOut2(const char* szName, ViReal64* value, ViInt32* count);
#define LogAddReal64ArrOut(szName, count) LogAddReal64ArrOut2(#szName, szName, count)

// Int32Arr
void LogAddInt32ArrArg2(const char* szName, ViInt32* value, ViInt32* count);
#define LogAddInt32ArrArg(szName, count) LogAddInt32ArrArg2(#szName, szName, count)

void LogAddInt32ArrOut2(const char* szName, ViInt32* value, ViInt32* count);
#define LogAddInt32ArrOut(szName, count) LogAddInt32ArrOut2(#szName, szName, count)

// CharArr
void LogAddCharArrArg2(const char* szName, ViChar* value, ViInt32* count);
#define LogAddCharArrArg(szName, count) LogAddCharArrArg2(#szName, szName, count)

void LogAddCharArrOut2(const char* szName, ViChar* value, ViInt32* count);
#define LogAddCharArrOut(szName, count) LogAddCharArrOut2(#szName, szName, count)

// StringArr
void LogAddStringArrArg2(const char* szName, ViString* value, ViInt32* count);
#define LogAddStringArrArg(szName, count) LogAddStringArrArg2(#szName, szName, count)

void LogAddStringArrOut2(const char* szName, ViString* value, ViInt32* count);
#define LogAddStringArrOut(szName, count) LogAddStringArrOut2(#szName, szName, count)


