/*****************************************************************************
 *  Rohde&Schwarz SGT Signal Generator instrument driver
 *  
 *  VXIpnp Instrument Driver
 *****************************************************************************/

#ifndef __RSSGT_HEADER
#define __RSSGT_HEADER

#include "rssgt_core.h"
#include "rssgt_attributes.h"
#include "rssgt_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#include "visaabstraction.h"

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif
	
/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/

#define RSSGT_SIMULATION_ID_QUERY      "Rohde&Schwarz,SGT,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define RSSGT_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSSGT_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSSGT_IO_BUFFER_SIZE           1024U   /* I/O buffer size */
#define RSSGT_OPC_TIMEOUT              5000L   /* Maximum time to wait for OPC in milliseconds */
#define IEEE_488_2_ERROR_MASK             0x4    /* 488.2 STB Bits */   
#define IEEE_488_2_ESE_MASK               0x3D    /* 488.2 Event Status Register (ESE) Bits */
#define MAX_OPC_TIME                   60000L
	
/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define RSSGT_CLASS_DRIVER_DESCRIPTION           ""
#define RSSGT_CLASS_DRIVER_PREFIX                ""
#define RSSGT_CLASS_DRIVER_VENDOR                ""
#define RSSGT_CLASS_DRIVER_REVISION              ""
#define RSSGT_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSSGT_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSSGT_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSSGT_SPECIFIC_DRIVER_PREFIX             "RSSGT"
#define RSSGT_SPECIFIC_DRIVER_LOCATOR            ""
#define RSSGT_SPECIFIC_DRIVER_VENDOR             ""
#define RSSGT_MAJOR_VERSION                      1L    /* Instrument driver major version          */
#define RSSGT_MINOR_VERSION                      6L    /* Instrument driver minor version          */
#define RSSGT_MINOR_MINOR_VERSION                5L    /* Instrument driver minor minor version    */

/* Driver Capabilities */          

#define RSSGT_SUPPORTED_INSTRUMENT_MODELS        ""    /* Instrument driver supported model(s)     */
#define RSSGT_GROUP_CAPABILITIES                 ""
#define RSSGT_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSSGT_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSSGT_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSSGT_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSSGT_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSSGT_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSSGT_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSSGT_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSSGT_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */
#define RSSGT_ATTR_PRIMARY_ERROR                                         RS_ATTR_PRIMARY_ERROR
#define RSSGT_ATTR_SECONDARY_ERROR                                       RS_ATTR_SECONDARY_ERROR
#define RSSGT_ATTR_IO_SESSION                                            RS_ATTR_IO_SESSION
#define RSSGT_ATTR_IO_SESSION_TYPE                                       RS_ATTR_IO_SESSION_TYPE


        /* Class Driver Identification */

#define RSSGT_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSSGT_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSSGT_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSSGT_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSSGT_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSSGT_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSSGT_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSSGT_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSSGT_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSSGT_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSSGT_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSSGT_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSSGT_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

#define RSSGT_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION                         RS_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION
#define RSSGT_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION                         RS_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION
#define RSSGT_ATTR_SPECIFIC_DRIVER_MINOR_VERSION                         RS_ATTR_SPECIFIC_DRIVER_MINOR_VERSION
#define RSSGT_ATTR_SPECIFIC_DRIVER_MINOR_MINOR_VERSION                   RS_ATTR_SPECIFIC_DRIVER_MINOR_MINOR_VERSION
#define RSSGT_ATTR_CLASS_DRIVER_MAJOR_VERSION                            RS_ATTR_CLASS_DRIVER_MAJOR_VERSION
#define RSSGT_ATTR_CLASS_DRIVER_MINOR_VERSION                            RS_ATTR_CLASS_DRIVER_MINOR_VERSION
#define RSSGT_ATTR_ENGINE_MAJOR_VERSION                                  RS_ATTR_ENGINE_MAJOR_VERSION
#define RSSGT_ATTR_ENGINE_MINOR_VERSION                                  RS_ATTR_ENGINE_MINOR_VERSION
#define RSSGT_ATTR_ENGINE_REVISION                                       RS_ATTR_ENGINE_REVISION


        /* Driver Capabilities */

#define RSSGT_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSSGT_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSSGT_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSSGT_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSSGT_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSSGT_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSSGT_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSSGT_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */
#define RSSGT_ATTR_OPTIONS_LIST                                          RS_ATTR_OPTIONS_LIST

        /* Advanced Session Information */

#define RSSGT_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSSGT_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */
#define RSSGT_ATTR_OPC_TIMEOUT                                           RS_ATTR_OPC_TIMEOUT                                    

    /*- Instrument-Specific Attributes -------------------------------------*/

/* BEGIN GENERATE */
#define RSSGT_ATTR_REFERENCE_OSCILLATOR_SOURCE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352097
#define RSSGT_ATTR_REFERENCE_OSCILLATOR_EXTERNAL_FREQUENCY                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352098
#define RSSGT_ATTR_REFERENCE_OSCILLATOR_OUTPUT_FREQUENCY                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352099
#define RSSGT_ATTR_REFERENCE_OSCILLATOR_SYNCHRONIZATION_BANDWIDTH           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352313
#define RSSGT_ATTR_REFERENCE_OSCILLATOR_ADJUSTMENT_ACTIVE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352314
#define RSSGT_ATTR_REFERENCE_OSCILLATOR_ADJUSTMENT_SMALL_SHIFT              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352315
#define RSSGT_ATTR_REFERENCE_OSCILLATOR_ADJUSTMENT_CALIBRATION_VALUE        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352435
#define RSSGT_ATTR_BB_SYSTEM_CONFIGURATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352570
#define RSSGT_ATTR_BB_FREQUENCY_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352100
#define RSSGT_ATTR_BB_PATH_GAIN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352101
#define RSSGT_ATTR_BB_PHASE_OFFSET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352102
#define RSSGT_ATTR_BB_PULSE_SEQUENCER_INFO                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352571
#define RSSGT_ATTR_PATH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352594
#define RSSGT_ATTR_ARB_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352103
#define RSSGT_ATTR_ARB_SET_TO_DEFAULT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352104
#define RSSGT_ATTR_ARB_CLOCK_FREQUENCY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352105
#define RSSGT_ATTR_ARB_WAVEFORM_CATALOG                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352106
#define RSSGT_ATTR_ARB_WAVEFORM_CATALOG_LENGTH                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352107
#define RSSGT_ATTR_ARB_WAVEFORM_DELETE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352110
#define RSSGT_ATTR_ARB_WAVEFORM_POINTS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352112
#define RSSGT_ATTR_ARB_WAVEFORM_SELECT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352113
#define RSSGT_ATTR_ARB_TRIGGER_STATUS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352115
#define RSSGT_ATTR_ARB_TRIGGER_ARM_EXECUTE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352436
#define RSSGT_ATTR_ARB_EXECUTE_TRIGGER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352116
#define RSSGT_ATTR_ARB_TRIGGER_DELAY_UNIT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352117
#define RSSGT_ATTR_ARB_TRIGGER_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352118
#define RSSGT_ATTR_ARB_EXTENDED_TRIGGER_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352119
#define RSSGT_ATTR_ARB_TRIGGER_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352120
#define RSSGT_ATTR_ARB_TRIGGER_SINGLE_SEQUENCE_LENGTH                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352121
#define RSSGT_ATTR_ARB_TRIGGER_SINGLE_SIGNAL_DURATION_UNIT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352122
#define RSSGT_ATTR_ARB_EXTERNAL_SYNCHRONIZE_OUTPUT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352123
#define RSSGT_ATTR_ARB_EXTERNAL_TRIGGER_DELAY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352126
#define RSSGT_ATTR_ARB_EXTERNAL_TRIGGER_INHIBIT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352127
#define RSSGT_ATTR_ARB_EXTERNAL_TRIGGER_TIME_DELAY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352128
#define RSSGT_ATTR_ARB_EXTERNAL_TRIGGER_TIME_EVENT_DELAY                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352129
#define RSSGT_ATTR_ARB_MARKER_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352130
#define RSSGT_ATTR_ARB_MARKER_PULSE_DIVIDER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352131
#define RSSGT_ATTR_ARB_MARKER_PULSE_FREQUENCY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352132
#define RSSGT_ATTR_ARB_MARKER_PATTERN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352133
#define RSSGT_ATTR_ARB_MARKER_ON_TIME                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352134
#define RSSGT_ATTR_ARB_MARKER_OFF_TIME                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352135
#define RSSGT_ATTR_ARB_MARKER_DELAY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352136
#define RSSGT_ATTR_ARB_FIXED_MARKER_DELAY_MAXIMUM                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352138
#define RSSGT_ATTR_ARB_FIXED_MARKER_DELAY_MINIMUM                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352139
#define RSSGT_ATTR_ARB_CLOCK_SOURCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352140
#define RSSGT_ATTR_ARB_CLOCK_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352141
#define RSSGT_ATTR_ARB_CHIP_CLOCK_MULTIPLIER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352142
#define RSSGT_ATTR_ARB_CLOCK_SYNCHRONISATION_MODE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352143
#define RSSGT_ATTR_ARB_TSIGNAL_SINE_NAME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352144
#define RSSGT_ATTR_ARB_TSIGNAL_SINE_CREATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352146
#define RSSGT_ATTR_ARB_TSIGNAL_SINE_FREQUENCY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352147
#define RSSGT_ATTR_ARB_TSIGNAL_SINE_PHASE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352148
#define RSSGT_ATTR_ARB_TSIGNAL_SINE_SAMPLES                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352149
#define RSSGT_ATTR_ARB_TSIGNAL_RECTANGLE_NAME                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352150
#define RSSGT_ATTR_ARB_TSIGNAL_RECTANGLE_CREATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352152
#define RSSGT_ATTR_ARB_TSIGNAL_RECTANGLE_FREQUENCY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352153
#define RSSGT_ATTR_ARB_TSIGNAL_RECTANGLE_AMPLITUDE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352154
#define RSSGT_ATTR_ARB_TSIGNAL_RECTANGLE_OFFSET_DC                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352155
#define RSSGT_ATTR_ARB_TSIGNAL_RECTANGLE_SAMPLES                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352156
#define RSSGT_ATTR_ARB_TSIGNAL_CIQ_NAME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352157
#define RSSGT_ATTR_ARB_TSIGNAL_CIQ_CREATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352158
#define RSSGT_ATTR_ARB_TSIGNAL_CIQ_I                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352159
#define RSSGT_ATTR_ARB_TSIGNAL_CIQ_Q                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352160
#define RSSGT_ATTR_ARB_MULTISEGMENT_STREAMING_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352161
#define RSSGT_ATTR_ARB_MULTISEGMENT_FREE_DISK_SPACE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352162
#define RSSGT_ATTR_ARB_MULTISEGMENT_FILLING_LEVEL_STREAMING_BUFFER          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352163
#define RSSGT_ATTR_ARB_MULTISEGMENT_OUTPUT_SEGMENT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352164
#define RSSGT_ATTR_ARB_MULTISEGMENT_CURRENT_OUTPUT_SEGMENT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352165
#define RSSGT_ATTR_ARB_MULTISEGMENT_LEVEL_MODE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352166
#define RSSGT_ATTR_ARB_MULTISEGMENT_MARKER_MODE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352167
#define RSSGT_ATTR_ARB_MULTISEGMENT_SEQUENCE_RESTART                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352168
#define RSSGT_ATTR_ARB_MULTISEGMENT_SEGMENT_RESTART                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352169
#define RSSGT_ATTR_ARB_MULTISEGMENT_SAVE_FILE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352170
#define RSSGT_ATTR_ARB_MULTISEGMENT_APPEND_FILE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352172
#define RSSGT_ATTR_ARB_MULTISEGMENT_NAME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352174
#define RSSGT_ATTR_ARB_MULTISEGMENT_LEVEL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352573
#define RSSGT_ATTR_ARB_MULTISEGMENT_EXECUTE_NEXT_SEGMENT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352175
#define RSSGT_ATTR_ARB_MULTISEGMENT_NEXT_SEGMENT_SOURCE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352176
#define RSSGT_ATTR_ARB_MULTISEGMENT_SEQUENCING_LIST                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352177
#define RSSGT_ATTR_ARB_MULTISEGMENT_CONFIGURATION_FILE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352179
#define RSSGT_ATTR_ARB_MULTISEGMENT_CREATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352180
#define RSSGT_ATTR_ARB_MULTISEGMENT_LOAD_FROM_CONFIGURATION_FILE            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352181
#define RSSGT_ATTR_ARB_MULTISEGMENT_CATALOG                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352182
#define RSSGT_ATTR_ARB_MULTISEGMENT_SEGMENT_CATALOG                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352183
#define RSSGT_ATTR_ARB_MULTISEGMENT_DELETE_CONFIGURATION_FILE               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352184
#define RSSGT_ATTR_ARB_MULTISEGMENT_COMMENT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352185
#define RSSGT_ATTR_ARB_MULTISEGMENT_CLOCK                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352186
#define RSSGT_ATTR_ARB_MULTISEGMENT_CLOCK_MODE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352187
#define RSSGT_ATTR_ARB_MULTI_CARRIER_CREATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352188
#define RSSGT_ATTR_ARB_MULTI_CARRIER_CLOCK                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352437
#define RSSGT_ATTR_ARB_MULTI_CARRIER_RESET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352189
#define RSSGT_ATTR_ARB_MULTI_CARRIER_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352190
#define RSSGT_ATTR_ARB_MULTI_CARRIER_CREST_FACTOR_MODE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352191
#define RSSGT_ATTR_ARB_MULTI_CARRIER_OUTPUT_FILE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352192
#define RSSGT_ATTR_ARB_MULTI_CARRIER_SAVE_FILE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352194
#define RSSGT_ATTR_ARB_MULTI_CARRIER_SAMPLES                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352195
#define RSSGT_ATTR_ARB_MULTI_CARRIER_SIGNAL_PERIOD_MODE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352196
#define RSSGT_ATTR_ARB_MULTI_CARRIER_SIGNAL_PERIOD                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352197
#define RSSGT_ATTR_ARB_MULTI_CARRIER_POWER_REFERENCE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352198
#define RSSGT_ATTR_ARB_MULTI_CARRIER_COUNT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352199
#define RSSGT_ATTR_ARB_MULTI_CARRIER_SPACING                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352200
#define RSSGT_ATTR_ARB_MULTI_CARRIER_FREQUENCY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352201
#define RSSGT_ATTR_ARB_MULTI_CARRIER_DELAY                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352202
#define RSSGT_ATTR_ARB_MULTI_CARRIER_DATA_FILE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352203
#define RSSGT_ATTR_ARB_MULTI_CARRIER_PHASE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352204
#define RSSGT_ATTR_ARB_MULTI_CARRIER_POWER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352205
#define RSSGT_ATTR_ARB_MULTI_CARRIER_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352206
#define RSSGT_ATTR_ARB_MULTI_CARRIER_CONFLICT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352207
#define RSSGT_ATTR_ARB_MULTI_CARRIER_EDIT_EXECUTE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352208
#define RSSGT_ATTR_ARB_MULTI_CARRIER_EDIT_DELAY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352209
#define RSSGT_ATTR_ARB_MULTI_CARRIER_EDIT_DELAY_STEP                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352210
#define RSSGT_ATTR_ARB_MULTI_CARRIER_EDIT_INPUT_IQ_FILE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352211
#define RSSGT_ATTR_ARB_MULTI_CARRIER_EDIT_PHASE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352212
#define RSSGT_ATTR_ARB_MULTI_CARRIER_EDIT_PHASE_STEP                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352213
#define RSSGT_ATTR_ARB_MULTI_CARRIER_EDIT_POWER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352214
#define RSSGT_ATTR_ARB_MULTI_CARRIER_EDIT_POWER_STEP                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352215
#define RSSGT_ATTR_ARB_MULTI_CARRIER_EDIT_START                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352216
#define RSSGT_ATTR_ARB_MULTI_CARRIER_EDIT_STOP                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352217
#define RSSGT_ATTR_ARB_MULTI_CARRIER_EDIT_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352218
#define RSSGT_ATTR_ARB_MULTI_CARRIER_FILE_STORE_FAST                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352219
#define RSSGT_ATTR_ARB_MULTI_CARRIER_FILE_CATALOG                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352220
#define RSSGT_ATTR_ARB_MULTI_CARRIER_FILE_LOAD                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352221
#define RSSGT_ATTR_ARB_MULTI_CARRIER_FILE_STORE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352222
#define RSSGT_ATTR_ARB_MULTI_CARRIER_CLIPPING_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352223
#define RSSGT_ATTR_ARB_MULTI_CARRIER_CLIPPING_TARGET_CREST_FACTOR           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352224
#define RSSGT_ATTR_ARB_MULTI_CARRIER_CLIPPING_FILTER_CUT_OFF_FREQUENCY      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352225
#define RSSGT_ATTR_PROGRESS_MULTI_CODER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352226
#define RSSGT_ATTR_PROGRESS_MULTI_CARRIER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352227
#define RSSGT_ATTR_PROGRESS_MULTI_SEGMENT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352228
#define RSSGT_ATTR_IQ_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352229
#define RSSGT_ATTR_IQ_WIDEBAND_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352230
#define RSSGT_ATTR_IQ_ANALOG_WIDEBAND_CREST_FACTOR                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352232
#define RSSGT_ATTR_IQ_OUTPUT_LEVEL_ENTRY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352438
#define RSSGT_ATTR_IQ_OUTPUT_DIGITAL_OVERFLOW_RESET                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352244
#define RSSGT_ATTR_IQ_OUTPUT_ANALOG_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352491
#define RSSGT_ATTR_IQ_OUTPUT_ANALOG_SET_TO_DEFAULT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352492
#define RSSGT_ATTR_IQ_OUTPUT_ANALOG_TYPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352493
#define RSSGT_ATTR_IQ_OUTPUT_ANALOG_LOAD_SETTINGS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352494
#define RSSGT_ATTR_IQ_OUTPUT_ANALOG_STORE_SETTINGS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352495
#define RSSGT_ATTR_IQ_OUTPUT_ANALOG_DELETE_SETTINGS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352496
#define RSSGT_ATTR_IQ_OUTPUT_ANALOG_SETTINGS_CATALOG                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352497
#define RSSGT_ATTR_IQ_OUTPUT_ANALOG_I_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352574
#define RSSGT_ATTR_IQ_OUTPUT_ANALOG_Q_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352575
#define RSSGT_ATTR_IQ_OUTPUT_ANALOG_DISPLAY_POWER_VIA                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352576
#define RSSGT_ATTR_ENVELOPE_TRACKING_RF_ENVELOPE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352498
#define RSSGT_ATTR_ENVELOPE_TRACKING_VOLTAGE_ADAPTATION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352499
#define RSSGT_ATTR_ENVELOPE_TRACKING_ETRACK_INTERFACE_TYPE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352500
#define RSSGT_ATTR_ENVELOPE_TRACKING_VOLTAGE_REFERENCE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352501
#define RSSGT_ATTR_ENVELOPE_TRACKING_VOUT_MAX                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352502
#define RSSGT_ATTR_ENVELOPE_TRACKING_VOUT_MIN                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352503
#define RSSGT_ATTR_ENVELOPE_TRACKING_BIAS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352504
#define RSSGT_ATTR_ENVELOPE_TRACKING_OFFSET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352505
#define RSSGT_ATTR_ENVELOPE_TRACKING_VPP_MAX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352506
#define RSSGT_ATTR_ENVELOPE_TRACKING_EMF_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352507
#define RSSGT_ATTR_ENVELOPE_TRACKING_RIN                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352508
#define RSSGT_ATTR_ENVELOPE_TRACKING_TERMINATION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352509
#define RSSGT_ATTR_ENVELOPE_TRACKING_BIPOLAR_INPUT_ENABLED                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352510
#define RSSGT_ATTR_ENVELOPE_TRACKING_GAIN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352511
#define RSSGT_ATTR_ENVELOPE_TRACKING_VCC_OFFSET                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352512
#define RSSGT_ATTR_ENVELOPE_TRACKING_VCC_MAX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352513
#define RSSGT_ATTR_ENVELOPE_TRACKING_VCC_MIN                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352514
#define RSSGT_ATTR_ENVELOPE_TRACKING_PEP_IN_MAX                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352515
#define RSSGT_ATTR_ENVELOPE_TRACKING_PEP_IN_MIN                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352516
#define RSSGT_ATTR_ENVELOPE_TRACKING_POWER_OFFSET                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352517
#define RSSGT_ATTR_ENVELOPE_TRACKING_DELAY                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352518
#define RSSGT_ATTR_ENVELOPE_TRACKING_CALCULATE_ENVELOPE_FROM_PREDISTORTED_SIGNAL RS_SPECIFIC_PUBLIC_ATTR_BASE + 352519
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352520
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING_DETROUGHING_FUNCTION           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352521
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING_COUPLE_DETROUGHING_FACTOR_WITH_VCC RS_SPECIFIC_PUBLIC_ATTR_BASE + 352522
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING_DETROUGHING_FACTOR             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352523
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING_DETROUGHING_EXPONENT           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352524
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING_PRE_GAIN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352525
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING_POST_GAIN                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352526
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING_INTERPOLATION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352527
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING_SCALE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352528
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING_CLIPPING_FROM                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352577
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING_CLIPPING_TO                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352578
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING_FILE_CATALOG                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352529
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING_SELECT_FILE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352530
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING_PV_FILE_CATALOG                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352531
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING_PV_SELECT_FILE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352532
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING_POLYNOMIAL_FILE_CATALOG        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352533
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING_POLYNOMIAL_LOAD_FILE           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352534
#define RSSGT_ATTR_ENVELOPE_TRACKING_SHAPING_POLYNOMIAL_SAVE_FILE           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352535
#define RSSGT_ATTR_IQ_MODULATION_IMPAIRMENTS_ENABLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352247
#define RSSGT_ATTR_IQ_I_OFFSET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352248
#define RSSGT_ATTR_IQ_Q_OFFSET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352249
#define RSSGT_ATTR_IQ_GAIN_IMBALANCE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352250
#define RSSGT_ATTR_IQ_QUADRATURE_OFFSET                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352251
#define RSSGT_ATTR_IQ_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352458
#define RSSGT_ATTR_IQ_IMPAIRMENTS_SWAP                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352486
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352536
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_SET_TO_DEFAULT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352537
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_LOAD_SETTINGS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352538
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_STORE_SETTINGS                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352539
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_DELETE_SETTINGS                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352540
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_SETTINGS_CATALOG                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352541
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_AM_AM_FIRST                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352542
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_LEVEL_REFERENCE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352543
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_MAXIMUM_OUTPUT_LEVEL_ERROR         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352544
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_MAXIMUM_NUMBER_OF_ITERACTIONS      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352545
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_INTERACTIONS_STATUS                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352546
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_ACHIEVED_OUTPUT_LEVEL_ERROR        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352547
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_INPUT_PEP                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352548
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_INPUT_LEVEL                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352549
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_INPUT_CREST_FACTOR                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352550
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_OUTPUT_PEP                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352551
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_OUTPUT_LEVEL                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352552
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_OUTPUT_CREST_FACTOR                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352553
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_AM_AM_STATE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352554
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_AM_PM_STATE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352555
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_SHAPING                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352556
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_INTERPOLATION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352557
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_INVERT_CORRECTION_VALUES           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352558
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_MAXIMUM_PEP_INPUT_POWER            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352559
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_MINIMUM_PEP_INPUT_POWER            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352560
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_PRE_GAIN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352561
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_SHAPING_TABLE_AM_AM_FILE_CATALOG   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352562
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_SHAPING_TABLE_AM_AM_SELECT_FILE    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352563
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_SHAPING_TABLE_AM_PM_FILE_CATALOG   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352564
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_SHAPING_TABLE_AM_PM_SELECT_FILE    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352565
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_SHAPING_POLYNOMIAL_FILE_CATALOG    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352566
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_SHAPING_POLYNOMIAL_LOAD_FILE       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352567
#define RSSGT_ATTR_DIGITAL_PREDISTORTION_SHAPING_POLYNOMIAL_SAVE_FILE       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352568
#define RSSGT_ATTR_IQ_IMPAIRMENTS_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352439
#define RSSGT_ATTR_IQ_IMPAIRMENTS_DELAY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352440
#define RSSGT_ATTR_IQ_IMPAIRMENTS_RATIO                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352441
#define RSSGT_ATTR_IQ_IMPAIRMENTS_LEAKAGE_I                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352442
#define RSSGT_ATTR_IQ_IMPAIRMENTS_LEAKAGE_Q                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352443
#define RSSGT_ATTR_IQ_IMPAIRMENTS_QUADRATURE_OFFSET                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352444
#define RSSGT_ATTR_IQ_IMPAIRMENTS_SKEW                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352445
#define RSSGT_ATTR_IQ_IMPAIRMENTS_PEAK_LEVEL                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352254
#define RSSGT_ATTR_IQ_IMPAIRMENTS_SIGNAL_LEVEL                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352255
#define RSSGT_ATTR_IQ_IMPAIRMENTS_OPTIMIZATION_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352256
#define RSSGT_ATTR_IQ_IMPAIRMENTS_OPTIMIZATION_MODE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352257
#define RSSGT_ATTR_IQ_IMPAIRMENTS_CREST_FACTOR                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352258
#define RSSGT_ATTR_IQ_OUTPUT_IMPAIRMENTS_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352579
#define RSSGT_ATTR_IQ_OUTPUT_IMPAIRMENTS_DELAY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352580
#define RSSGT_ATTR_IQ_OUTPUT_IMPAIRMENTS_RATIO                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352581
#define RSSGT_ATTR_IQ_OUTPUT_IMPAIRMENTS_LEAKAGE_I                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352582
#define RSSGT_ATTR_IQ_OUTPUT_IMPAIRMENTS_LEAKAGE_Q                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352583
#define RSSGT_ATTR_IQ_OUTPUT_IMPAIRMENTS_QUADRATURE_OFFSET                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352584
#define RSSGT_ATTR_IQ_OUTPUT_IMPAIRMENTS_SKEW                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352585
#define RSSGT_ATTR_IQ_OUTPUT_IMPAIRMENTS_PHASE_OFFSET                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352657
#define RSSGT_ATTR_AWGN_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352259
#define RSSGT_ATTR_AWGN_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352260
#define RSSGT_ATTR_AWGN_BANDWIDTH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352261
#define RSSGT_ATTR_AWGN_BANDWIDTH_RATIO                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352262
#define RSSGT_ATTR_AWGN_BANDWIDTH_NOISE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352263
#define RSSGT_ATTR_AWGN_BIT_RATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352264
#define RSSGT_ATTR_AWGN_DISPLAY_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352265
#define RSSGT_ATTR_AWGN_DISPLAY_OUTPUT_RESULT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352266
#define RSSGT_ATTR_AWGN_TARGET_CW_FREQUENCY_OFFSET                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352267
#define RSSGT_ATTR_AWGN_RESULTING_CW_FREQUENCY_OFFSET                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352268
#define RSSGT_ATTR_AWGN_NOISE_LEVEL_VIA                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352269
#define RSSGT_ATTR_AWGN_CARRIER_TO_NOISE_RATIO                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352270
#define RSSGT_ATTR_AWGN_EB_TO_N0                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352271
#define RSSGT_ATTR_AWGN_CARRIER_LEVEL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352272
#define RSSGT_ATTR_AWGN_NOISE_LEVEL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352273
#define RSSGT_ATTR_AWGN_NOISE_LEVEL_TOTAL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352274
#define RSSGT_ATTR_AWGN_CARRIER_AND_NOISE_LEVEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352275
#define RSSGT_ATTR_AWGN_CARRIER_AND_NOISE_PEP                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352276
#define RSSGT_ATTR_AWGN_POWER_REFERENCE_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352277
#define RSSGT_ATTR_OUTPUT_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352279
#define RSSGT_ATTR_BB_OPERATION_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352278
#define RSSGT_ATTR_PATH_COUNT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352569
#define RSSGT_ATTR_RF_FREQUENCY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352280
#define RSSGT_ATTR_RF_FREQUENCY_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352649
#define RSSGT_ATTR_RF_DELTA_PHASE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352281
#define RSSGT_ATTR_RESET_RF_DELTA_PHASE_DISPLAY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352282
#define RSSGT_ATTR_PULM_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352283
#define RSSGT_ATTR_PULM_POLARITY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352284
#define RSSGT_ATTR_PULM_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352285
#define RSSGT_ATTR_PULM_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352286
#define RSSGT_ATTR_PULM_PERIOD                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352287
#define RSSGT_ATTR_PULM_WIDTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352288
#define RSSGT_ATTR_PULM_DELAY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352289
#define RSSGT_ATTR_PULM_DOUBLE_WIDTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352291
#define RSSGT_ATTR_PULM_DOUBLE_DELAY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352292
#define RSSGT_ATTR_PULM_TRIGGER_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352293
#define RSSGT_ATTR_PULM_TRIGGER_EXTERNAL_INPUT_IMPEDANCE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352294
#define RSSGT_ATTR_PULM_TRIGGER_EXTERNAL_INPUT_SLOPE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352295
#define RSSGT_ATTR_PULM_TRIGGER_EXTERNAL_INPUT_GATE_POLARITY                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352296
#define RSSGT_ATTR_ALC_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352297
#define RSSGT_ATTR_ALC_SEARCH_ONCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352298
#define RSSGT_ATTR_ALC_DETECTOR_SENSITIVITY                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352299
#define RSSGT_ATTR_RF_AMPLITUDE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352300
#define RSSGT_ATTR_RF_LEVEL_OFFSET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352586
#define RSSGT_ATTR_RF_LEVEL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352587
#define RSSGT_ATTR_RF_LEVEL_LIMIT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352301
#define RSSGT_ATTR_RF_LEVEL_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352302
#define RSSGT_ATTR_RF_LEVEL_SETTING_CHARACTERISTIC                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352303
#define RSSGT_ATTR_RF_LEVEL_RANGE_MINIMUM                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352304
#define RSSGT_ATTR_RF_LEVEL_RANGE_MAXIMUM                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352305
#define RSSGT_ATTR_RF_PEP                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352306
#define RSSGT_ATTR_RF_LEVEL_RANGE_WARNINGS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352588
#define RSSGT_ATTR_RF_ATTENUATOR_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352307
#define RSSGT_ATTR_RF_ATTENUATOR_LOWER_RANGE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352308
#define RSSGT_ATTR_RF_ATTENUATOR_UPPER_RANGE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352309
#define RSSGT_ATTR_RF_ATTENUATOR_RF_OFF_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352310
#define RSSGT_ATTR_RF_ATTENUATOR_SWITCH_OVER_OFFSET                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352311
#define RSSGT_ATTR_RF_ATTENUATION_DIGITAL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352434
#define RSSGT_ATTR_POWER_ON_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352312
#define RSSGT_ATTR_USER_CORRECTION_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352460
#define RSSGT_ATTR_USER_CORRECTION_VALUE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352461
#define RSSGT_ATTR_USER_CORRECTION_CATALOG                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352462
#define RSSGT_ATTR_USER_CORRECTION_SELECTED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352463
#define RSSGT_ATTR_USER_CORRECTION_NUMBER_OF_FREQUENCIES                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352465
#define RSSGT_ATTR_USER_CORRECTION_NUMBER_OF_POWERS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352467
#define RSSGT_ATTR_USER_CORRECTION_DELETE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352468
#define RSSGT_ATTR_USER_CORRECTION_IMPORT_EXPORT_CATALOG                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352470
#define RSSGT_ATTR_USER_CORRECTION_IMPORT_EXPORT_EXTENSION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352471
#define RSSGT_ATTR_USER_CORRECTION_IMPORT_EXPORT_ASCII_FILE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352472
#define RSSGT_ATTR_USER_CORRECTION_IMPORT_EXPORT_CORRECTION_FILE            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352473
#define RSSGT_ATTR_USER_CORRECTION_IMPORT_EXPORT_COLUMN_SEPARATOR           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352474
#define RSSGT_ATTR_USER_CORRECTION_IMPORT_EXPORT_DECIMAL_SEPARATOR          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352475
#define RSSGT_ATTR_USER_CORRECTION_IMPORT_EXPORT_MODE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352476
#define RSSGT_ATTR_USER_CORRECTION_IMPORT_EXPORT_EXECUTE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352477
#define RSSGT_ATTR_LOSC_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352316
#define RSSGT_ATTR_BBIN_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352317
#define RSSGT_ATTR_BBIN_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352318
#define RSSGT_ATTR_BBIN_IQ_SWAP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352319
#define RSSGT_ATTR_BBIN_IQ_SKEW                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352320
#define RSSGT_ATTR_BBIN_CREST_FACTOR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352321
#define RSSGT_ATTR_BBIN_MEASUREMENT_PERIOD                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352322
#define RSSGT_ATTR_BBIN_AUTO_LEVEL_SET_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352323
#define RSSGT_ATTR_BBIN_AUTO_LEVEL_SET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352324
#define RSSGT_ATTR_BBIN_OVERLOAD_RESET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352325
#define RSSGT_ATTR_BBIN_OVERLOAD_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352326
#define RSSGT_ATTR_BBIN_OVERLOAD_HOLD_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352446
#define RSSGT_ATTR_BBIN_RMS_POWER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352327
#define RSSGT_ATTR_BBIN_CURRENT_SAMPLE_RATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352328
#define RSSGT_ATTR_BBIN_PATH_GAIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352330
#define RSSGT_ATTR_BBIN_FREQUENCY_OFFSET                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352331
#define RSSGT_ATTR_BBIN_EXTERNALLY_CONNECTED_ID                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352332
#define RSSGT_ATTR_BBIN_SAMPLE_RATE_SOURCE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352333
#define RSSGT_ATTR_BBIN_OUTPUT_DELAY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352589
#define RSSGT_ATTR_BBIN_IMPAIRMENTS_GAIN_IMBALANCE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352334
#define RSSGT_ATTR_BBIN_IMPAIRMENTS_I_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352335
#define RSSGT_ATTR_BBIN_IMPAIRMENTS_Q_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352336
#define RSSGT_ATTR_POWER_UNIT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352605
#define RSSGT_ATTR_POWER_FREQUENCY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352606
#define RSSGT_ATTR_POWER_RECORDER_STATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352607
#define RSSGT_ATTR_POWER_OFFSET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352608
#define RSSGT_ATTR_POWER_OFFSET_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352609
#define RSSGT_ATTR_POWER_SOURCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352610
#define RSSGT_ATTR_POWER_ZERO                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352611
#define RSSGT_ATTR_POWER_CONTINUOUS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352612
#define RSSGT_ATTR_POWER_USE_SPARAMETERS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352613
#define RSSGT_ATTR_POWER_DISPLAY_PERMANENT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352614
#define RSSGT_ATTR_POWER_DISPLAY_PERMANENT_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352615
#define RSSGT_ATTR_POWER_FILTER_LENGTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352622
#define RSSGT_ATTR_POWER_FILTER_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352623
#define RSSGT_ATTR_POWER_FILTER_NS_RATIO                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352624
#define RSSGT_ATTR_POWER_FILTER_NS_RATIO_TIMEOUT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352625
#define RSSGT_ATTR_POWER_FILTER_LENGTH_AUTO                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352626
#define RSSGT_ATTR_POWER_FILTER_SEARCH_ONCE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352627
#define RSSGT_ATTR_POWER_SENSOR_DEVICE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352628
#define RSSGT_ATTR_POWER_SENSOR_TYPE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352629
#define RSSGT_ATTR_POWER_READ_POWER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352630
#define RSSGT_ATTR_POWER_SENSOR_VERSION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352631
#define RSSGT_ATTR_POWER_SENSOR_SERIAL_NUMBER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352632
#define RSSGT_ATTR_POWER_DEFAULT_APERTURE_TIME_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352633
#define RSSGT_ATTR_POWER_APERTURE_TIME                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352634
#define RSSGT_ATTR_POWER_BASEBAND_ADD_MEASUREMENT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352635
#define RSSGT_ATTR_POWER_BASEBAND_CHANGE_MEASUREMENT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352636
#define RSSGT_ATTR_POWER_BASEBAND_DELETE_MEASUREMENT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352637
#define RSSGT_ATTR_POWER_BASEBAND_EXECUTE_MEASUREMENT                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352638
#define RSSGT_ATTR_POWER_BASEBAND_ABORT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352641
#define RSSGT_ATTR_PSER_STATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352651
#define RSSGT_ATTR_PSER_TARGET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352650
#define RSSGT_ATTR_PSER_TOL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352652
#define RSSGT_ATTR_PSER_TEST                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352653
#define RSSGT_ATTR_PSER_TRACK                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352656
#define RSSGT_ATTR_PSER_SENSOR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352654
#define RSSGT_ATTR_PSER_APER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352655
#define RSSGT_ATTR_CLOCK_INPUT_SLOPE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352337
#define RSSGT_ATTR_CLOCK_MODE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352339
#define RSSGT_ATTR_CLOCK_INPUT_FREQUENCY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352340
#define RSSGT_ATTR_RESTART                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352347
#define RSSGT_ATTR_STANDBY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352348
#define RSSGT_ATTR_UNLOCK                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352350
#define RSSGT_ATTR_USER_PATH                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352479
#define RSSGT_ATTR_ID_QUERY_RESPONSE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352096
#define RSSGT_ATTR_CALIBRATION_ALL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352351
#define RSSGT_ATTR_CALIBRATION_FREQUENCY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352352
#define RSSGT_ATTR_CALIBRATION_FREQUENCY_TEMPERATURE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352353
#define RSSGT_ATTR_CALIBRATION_IQ_MODULATOR_FULL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352354
#define RSSGT_ATTR_CALIBRATION_IQ_MODULATOR_LOCAL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352355
#define RSSGT_ATTR_CALIBRATION_IQ_MODULATOR_TEMPERATURE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352356
#define RSSGT_ATTR_CALIBRATION_LEVEL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352357
#define RSSGT_ATTR_CALIBRATION_LEVEL_TEMPERATURE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352358
#define RSSGT_ATTR_CALIBRATION_IQ_INPUT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352359
#define RSSGT_ATTR_TEST_ALL_START                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352360
#define RSSGT_ATTR_TEST_ALL_RESULT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352361
#define RSSGT_ATTR_TEST_KEYBOARD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352362
#define RSSGT_ATTR_TEST_EXTERNAL_IQ_DEVICES                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352447
#define RSSGT_ATTR_TEST_BASEBAND_INPUT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352448
#define RSSGT_ATTR_DIAGNOSTIC_TEST_POINTS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352366
#define RSSGT_ATTR_MMEMORY_CHANGE_DIRECTORY                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352370
#define RSSGT_ATTR_MMEMORY_DELETE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352377
#define RSSGT_ATTR_MMEMORY_MAKE_DIRECTORY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352380
#define RSSGT_ATTR_MMEMORY_REMOVE_DIRECTORY                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352384
#define RSSGT_ATTR_SYSTEM_FACTORY_PRESET                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352388
#define RSSGT_ATTR_SYSTEM_ERROR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352389
#define RSSGT_ATTR_SYSTEM_ERROR_QUEUE_ALL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352390
#define RSSGT_ATTR_SYSTEM_ERROR_QUEUE_CODE_ALL                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352391
#define RSSGT_ATTR_SYSTEM_ERROR_QUEUE_CODE_NEXT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352392
#define RSSGT_ATTR_SYSTEM_ERROR_QUEUE_COUNT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352393
#define RSSGT_ATTR_SYSTEM_ERROR_QUEUE_NEXT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352394
#define RSSGT_ATTR_SYSTEM_ERROR_ALL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352395
#define RSSGT_ATTR_SYSTEM_VERSION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352396
#define RSSGT_ATTR_SYSTEM_PRESET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352397
#define RSSGT_ATTR_SYSTEM_STARTUP_COMPLETE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352398
#define RSSGT_ATTR_SYSTEM_USB_RESOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352399
#define RSSGT_ATTR_SYSTEM_GPIB_RESOURCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352590
#define RSSGT_ATTR_SYSTEM_GPIB_ADDRESS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352591
#define RSSGT_ATTR_SYSTEM_GPIB_LINE_TERMINATOR                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352592
#define RSSGT_ATTR_SYSTEM_SERIAL_RESOURCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352400
#define RSSGT_ATTR_SYSTEM_SERIAL_BAUD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352401
#define RSSGT_ATTR_SYSTEM_SERIAL_PARITY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352402
#define RSSGT_ATTR_SYSTEM_SERIAL_STOP_BITS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352403
#define RSSGT_ATTR_SYSTEM_HISLIP_RESOURCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352404
#define RSSGT_ATTR_SYSTEM_PCI_EXPRESS_RESOURCE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352405
#define RSSGT_ATTR_SYSTEM_SOCKET_RESOURCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352406
#define RSSGT_ATTR_SYSTEM_OPERATING_SYSTEM                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352408
#define RSSGT_ATTR_SYSTEM_UPTIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352450
#define RSSGT_ATTR_SYSTEM_NETWORK_RESTART                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352410
#define RSSGT_ATTR_SYSTEM_NETWORK_STATUS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352411
#define RSSGT_ATTR_SYSTEM_NETWORK_RESOURCE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352412
#define RSSGT_ATTR_SYSTEM_NETWORK_MAC_ADDRESS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352413
#define RSSGT_ATTR_SYSTEM_NETWORK_HOST_NAME                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352414
#define RSSGT_ATTR_SYSTEM_NETWORK_IP_ADDRESS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352415
#define RSSGT_ATTR_SYSTEM_NETWORK_IP_ADDRESS_SUBNET_MASK                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352416
#define RSSGT_ATTR_SYSTEM_NETWORK_IP_ADDRESS_GATEWAY                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352417
#define RSSGT_ATTR_SYSTEM_NETWORK_IP_ADDRESS_MODE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352418
#define RSSGT_ATTR_SYSTEM_NETWORK_IP_ADDRESS_DNS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352593
#define RSSGT_ATTR_STATUS_PRESET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352419
#define RSSGT_ATTR_UNIT_ANGLE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352420
#define RSSGT_ATTR_UNIT_POWER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352421
#define RSSGT_ATTR_CONNECTOR_OUTPUT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352428
#define RSSGT_ATTR_CONNECTOR_OPERATION_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352451
#define RSSGT_ATTR_CONNECTOR_THRESHOLD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352452
#define RSSGT_ATTR_CONNECTOR_CLOCK_IMPEDANCE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352487
#define RSSGT_ATTR_CONNECTOR_CLOCK_SLOPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352488
#define RSSGT_ATTR_CONNECTOR_TRIGGER_IMPEDANCE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352489
#define RSSGT_ATTR_CONNECTOR_TRIGGER_SLOPE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352490
#define RSSGT_ATTR_FAST_SPEED_RF_OUTPUT_FREQUENCY                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352429
#define RSSGT_ATTR_FAST_SPEED_RF_OUTPUT_LEVEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352430
#define RSSGT_ATTR_FORMAT_SEQUENCE_OF_BYTES                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352431
#define RSSGT_ATTR_FORMAT_STATUS_REGISTER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352432
#define RSSGT_ATTR_FORMAT_DATA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352433
#define RSSGT_ATTR_TIME_ZONE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352484
#define RSSGT_ATTR_TIME_ZONE_CATALOG                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352485
#define RSSGT_ATTR_INIT_SW_TRIGGER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350156

// manually added
#define RSSGT_ATTR_IQ_OUTPUT_ANALOG_MODE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350157
#define RSSGT_ATTR_IQ_OUTPUT_ANALOG_BIAS_COUPLING_STATE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350158
#define RSSGT_ATTR_IQ_OUTPUT_ANALOG_BIAS_I                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350159



// rssgt_rngPulseModulationPolarity
#define RSSGT_VAL_PULM_POLARITY_NORMAL                                      0
#define RSSGT_VAL_PULM_POLARITY_INVERSE                                     1

// rssgt_rngExternalTriggerSlope
#define RSSGT_VAL_PULSE_EXTERNAL_TRIGGER_SLOPE_POSITIVE                     0
#define RSSGT_VAL_PULSE_EXTERNAL_TRIGGER_SLOPE_NEGATIVE                     1

// rssgt_rngReferenceOscillatorSource
#define RSSGT_VAL_ROSC_SOURCE_INTERNAL                                      0
#define RSSGT_VAL_ROSC_SOURCE_EXTERNAL                                      1

// rssgt_rngReferenceOscillatorExternalFrequency
#define RSSGT_VAL_SMU_ROSC_EXTERNAL_FREQUENCY_5MHZ                          0
#define RSSGT_VAL_SMU_ROSC_EXTERNAL_FREQUENCY_10MHZ                         1
#define RSSGT_VAL_SMU_ROSC_EXTERNAL_FREQUENCY_13MHZ                         2

// rssgt_rngClockSynchronisationMode
#define RSSGT_VAL_CLOCK_SYNC_MODE_NONE                                      0
#define RSSGT_VAL_CLOCK_SYNC_MODE_MASTER                                    1
#define RSSGT_VAL_CLOCK_SYNC_MODE_SLAVE                                     2
#define RSSGT_VAL_CLOCK_SYNC_MODE_DIIN                                      3

// rssgt_rngTrgTriggerMode
#define RSSGT_VAL_TRIGGER_MODE_AUTO                                         0
#define RSSGT_VAL_TRIGGER_MODE_RETRIGGER                                    1
#define RSSGT_VAL_TRIGGER_MODE_AAUTO                                        2
#define RSSGT_VAL_TRIGGER_MODE_ARETRIGGER                                   3
#define RSSGT_VAL_TRIGGER_MODE_SINGLE                                       4

// rssgt_rngClockMode
#define RSSGT_VAL_CLOCK_MODE_SAMP                                           0
#define RSSGT_VAL_CLOCK_MODE_MSAMP                                          1

// rssgt_rngARBExtendedTriggerMode
#define RSSGT_VAL_ARB_EXTENDED_TRIGGER_MODE_SAME                            0
#define RSSGT_VAL_ARB_EXTENDED_TRIGGER_MODE_NEXT                            1
#define RSSGT_VAL_ARB_EXTENDED_TRIGGER_MODE_NSEAM                           2
#define RSSGT_VAL_ARB_EXTENDED_TRIGGER_MODE_SEQ                             3

// rssgt_rngARBSignalDurationUnit
#define RSSGT_VAL_ARB_TRIGGER_UNIT_SAMPLE                                   0
#define RSSGT_VAL_ARB_TRIGGER_UNIT_SEQUENCE                                 1

// rssgt_rngARBMarkerMode
#define RSSGT_VAL_ARB_MARKER_MODE_UNCH                                      0
#define RSSGT_VAL_ARB_MARKER_MODE_RESTART                                   1
#define RSSGT_VAL_ARB_MARKER_MODE_PULSE                                     2
#define RSSGT_VAL_ARB_MARKER_MODE_PATTERN                                   3
#define RSSGT_VAL_ARB_MARKER_MODE_RATIO                                     4

// rssgt_rngARBMultisegmentLevelMode
#define RSSGT_VAL_ARB_LEVEL_MODE_UNCH                                       0
#define RSSGT_VAL_ARB_LEVEL_MODE_ERMS                                       1

// rssgt_rngARBSequenceRestart
#define RSSGT_VAL_ARB_SRESTART_DISABLED                                     0
#define RSSGT_VAL_ARB_SRESTART_MRK1                                         1
#define RSSGT_VAL_ARB_SRESTART_MRK2                                         2
#define RSSGT_VAL_ARB_SRESTART_MRK3                                         3
#define RSSGT_VAL_ARB_SRESTART_MRK4                                         4

// rssgt_rngARBMultisegmentClockMode
#define RSSGT_VAL_ARB_CLOCK_MODE_UNCH                                       0
#define RSSGT_VAL_ARB_CLOCK_MODE_HIGH                                       1
#define RSSGT_VAL_ARB_CLOCK_MODE_USER                                       2

// rssgt_rngARBMultiCarrierMode
#define RSSGT_VAL_ARB_MULTIC_MODE_EQU                                       0
#define RSSGT_VAL_ARB_MULTIC_MODE_ARB                                       1

// rssgt_rngARBMultiCarrierCrestFactorMode
#define RSSGT_VAL_ARB_SRC_CFACTOR_MODE_OFF                                  0
#define RSSGT_VAL_ARB_SRC_CFACTOR_MODE_MIN                                  1
#define RSSGT_VAL_ARB_SRC_CFACTOR_MODE_MAX                                  2

// rssgt_rngARBSignalPeriodMode
#define RSSGT_VAL_ARB_SRC_CALC_MODE_LONG                                    0
#define RSSGT_VAL_ARB_SRC_CALC_MODE_SHRT                                    1
#define RSSGT_VAL_ARB_SRC_CALC_MODE_USER                                    2
#define RSSGT_VAL_ARB_SRC_CALC_MODE_LCM                                     3

// rssgt_rngBBINMode
#define RSSGT_VAL_BBIN_MODE_ANALOG                                          0
#define RSSGT_VAL_BBIN_MODE_DIGITAL                                         1

// rssgt_rngImpedance
#define RSSGT_VAL_IMPEDANCE_G50                                             0
#define RSSGT_VAL_IMPEDANCE_G1K                                             1

// rssgt_rngSlope
#define RSSGT_VAL_SLOPE_NEGATIVE                                            0
#define RSSGT_VAL_SLOPE_POSITIVE                                            1

// rssgt_rngGlobalClockMode
#define RSSGT_VAL_CLOCK_OUTPUT_MODE_SYMBOL                                  0
#define RSSGT_VAL_CLOCK_OUTPUT_MODE_BIT                                     1

// rssgt_rngIMPOptimizationMode
#define RSSGT_VAL_OPTIM_MODE_FAST                                           0
#define RSSGT_VAL_OPTIM_MODE_QHIGH                                          1

// rssgt_rngAWGNMode
#define RSSGT_VAL_AWGN_MODE_ADD                                             0
#define RSSGT_VAL_AWGN_MODE_ONLY                                            1
#define RSSGT_VAL_AWGN_MODE_CWI                                             2

// rssgt_rngAWGNNoiseMode
#define RSSGT_VAL_AWGN_POWER_MODE_CN                                        0
#define RSSGT_VAL_AWGN_POWER_MODE_EN                                        1
#define RSSGT_VAL_AWGN_POWER_MODE_SN                                        2

// rssgt_rngUnitAngle
#define RSSGT_VAL_UNIT_ANGLE_DEG                                            0
#define RSSGT_VAL_UNIT_ANGLE_RAD                                            1

// rssgt_rngUnitPower
#define RSSGT_VAL_UNIT_POWER_V                                              0
#define RSSGT_VAL_UNIT_POWER_DBM                                            1
#define RSSGT_VAL_UNIT_POWER_DBUV                                           2

// rssgt_rngSystemIPAddressMode
#define RSSGT_VAL_SYSTEM_COMMUNICATE_IP_MODE_STATIC                         0
#define RSSGT_VAL_SYSTEM_COMMUNICATE_IP_MODE_AUTO                           1

// rssgt_rngROSCSynchronizationBandwidth
#define RSSGT_VAL_ROSC_SBAN_WIDE                                            0
#define RSSGT_VAL_ROSC_SBAN_NARROW                                          1

// rssgt_rngRFAttenuatorMode
#define RSSGT_VAL_OUTPUT_AMODE_AUTO                                         0
#define RSSGT_VAL_OUTPUT_AMODE_FIXED                                        1
#define RSSGT_VAL_OUTPUT_AMODE_AUTOPASS                                     2

// rssgt_rngPowerOnState
#define RSSGT_VAL_OUTPUT_STATE_PON_OFF                                      0
#define RSSGT_VAL_OUTPUT_STATE_PON_UNCH                                     1

// rssgt_rngALCEnabled
#define RSSGT_VAL_POWER_ALC_STATE_TAB_ON                                    0
#define RSSGT_VAL_POWER_ALC_STATE_ON                                        1
#define RSSGT_VAL_POWER_ALC_STATE_OFFT                                      2

// rssgt_rngPULMPolarity
#define RSSGT_VAL_PULM_POLARITY_INVERTED                                    1

// rssgt_rngPULMSource
#define RSSGT_VAL_PULM_SOURCE_INTERNAL                                      0
#define RSSGT_VAL_PULM_SOURCE_EXTERNAL                                      1

// rssgt_rngPULMExternalInputImpedance
#define RSSGT_VAL_INPUT_IMPEDANCE_G50                                       0
#define RSSGT_VAL_INPUT_IMPEDANCE_G10K                                      1

// rssgt_rngPULMTriggerMode
#define RSSGT_VAL_PULM_TRIGGER_MODE_AUTO                                    0
#define RSSGT_VAL_PULM_TRIGGER_MODE_EXTERNAL                                1
#define RSSGT_VAL_PULM_TRIGGER_MODE_EGATE                                   2

// rssgt_rngTriggerSour
#define RSSGT_VAL_TRIGGER_SOURCE_INTERNAL                                   0
#define RSSGT_VAL_TRIGGER_SOURCE_EXTERNAL                                   1

// rssgt_rngClockSource
#define RSSGT_VAL_CLOCK_SOURCE_INTERNAL                                     0
#define RSSGT_VAL_CLOCK_SOURCE_EXTERNAL                                     1

// rssgt_rngPULMMode
#define RSSGT_VAL_PULSE_MODE_SINGLE                                         0
#define RSSGT_VAL_PULSE_MODE_DOUBLE                                         1

// rssgt_rngALCDetectorSensitivity
#define RSSGT_VAL_ALC_DETECTOR_AUTO                                         0
#define RSSGT_VAL_ALC_DETECTOR_LOW                                          1
#define RSSGT_VAL_ALC_DETECTOR_MEDIUM                                       2
#define RSSGT_VAL_ALC_DETECTOR_HIGH                                         3

// rssgt_rngRFAttRFOFFMode
#define RSSGT_VAL_RF_OFF_MODE_UNCH                                          0
#define RSSGT_VAL_RF_OFF_MODE_FULL                                          1

// rssgt_rngRFLevelMode
#define RSSGT_VAL_RF_LEVEL_MODE_NORMAL                                      0
#define RSSGT_VAL_RF_LEVEL_MODE_LOWNOISE                                    1
#define RSSGT_VAL_RF_LEVEL_MODE_LOWDIST                                     2

// rssgt_rngIQSMWAnalogWidebandGain
#define RSSGT_VAL_IQ_GAIN_DBM3                                              0
#define RSSGT_VAL_IQ_GAIN_DBM4                                              1
#define RSSGT_VAL_IQ_GAIN_DBM2                                              2
#define RSSGT_VAL_IQ_GAIN_DB0                                               3
#define RSSGT_VAL_IQ_GAIN_DB2                                               4
#define RSSGT_VAL_IQ_GAIN_DB3                                               5
#define RSSGT_VAL_IQ_GAIN_DB4                                               6
#define RSSGT_VAL_IQ_GAIN_DB6                                               7
#define RSSGT_VAL_IQ_GAIN_DB8                                               8

// rssgt_rngROSCOutputFrequency
#define RSSGT_VAL_ROSC_FREQUENCY_10MHZ                                      0
#define RSSGT_VAL_ROSC_FREQUENCY_100MHZ                                     1
#define RSSGT_VAL_ROSC_FREQUENCY_1000MHZ                                    2
#define RSSGT_VAL_ROSC_FREQUENCY_13MHZ                                      3

// rssgt_rngRFLevSettCharacteristic
#define RSSGT_VAL_RF_LEVEL_CHARACTERISTIC_AUTO                              0
#define RSSGT_VAL_RF_LEVEL_CHARACTERISTIC_UNIN                              1
#define RSSGT_VAL_RF_LEVEL_CHARACTERISTIC_MON                               2
#define RSSGT_VAL_RF_LEVEL_CHARACTERISTIC_CVSW                              3
#define RSSGT_VAL_RF_LEVEL_CHARACTERISTIC_USER                              4

// rssgt_rngOperationMode
#define RSSGT_VAL_OPERATION_MODE_NORM                                       0
#define RSSGT_VAL_OPERATION_MODE_BBBY                                       1

// rssgt_rngAWGNDisplayMode
#define RSSGT_VAL_AWGN_DISP_MODE_RF                                         0
#define RSSGT_VAL_AWGN_DISP_MODE_BB                                         1

// rssgt_rngAWGNPowerRefMode
#define RSSGT_VAL_AWGN_REF_MODE_CARR                                        0
#define RSSGT_VAL_AWGN_REF_MODE_NOIS                                        1

// rssgt_rngARBMCarPowerRef
#define RSSGT_VAL_ARB_MCAR_POWER_REF_RMS                                    0
#define RSSGT_VAL_ARB_MCAR_POWER_REF_PEAK                                   1

// rssgt_rngARBTriggerDelayUnit
#define RSSGT_VAL_TRIGGER_DELAY_UNIT_SAMP                                   0
#define RSSGT_VAL_TRIGGER_DELAY_UNIT_TIME                                   1

// rssgt_rngARBMultisegmentMarkerMode
#define RSSGT_VAL_ARB_MULTI_MARKER_MODE_IGN                                 0
#define RSSGT_VAL_ARB_MULTI_MARKER_MODE_TAKE                                1

// rssgt_rngBBINSRateSource
#define RSSGT_VAL_BBIN_SRATE_USER                                           0
#define RSSGT_VAL_BBIN_SRATE_DIN                                            1

// rssgt_rngIQOutputDigitalStepMode
#define RSSGT_VAL_IQ_OUTPUT_DIGITAL_STEP_MODE_DEC                           0
#define RSSGT_VAL_IQ_OUTPUT_DIGITAL_STEP_MODE_USER                          1

// rssgt_rngIQOutputDigitalSRateSource
#define RSSGT_VAL_IQ_OUTPUT_SAMPLE_RATE_SOURCE_USER                         0
#define RSSGT_VAL_IQ_OUTPUT_SAMPLE_RATE_SOURCE_DIN                          1
#define RSSGT_VAL_IQ_OUTPUT_SAMPLE_RATE_SOURCE_DOUT                         2

// rssgt_rngConnectorOutput
#define RSSGT_VAL_CONNECTOR_OUTPUT_REF                                      0
#define RSSGT_VAL_CONNECTOR_OUTPUT_LO                                       1
#define RSSGT_VAL_CONNECTOR_OUTPUT_OFF                                      2

// rssgt_rngSystemEmode
#define RSSGT_VAL_SYSTEM_EMODE_OFF                                          0
#define RSSGT_VAL_SYSTEM_EMODE_EM1                                          1
#define RSSGT_VAL_SYSTEM_EMODE_EM2                                          2

// rssgt_rngFormatSequenceOfBytes
#define RSSGT_VAL_FORMAT_BORDER_NORM                                        0
#define RSSGT_VAL_FORMAT_BORDER_SWAP                                        1

// rssgt_rngFormatStatusRegister
#define RSSGT_VAL_FORMAT_SREG_ASCII                                         0
#define RSSGT_VAL_FORMAT_SREG_BIN                                           1
#define RSSGT_VAL_FORMAT_SREG_HEX                                           2
#define RSSGT_VAL_FORMAT_SREG_OCT                                           3

// rssgt_rngFormatData
#define RSSGT_VAL_FORMAT_DATA_ASCII                                         0
#define RSSGT_VAL_FORMAT_DATA_PACK                                          1

// rssgt_rngSystemSerialParity
#define RSSGT_VAL_SERIAL_PARITY_NONE                                        0
#define RSSGT_VAL_SERIAL_PARITY_ODD                                         1
#define RSSGT_VAL_SERIAL_PARITY_EVEN                                        2

// rssgt_rngIQOutputLevelEntry
#define RSSGT_VAL_IQ_OUTPUT_LEVEL_ENTRY_PEP                                 0
#define RSSGT_VAL_IQ_OUTPUT_LEVEL_ENTRY_LEV                                 1

// rssgt_rngTestExternalIQDevices
#define RSSGT_VAL_TEST_EXTERNAL_IQ_IN                                       0
#define RSSGT_VAL_TEST_EXTERNAL_IQ_OUT                                      1

// rssgt_rngConnectorOperationMode
#define RSSGT_VAL_CONN_OPMODE_MKR1                                          0
#define RSSGT_VAL_CONN_OPMODE_MKR2                                          1
#define RSSGT_VAL_CONN_OPMODE_TRIG                                          2
#define RSSGT_VAL_CONN_OPMODE_CIN                                           3
#define RSSGT_VAL_CONN_OPMODE_COUT                                          4
#define RSSGT_VAL_CONN_OPMODE_SIN                                           5
#define RSSGT_VAL_CONN_OPMODE_SOUT                                          6
#define RSSGT_VAL_CONN_OPMODE_NEXT                                          7
#define RSSGT_VAL_CONN_OPMODE_LOW                                           8
#define RSSGT_VAL_CONN_OPMODE_MLAT                                          9
#define RSSGT_VAL_CONN_OPMODE_MARR                                          10
#define RSSGT_VAL_CONN_OPMODE_HIGH                                          11
#define RSSGT_VAL_CONN_OPMODE_SVAL                                          12
#define RSSGT_VAL_CONN_OPMODE_SNV                                           13
#define RSSGT_VAL_CONN_OPMODE_PVO                                           14
#define RSSGT_VAL_CONN_OPMODE_PETR                                          15
#define RSSGT_VAL_CONN_OPMODE_PEMS                                          16
#define RSSGT_VAL_CONN_OPMODE_TOUT                                          17

// rssgt_rngInput
#define RSSGT_VAL_SYSTEM_INPUT_G1K                                          0
#define RSSGT_VAL_SYSTEM_INPUT_G50                                          1
#define RSSGT_VAL_SYSTEM_INPUT_G10K                                         2

// rssgt_rngNextSegment
#define RSSGT_VAL_ARB_APPEND_SEGMENT_NEXT                                   0
#define RSSGT_VAL_ARB_APPEND_SEGMENT_BLANK                                  1
#define RSSGT_VAL_ARB_APPEND_SEGMENT_ENDLESS                                2
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG0                                   3
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG1                                   4
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG2                                   5
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG3                                   6
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG4                                   7
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG5                                   8
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG6                                   9
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG7                                   10
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG8                                   11
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG9                                   12
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG10                                  13
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG11                                  14
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG12                                  15
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG13                                  16
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG14                                  17
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG15                                  18
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG16                                  19
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG17                                  20
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG18                                  21
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG19                                  22
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG20                                  23
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG21                                  24
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG22                                  25
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG23                                  26
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG24                                  27
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG25                                  28
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG26                                  29
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG27                                  30
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG28                                  31
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG29                                  32
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG30                                  33
#define RSSGT_VAL_ARB_APPEND_SEGMENT_SEG31                                  34

// rssgt_rngIQSource
#define RSSGT_VAL_IQ_SOURCE_ANALOG                                          0
#define RSSGT_VAL_IQ_SOURCE_BASEBAND                                        1

// rssgt_rngUserCorrectionImportExportExtension
#define RSSGT_VAL_FILE_FORMAT_TXT                                           0
#define RSSGT_VAL_FILE_FORMAT_CSV                                           1

// rssgt_rngUserCorrectionImportExportColumnSeparator
#define RSSGT_VAL_COLUMN_SEPARATOR_TAB                                      0
#define RSSGT_VAL_COLUMN_SEPARATOR_SEMICOLON                                1
#define RSSGT_VAL_COLUMN_SEPARATOR_COMMA                                    2
#define RSSGT_VAL_COLUMN_SEPARATOR_SPACE                                    3

// rssgt_rngUserCorrectionImportExportDecimalSeparator
#define RSSGT_VAL_DECIMAL_SEPARATOR_DOT                                     0
#define RSSGT_VAL_DECIMAL_SEPARATOR_COMMA                                   1

// rssgt_rngUserCorrectionImportExportMode
#define RSSGT_VAL_IMPORT                                                    0
#define RSSGT_VAL_EXPORT                                                    1

// rssgt_rngConnectorImpedance
#define RSSGT_VAL_CONN_IMPEDANCE_G50                                        0
#define RSSGT_VAL_CONN_IMPEDANCE_G10K                                       1

// rssgt_rngDigitalPredistortionLevelReference
#define RSSGT_VAL_DPD_LEVEL_REFERENCE_BDPD                                  0
#define RSSGT_VAL_DPD_LEVEL_REFERENCE_ADPD                                  1
#define RSSGT_VAL_DPD_LEVEL_REFERENCE_SDPD                                  2

// rssgt_rngDigitalPredistortionShaping
#define RSSGT_VAL_DPD_SHAPING_TABLE                                         0
#define RSSGT_VAL_DPD_SHAPING_POLYNOMIAL                                    1
#define RSSGT_VAL_DPD_SHAPING_NORMALIZED                                    2

// rssgt_rngDigitalPredistortionInterpolation
#define RSSGT_VAL_DPD_INTERPOLATION_OFF                                     0
#define RSSGT_VAL_DPD_INTERPOLATION_LINEAR                                  1
#define RSSGT_VAL_DPD_INTERPOLATION_POWER                                   2

// rssgt_rngIQOutputAnalogType
#define RSSGT_VAL_IQ_OUTPUT_ANALOG_TYPE_SINGLE                              0
#define RSSGT_VAL_IQ_OUTPUT_ANALOG_TYPE_DIFFERENTIAL                        1

// rssgt_rngIQOutputAnalogMode
#define RSSGT_VAL_IQ_OUTPUT_ANALOG_MODE_FIXED                               0
#define RSSGT_VAL_IQ_OUTPUT_ANALOG_MODE_VARIABLE                            1

// rssgt_rngEnvelopeTrackingVoltageAdaptation
#define RSSGT_VAL_ENVELOPE_VOLTAGE_ADAPTATION_AUTO                          0
#define RSSGT_VAL_ENVELOPE_VOLTAGE_ADAPTATION_POWER                         1
#define RSSGT_VAL_ENVELOPE_VOLTAGE_ADAPTATION_MANUAL                        2

// rssgt_rngEnvelopeTrackingeTrackInterfaceType
#define RSSGT_VAL_ETRACK_INTERFACE_TYPE_USER                                0
#define RSSGT_VAL_ETRACK_INTERFACE_TYPE_ET1V2                               1
#define RSSGT_VAL_ETRACK_INTERFACE_TYPE_ET1V5                               2
#define RSSGT_VAL_ETRACK_INTERFACE_TYPE_ET2V0                               3

// rssgt_rngEnvelopeTrackingVoltageReference
#define RSSGT_VAL_ENVELOPE_VOLTAGE_REFERENCE_VCC                            0
#define RSSGT_VAL_ENVELOPE_VOLTAGE_REFERENCE_VOUT                           1

// rssgt_rngEnvelopeTrackingTermination
#define RSSGT_VAL_ENVELOPE_TRACKING_TERMINATION_GROUND                      0
#define RSSGT_VAL_ENVELOPE_TRACKING_TERMINATION_WIRE                        1

// rssgt_rngEnvelopeTrackingShaping
#define RSSGT_VAL_ENVELOPE_SHAPING_OFF                                      0
#define RSSGT_VAL_ENVELOPE_SHAPING_LINEAR_VOLTAGE                           1
#define RSSGT_VAL_ENVELOPE_SHAPING_LINEAR_POWER                             2
#define RSSGT_VAL_ENVELOPE_SHAPING_DETROUGHING                              3
#define RSSGT_VAL_ENVELOPE_SHAPING_FROM_TABLE                               4
#define RSSGT_VAL_ENVELOPE_SHAPING_FROM_POLYNOMIAL                          5

// rssgt_rngEnvelopeTrackingDetroughingFunction
#define RSSGT_VAL_ENVELOPE_DETROUGHING_FUNCTION_F1                          1
#define RSSGT_VAL_ENVELOPE_DETROUGHING_FUNCTION_F2                          2
#define RSSGT_VAL_ENVELOPE_DETROUGHING_FUNCTION_F3                          3

// rssgt_rngEnvelopeTrackingShapingInterpolation
#define RSSGT_VAL_ENVELOPE_SHAPING_INTERPOLATION_OFF                        0
#define RSSGT_VAL_ENVELOPE_SHAPING_INTERPOLATION_LINEAR_VOLTAGE             1
#define RSSGT_VAL_ENVELOPE_SHAPING_INTERPOLATION_LINEAR_POWER               2

// rssgt_rngEvenlopeTrackingShapingScale
#define RSSGT_VAL_ENVELOPE_SHAPING_SCALE_POWER                              0
#define RSSGT_VAL_ENVELOPE_SHAPING_SCALE_VOLTAGE                            1

// rssgt_rngTriggerNextSour
#define RSSGT_VAL_TRIGGER_SOURCE_NEXT                                       1

// rssgt_rngSystemGPIBLineTerminator
#define RSSGT_VAL_GPIB_LINE_TERM_STANDARD                                   0
#define RSSGT_VAL_GPIB_LINE_TERM_EOI                                        1

// rssgt_rngARBMultisegmentLevel
#define RSSGT_VAL_ARB_LEVEL_MODE_HIGHEST                                    1

// rssgt_rngIQOutputAnalogDisplayPowerVia
#define RSSGT_VAL_DISPLAY_VIA_PEP                                           0
#define RSSGT_VAL_DISPLAY_VIA_LEVEL                                         1

// rssgt_rngBBSystemConfiguration
#define RSSGT_VAL_SYSTEM_CONFIGURATION_STANDARD                             0
#define RSSGT_VAL_SYSTEM_CONFIGURATION_ARB_FOR_ET                           1

// rssgt_rngPowerUnit
#define RSSGT_VAL_SENSE_POWER_UNIT_DBM                                      0
#define RSSGT_VAL_SENSE_POWER_UNIT_DBUV                                     1
#define RSSGT_VAL_SENSE_POWER_UNIT_WATT                                     2

// rssgt_rngPowerSource
#define RSSGT_VAL_SENSE_POWER_SOURCE_RF                                     0
#define RSSGT_VAL_SENSE_POWER_SOURCE_USER                                   1

// rssgt_rngPowerDisplayPermanent
#define RSSGT_VAL_SENSE_POWER_DISPLAY_AVERAGE                               0
#define RSSGT_VAL_SENSE_POWER_DISPLAY_PEAK                                  1

// rssgt_rngPowerSPCSensorSelect
#define RSSGT_VAL_POWER_CONTROL_SENS1                                       1
#define RSSGT_VAL_POWER_CONTROL_SENS2                                       2
#define RSSGT_VAL_POWER_CONTROL_SENS3                                       3
#define RSSGT_VAL_POWER_CONTROL_SENS4                                       4

// rssgt_rngPowerFilterMode
#define RSSGT_VAL_SENSE_POWER_FILTER_TYPE_AUTO                              0
#define RSSGT_VAL_SENSE_POWER_FILTER_TYPE_USER                              1
#define RSSGT_VAL_SENSE_POWER_FILTER_TYPE_NSR                               2

// rssgt_rngPowerBasebandSource
#define RSSGT_VAL_POWER_BB_SOURCE_BBA                                       0
#define RSSGT_VAL_POWER_BB_SOURCE_BBB                                       1
#define RSSGT_VAL_POWER_BB_SOURCE_BBC                                       2
#define RSSGT_VAL_POWER_BB_SOURCE_BBD                                       3
#define RSSGT_VAL_POWER_BB_SOURCE_BBINA                                     4
#define RSSGT_VAL_POWER_BB_SOURCE_BBINB                                     5
#define RSSGT_VAL_POWER_BB_SOURCE_FADINPA                                   6
#define RSSGT_VAL_POWER_BB_SOURCE_FADINPB                                   7
#define RSSGT_VAL_POWER_BB_SOURCE_FADINPC                                   8
#define RSSGT_VAL_POWER_BB_SOURCE_FADINPD                                   9
#define RSSGT_VAL_POWER_BB_SOURCE_FADOUTA                                   10
#define RSSGT_VAL_POWER_BB_SOURCE_FADOUTB                                   11
#define RSSGT_VAL_POWER_BB_SOURCE_FADOUTC                                   12
#define RSSGT_VAL_POWER_BB_SOURCE_FADOUTD                                   13
#define RSSGT_VAL_POWER_BB_SOURCE_AWGNA                                     14
#define RSSGT_VAL_POWER_BB_SOURCE_AWGNB                                     15
#define RSSGT_VAL_POWER_BB_SOURCE_AWGNC                                     16
#define RSSGT_VAL_POWER_BB_SOURCE_AWGND                                     17
#define RSSGT_VAL_POWER_BB_SOURCE_STREAMA                                   18
#define RSSGT_VAL_POWER_BB_SOURCE_STREAMB                                   19
#define RSSGT_VAL_POWER_BB_SOURCE_STREAMC                                   20
#define RSSGT_VAL_POWER_BB_SOURCE_STREAMD                                   21

// rssgt_rngPowerBasebandAcquisition
#define RSSGT_VAL_POWER_BB_ACQ_NOM                                          0
#define RSSGT_VAL_POWER_BB_ACQ_CONT                                         1
#define RSSGT_VAL_POWER_BB_ACQ_GAT                                          2
#define RSSGT_VAL_POWER_BB_ACQ_MGAT                                         3

// rssgt_rngPowerBasebandGateSource
#define RSSGT_VAL_POWER_BB_GATE_SOURCE_NONE                                 0
#define RSSGT_VAL_POWER_BB_GATE_SOURCE_MARK1                                1
#define RSSGT_VAL_POWER_BB_GATE_SOURCE_MARK2                                2
#define RSSGT_VAL_POWER_BB_GATE_SOURCE_MARK3                                3
#define RSSGT_VAL_POWER_BB_GATE_SOURCE_MGAT                                 4

// rssgt_rngPowerBasebandOutput
#define RSSGT_VAL_POWER_BASEBAND_OUTPUT_RFA                                 0
#define RSSGT_VAL_POWER_BASEBAND_OUTPUT_RFB                                 1
#define RSSGT_VAL_POWER_BASEBAND_OUTPUT_IQOUT1                              2
#define RSSGT_VAL_POWER_BASEBAND_OUTPUT_IQOUT2                              3
#define RSSGT_VAL_POWER_BASEBAND_OUTPUT_BBMM1                               4
#define RSSGT_VAL_POWER_BASEBAND_OUTPUT_BBMM2                               5

// rssgt_rngPowerBasebandRunMode
#define RSSGT_VAL_POWER_BASEBAND_RMODE_SINGLE                               0
#define RSSGT_VAL_POWER_BASEBAND_RMODE_AUTO                                 1

// rssgt_rngPowerServoingSensorSelect
#define RSSGT_VAL_POWER_CONTROL_SENSUNDEF                                   5
/* END GENERATE */
	
// rssgt_rngDistortionType
#define RSSGT_VAL_DISTORTION_AM_AM 0
#define RSSGT_VAL_DISTORTION_AM_PM 1

	
#define RSSGT_ARB_APPEND_SEGMENT_NEXT    									0
#define RSSGT_ARB_APPEND_SEGMENT_BLANK   									1
#define RSSGT_ARB_APPEND_SEGMENT_ENDLESS 									2
#define RSSGT_ARB_APPEND_SEGMENT_SEG0    									3
#define RSSGT_ARB_APPEND_SEGMENT_SEG1    									4
#define RSSGT_ARB_APPEND_SEGMENT_SEG2    									5
#define RSSGT_ARB_APPEND_SEGMENT_SEG3    									6
#define RSSGT_ARB_APPEND_SEGMENT_SEG4    									7
#define RSSGT_ARB_APPEND_SEGMENT_SEG5    									8
#define RSSGT_ARB_APPEND_SEGMENT_SEG6    									9
#define RSSGT_ARB_APPEND_SEGMENT_SEG7    									10
#define RSSGT_ARB_APPEND_SEGMENT_SEG8    									11
#define RSSGT_ARB_APPEND_SEGMENT_SEG9    									12
#define RSSGT_ARB_APPEND_SEGMENT_SEG10   									13
#define RSSGT_ARB_APPEND_SEGMENT_SEG11   									14
#define RSSGT_ARB_APPEND_SEGMENT_SEG12   									15
#define RSSGT_ARB_APPEND_SEGMENT_SEG13   									16
#define RSSGT_ARB_APPEND_SEGMENT_SEG14   									17
#define RSSGT_ARB_APPEND_SEGMENT_SEG15   									18
#define RSSGT_ARB_APPEND_SEGMENT_SEG16   									19
#define RSSGT_ARB_APPEND_SEGMENT_SEG17   									20
#define RSSGT_ARB_APPEND_SEGMENT_SEG18   									21
#define RSSGT_ARB_APPEND_SEGMENT_SEG19   									22
#define RSSGT_ARB_APPEND_SEGMENT_SEG20   									23
#define RSSGT_ARB_APPEND_SEGMENT_SEG21   									24
#define RSSGT_ARB_APPEND_SEGMENT_SEG22   									25
#define RSSGT_ARB_APPEND_SEGMENT_SEG23   									26
#define RSSGT_ARB_APPEND_SEGMENT_SEG24   									27
#define RSSGT_ARB_APPEND_SEGMENT_SEG25   									28
#define RSSGT_ARB_APPEND_SEGMENT_SEG26   									29
#define RSSGT_ARB_APPEND_SEGMENT_SEG27   									30
#define RSSGT_ARB_APPEND_SEGMENT_SEG28   									31
#define RSSGT_ARB_APPEND_SEGMENT_SEG29   									32
#define RSSGT_ARB_APPEND_SEGMENT_SEG30   									33
#define RSSGT_ARB_APPEND_SEGMENT_SEG31   									34
	
#define RSSGT_REGISTER_OPERATION    0
#define RSSGT_REGISTER_QUESTIONABLE 1
#define RSSGT_REGISTER_ENABLE 		2
#define RSSGT_REGISTER_NTR    		3
#define RSSGT_REGISTER_PTR    		4
	
#define RSSGT_REGISTER_COND   0
#define RSSGT_REGISTER_EVENT  1
	
	
/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/
ViStatus _VI_FUNC rssgt_init (ViRsrc resourceName, ViBoolean IDQuery,
                              ViBoolean resetDevice, ViSession* instrumentHandle);
ViStatus _VI_FUNC rssgt_InitWithOptions (ViRsrc resourceName, ViBoolean IDQuery,
                                         ViBoolean resetDevice,
                                         ViString optionString,
                                         ViSession* instrumentHandle);
ViStatus _VI_FUNC rssgt_UseFastSettings (ViSession instrumentHandle,
                                         ViBoolean enableFast,
                                         ViBoolean enableAsynchronous);
ViStatus _VI_FUNC rssgt_GetFastSettings (ViSession instrumentHandle,
                                         ViBoolean* enableFast,
                                         ViBoolean* enableAsynchronous);
ViStatus _VI_FUNC rssgt_FastSync (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgt_ConfigureOperationMode (ViSession instrumentHandle,
                                                ViInt32 operationMode);
ViStatus _VI_FUNC rssgt_SetFrequencyAndLevel (ViSession instrumentHandle,
                                              ViReal64 frequency, ViReal64 level);
ViStatus _VI_FUNC rssgt_PowerServoingSet (ViSession instrumentHandle,
                                          ViReal64 targetPow, ViInt32* result);
ViStatus _VI_FUNC rssgt_SelectActivePath (ViSession instrumentHandle, ViInt32 path);
ViStatus _VI_FUNC rssgt_ConfigureARB (ViSession instrumentHandle, ViString waveform,
                                      ViReal64 clockFrequency,
                                      ViBoolean ARBEnabled);
ViStatus _VI_FUNC rssgt_ConfigureARBOffsets (ViSession instrumentHandle,
                                             ViReal64 frequencyOffset,
                                             ViReal64 phaseOffset);
ViStatus _VI_FUNC rssgt_WriteARBData (ViSession instrumentHandle,
                                      ViString waveformFilename,
                                      ViInt32 binaryBlockLength,
                                      ViChar _VI_FAR data[]);
ViStatus _VI_FUNC rssgt_ReadARBFileTag (ViSession instrumentHandle,
                                        ViString waveformFilename, ViString tag,
                                        ViInt32 bufferSize,
                                        ViChar _VI_FAR buffer[]);
ViStatus _VI_FUNC rssgt_ReadARBTag (ViSession instrumentHandle, ViString tag,
                                    ViInt32 bufferSize, ViChar _VI_FAR buffer[]);
ViStatus _VI_FUNC rssgt_ARBSetToDefault (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgt_ConfigureARBFileClock (ViSession instrumentHandle,
                                               ViString waveformFilename,
                                               ViReal64 clock);
ViStatus _VI_FUNC rssgt_ConfigureARBMultisegmentBlank (ViSession instrumentHandle,
                                                       ViReal64 sampleCount,
                                                       ViReal64 clockRate);
ViStatus _VI_FUNC rssgt_ConfigureARBMultisegmentLevelClockMarker
             (ViSession instrumentHandle, ViInt32 level, ViInt32 clock,
              ViReal64 userClockRate);
ViStatus _VI_FUNC rssgt_ARBMultisegmentAppendSegmentToPlayList
             (ViSession instrumentHandle, ViBoolean state, ViInt32 segment,
              ViInt32 repetition, ViInt32 next);
ViStatus _VI_FUNC rssgt_ARBMultisegmentFileComment (ViSession instrumentHandle,
                                                    ViString comment);
ViStatus _VI_FUNC rssgt_ARBMultisegmentCatalog (ViSession instrumentHandle,
                                                ViInt32 arraySize,
                                                ViChar _VI_FAR catalog[]);
ViStatus _VI_FUNC rssgt_ARBMultisegmentSegmentCatalog (ViSession instrumentHandle,
                                                       ViInt32 arraySize,
                                                       ViChar _VI_FAR catalog[]);
ViStatus _VI_FUNC rssgt_ARBMultisegmentCreate (ViSession instrumentHandle,
                                               ViString file);
ViStatus _VI_FUNC rssgt_ARBMultisegmentLoadFromConfigurationFile
             (ViSession instrumentHandle, ViString file);
ViStatus _VI_FUNC rssgt_ARBMultisegmentConfigurationFile (ViSession instrumentHandle,
                                                          ViString file);
ViStatus _VI_FUNC rssgt_ARBMultisegmentConfigurationFileDelete
             (ViSession instrumentHandle, ViString file);
ViStatus _VI_FUNC rssgt_ARBMultisegmentConfigurationFileAppend
             (ViSession instrumentHandle, ViString file);
ViStatus _VI_FUNC rssgt_ARBMultiCarrierSetToDefault (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgt_ConfigureARBMultiCarrier (ViSession instrumentHandle,
                                                  ViInt32 mode,
                                                  ViInt32 numberOfCarriers,
                                                  ViReal64 carrierSpacing,
                                                  ViInt32 crestFactorMode,
                                                  ViInt32 signalPeriodMode,
                                                  ViReal64 signalPeriod,
                                                  ViInt32 powerReference);
ViStatus _VI_FUNC rssgt_ConfigureARBMultiCarrierClipping (ViSession instrumentHandle,
                                                          ViBoolean clipping,
                                                          ViReal64 targetCrestFactor,
                                                          ViReal64 filterCutOffFrequency);
ViStatus _VI_FUNC rssgt_ARBMultiCarrierTableNumberOfCarriers
             (ViSession instrumentHandle, ViInt32 numberOfCarriers);
ViStatus _VI_FUNC rssgt_ARBMultiCarrierTableInputWaveformFile
             (ViSession instrumentHandle, ViString file);
ViStatus _VI_FUNC rssgt_ARBMultiCarrierTableApply (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgt_ConfigureARBMultiCarrierTableCarrier
             (ViSession instrumentHandle, ViInt32 carrierStart, ViInt32 carrierStop,
              ViBoolean carrierState);
ViStatus _VI_FUNC rssgt_ConfigureARBMultiCarrierTable (ViSession instrumentHandle,
                                                       ViReal64 gainStart,
                                                       ViReal64 gainStep,
                                                       ViReal64 phaseStart,
                                                       ViReal64 phaseStep,
                                                       ViReal64 delayStart,
                                                       ViReal64 delayStep);
ViStatus _VI_FUNC rssgt_ConfigureARBMultiCarr (ViSession instrumentHandle,
                                               ViInt32 carrier, ViBoolean state,
                                               ViReal64 frequency, ViReal64 gain,
                                               ViReal64 phase, ViReal64 delay,
                                               ViString file);
ViStatus _VI_FUNC rssgt_ConfigureARBMultiCarrierStoreFast
             (ViSession instrumentHandle, ViBoolean storeFast);
ViStatus _VI_FUNC rssgt_ARBMultiCarrierFileCatalog (ViSession instrumentHandle,
                                                    ViInt32 arraySize,
                                                    ViChar _VI_FAR catalog[]);
ViStatus _VI_FUNC rssgt_ARBMultiCarrierFileLoad (ViSession instrumentHandle,
                                                 ViString file);
ViStatus _VI_FUNC rssgt_ARBMultiCarrierFileStore (ViSession instrumentHandle,
                                                  ViString file);
ViStatus _VI_FUNC rssgt_ConfigureARBSineTestSignal (ViSession instrumentHandle,
                                                    ViReal64 frequency,
                                                    ViInt32 samples,
                                                    ViReal64 phaseOffset);
ViStatus _VI_FUNC rssgt_ConfigureARBSineTestSignalName (ViSession instrumentHandle,
                                                        ViString fileName);
ViStatus _VI_FUNC rssgt_ARBSineTestSignalGenerate (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgt_ConfigureARBRectTestSignal (ViSession instrumentHandle,
                                                    ViReal64 frequency,
                                                    ViInt32 samples,
                                                    ViReal64 amplitude,
                                                    ViReal64 offsetDC);
ViStatus _VI_FUNC rssgt_ConfigureARBRectTestSignalName (ViSession instrumentHandle,
                                                        ViString fileName);
ViStatus _VI_FUNC rssgt_ARBRectTestSignalGenerate (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgt_ConfigureARBCIQTestSignal (ViSession instrumentHandle,
                                                   ViReal64 iValue,
                                                   ViReal64 qValue);
ViStatus _VI_FUNC rssgt_ConfigureARBCIQTestSignalName (ViSession instrumentHandle,
                                                       ViString fileName);
ViStatus _VI_FUNC rssgt_ARBCIQTestSignalGenerate (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgt_ARBExecuteTrigger (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgt_ARBTriggerStatus (ViSession instrumentHandle,
                                          ViChar _VI_FAR status[],
                                          ViInt32 arraySize);
ViStatus _VI_FUNC rssgt_ConfigureARBTriggerMode (ViSession instrumentHandle,
                                                 ViInt32 mode);
ViStatus _VI_FUNC rssgt_ConfigureARBTriggerSource (ViSession instrumentHandle,
                                                   ViInt32 source);
ViStatus _VI_FUNC rssgt_ConfigureARBTriggerSingle (ViSession instrumentHandle,
                                                   ViInt32 signalDurationUnit,
                                                   ViInt32 signalDuration);
ViStatus _VI_FUNC rssgt_ConfigureARBMarkerMode (ViSession instrumentHandle,
                                                ViInt32 marker, ViInt32 mode);
ViStatus _VI_FUNC rssgt_ConfigureARBMarkerDivider (ViSession instrumentHandle,
                                                   ViInt32 marker, ViInt32 divider);
ViStatus _VI_FUNC rssgt_ConfigureARBMarkerDelay (ViSession instrumentHandle,
                                                 ViInt32 marker, ViInt32 delay,
                                                 ViBoolean fixMarkerDelay);
ViStatus _VI_FUNC rssgt_ConfigureARBClockSource (ViSession instrumentHandle,
                                                 ViInt32 source);
ViStatus _VI_FUNC rssgt_ConfigureAWGNEnabled (ViSession instrumentHandle,
                                              ViBoolean AWGNEnabled);
ViStatus _VI_FUNC rssgt_ConfigureAWGNMode (ViSession instrumentHandle,
                                           ViInt32 mode);
ViStatus _VI_FUNC rssgt_ConfigureAWGNNoiseOnly (ViSession instrumentHandle,
                                                ViReal64 systemBandwidth,
                                                ViReal64 bandwidthRatio);
ViStatus _VI_FUNC rssgt_ConfigureAWGNAdditiveNoiseDisplayMode
             (ViSession instrumentHandle, ViInt32 displayMode);
ViStatus _VI_FUNC rssgt_ConfigureFrequencyPhase (ViSession instrumentHandle,
                                                 ViReal64 frequency,
                                                 ViReal64 deltaPhase);
ViStatus _VI_FUNC rssgt_ResetDeltaPhaseDisplay (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgt_ConfigureLocalOscillatorSource (ViSession instrumentHandle,
                                                        ViInt32 source);
ViStatus _VI_FUNC rssgt_ConfigureReferenceOscillatorSource
             (ViSession instrumentHandle, ViInt32 source);
ViStatus _VI_FUNC rssgt_ConfigureReferenceOscillatorExternal
             (ViSession instrumentHandle, ViInt32 referenceInputFrequency,
              ViInt32 synchronisationBandwidth);
ViStatus _VI_FUNC rssgt_ConfigureReferenceOscillatorAdjustment
             (ViSession instrumentHandle, ViBoolean active, ViInt32 smallShift);
ViStatus _VI_FUNC rssgt_ConfigureLevelState (ViSession instrumentHandle,
                                             ViBoolean state);
ViStatus _VI_FUNC rssgt_ConfigureLevelSettings (ViSession instrumentHandle,
                                                ViInt32 mode,
                                                ViInt32 settingCharacteristic,
                                                ViReal64 level, ViReal64 limit);
ViStatus _VI_FUNC rssgt_QueryLevelRange (ViSession instrumentHandle,
                                         ViReal64* minimum, ViReal64* maximum);
ViStatus _VI_FUNC rssgt_ConfigureLevelPowerOn (ViSession instrumentHandle,
                                               ViInt32 state);
ViStatus _VI_FUNC rssgt_ConfigureLevelALC (ViSession instrumentHandle,
                                           ViInt32 state,
                                           ViInt32 detectorSensitivity);
ViStatus _VI_FUNC rssgt_QueryLevelAttenuatorRange (ViSession instrumentHandle,
                                                   ViReal64* minimum,
                                                   ViReal64* maximum);
ViStatus _VI_FUNC rssgt_ConfigureLevelAttenuatorSettings (ViSession instrumentHandle,
                                                          ViInt32 mode,
                                                          ViReal64 SATT,
                                                          ViInt32 RFOffMode);
ViStatus _VI_FUNC rssgt_ConfigureIQEnabled (ViSession instrumentHandle,
                                            ViBoolean enabled);
ViStatus _VI_FUNC rssgt_ConfigureIQImpairments (ViSession instrumentHandle,
                                                ViBoolean enabled, ViReal64 iOffset,
                                                ViReal64 qOffset,
                                                ViReal64 gainImbalance,
                                                ViReal64 quadratureOffset);
ViStatus _VI_FUNC rssgt_CreateNewEnvelopeTrackingShapingTable
             (ViSession instrumentHandle, ViString filename, ViInt32 arraySize,
              ViReal64 _VI_FAR vinVmax[], ViReal64 _VI_FAR vccVmax[]);
ViStatus _VI_FUNC rssgt_ConfigureEnvelopeTrackingShapingTableData
             (ViSession instrumentHandle, ViInt32 arraySize,
              ViReal64 _VI_FAR vinVmax[], ViReal64 _VI_FAR vccVmax[]);
ViStatus _VI_FUNC rssgt_ConfigureEnvelopeTrackingPolynomialCoefficients
             (ViSession instrumentHandle, ViInt32 arraySize,
              ViReal64 _VI_FAR polynomialCoefficients[]);
ViStatus _VI_FUNC rssgt_CreateNewDigitalPredistortionShapingTable
             (ViSession instrumentHandle, ViInt32 distortionType, ViString filename,
              ViInt32 arraySize, ViReal64 _VI_FAR pin[], ViReal64 _VI_FAR delta[]);
ViStatus _VI_FUNC rssgt_ConfigureDigitalPredistortionShapingTableData
             (ViSession instrumentHandle, ViInt32 distortionType, ViInt32 arraySize,
              ViReal64 _VI_FAR pin[], ViReal64 _VI_FAR delta[]);
ViStatus _VI_FUNC rssgt_ConfigureDigitalPredistortionPolynomialCoefficients
             (ViSession instrumentHandle, ViInt32 arraySize,
              ViReal64 _VI_FAR real[], ViReal64 _VI_FAR imaginary[]);
ViStatus _VI_FUNC rssgt_ConfigurePULMEnabled (ViSession instrumentHandle,
                                              ViBoolean enabled);
ViStatus _VI_FUNC rssgt_ConfigurePULMSource (ViSession instrumentHandle,
                                             ViInt32 source);
ViStatus _VI_FUNC rssgt_ConfigurePULM (ViSession instrumentHandle,
                                       ViInt32 pulseMode, ViReal64 pulsePeriod,
                                       ViReal64 pulseWidth,
                                       ViReal64 doublePulseWidth,
                                       ViReal64 doublePulseDelay);
ViStatus _VI_FUNC rssgt_ConfigureUserCorrectionFrequencies
             (ViSession instrumentHandle, ViInt32 arraySize,
              ViReal64 _VI_FAR frequencies[]);
ViStatus _VI_FUNC rssgt_ConfigureUserCorrectionPowers (ViSession instrumentHandle,
                                                       ViInt32 arraySize,
                                                       ViReal64 _VI_FAR powers[]);
ViStatus _VI_FUNC rssgt_ConfigurePowerMeasurementDisplay (ViSession instrumentHandle,
                                                          ViInt32 sensor,
                                                          ViBoolean permanent,
                                                          ViInt32 priority);
ViStatus _VI_FUNC rssgt_ConfigurePowerMeasurementZero (ViSession instrumentHandle,
                                                       ViInt32 sensor);
ViStatus _VI_FUNC rssgt_ConfigurePowerMeasurementSource (ViSession instrumentHandle,
                                                         ViInt32 sensor,
                                                         ViInt32 source);
ViStatus _VI_FUNC rssgt_ConfigurePowerMeasurement (ViSession instrumentHandle,
                                                   ViInt32 sensor,
                                                   ViBoolean levelOffsetState,
                                                   ViReal64 levelOffset,
                                                   ViInt32 filter,
                                                   ViBoolean SParameter,
                                                   ViBoolean logging);
ViStatus _VI_FUNC rssgt_ConfigurePowerMeasurementApertureTime
             (ViSession instrumentHandle, ViInt32 sensor, ViBoolean defaultTime,
              ViReal64 apertureTime);
ViStatus _VI_FUNC rssgt_ReadPowerMeasurement (ViSession instrumentHandle,
                                              ViInt32 sensor, ViReal64* level_Peak,
                                              ViReal64* level_Average);
ViStatus _VI_FUNC rssgt_SendSoftwareTrigger (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgt_Lock (ViSession instrumentHandle, ViInt32 requestID,
                              ViInt32* requestResult);
ViStatus _VI_FUNC rssgt_SystemProtect (ViSession instrumentHandle, ViInt32 level,
                                       ViBoolean enabled, ViInt32 key);
ViStatus _VI_FUNC rssgt_GetMemoryInformation (ViSession instrumentHandle,
                                              ViInt32* totalPhysicalMemory,
                                              ViInt32* applicationMemory,
                                              ViInt32* usedHeapMemory,
                                              ViInt32* availableHeapMemory);
ViStatus _VI_FUNC rssgt_MMEMoryCatalog (ViSession instrumentHandle,
                                        ViString directoryPath, ViInt32 arraySize,
                                        ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssgt_MMEMoryCatalogLength (ViSession instrumentHandle,
                                              ViString directoryPath,
                                              ViInt32* catalogLength);
ViStatus _VI_FUNC rssgt_MMEMoryChangeDirectory (ViSession instrumentHandle,
                                                ViString directoryName);
ViStatus _VI_FUNC rssgt_MMEMoryCopy (ViSession instrumentHandle,
                                     ViString sourcePath, ViString destinationPath);
ViStatus _VI_FUNC rssgt_MMEMoryBlockDataWrite (ViSession instrumentHandle,
                                               ViString fileName,
                                               ViInt32 binaryBlockLength,
                                               ViChar _VI_FAR binaryBlockData[]);
ViStatus _VI_FUNC rssgt_MMEMoryBlockDataRead (ViSession instrumentHandle,
                                              ViString fileName,
                                              ViInt32 binaryBlockLength,
                                              ViChar _VI_FAR binaryBlockData[],
                                              ViUInt32* bytesRead);
ViStatus _VI_FUNC rssgt_MMEMoryReadToFileFromInstrument (ViSession instrumentHandle,
                                                         ViString source,
                                                         ViString destination);
ViStatus _VI_FUNC rssgt_MMEMoryWriteFromFileToInstrument (ViSession instrumentHandle,
                                                          ViString source,
                                                          ViString destination);
ViStatus _VI_FUNC rssgt_MMEMoryDirectoryCatalog (ViSession instrumentHandle,
                                                 ViString directoryPath,
                                                 ViInt32 arraySize,
                                                 ViChar _VI_FAR catalogList[]);
ViStatus _VI_FUNC rssgt_MMEMoryDirectoryCatalogLength (ViSession instrumentHandle,
                                                       ViString directoryPath,
                                                       ViInt32* catalogLength);
ViStatus _VI_FUNC rssgt_MMEMoryDelete (ViSession instrumentHandle,
                                       ViString fileName);
ViStatus _VI_FUNC rssgt_MMEMoryLoad (ViSession instrumentHandle,
                                     ViInt32 instrumentSetting, ViString fileName);
ViStatus _VI_FUNC rssgt_MMEMoryMakeDirectory (ViSession instrumentHandle,
                                              ViString directoryName);
ViStatus _VI_FUNC rssgt_MMEMoryMove (ViSession instrumentHandle,
                                     ViString fileSource, ViString fileDestination);
ViStatus _VI_FUNC rssgt_MMEMoryRemoveDirectory (ViSession instrumentHandle,
                                                ViString directoryName);
ViStatus _VI_FUNC rssgt_MMEMoryStore (ViSession instrumentHandle,
                                      ViInt32 instrumentSetting, ViString fileName);
ViStatus _VI_FUNC rssgt_DiagnosticTestPointVoltages (ViSession instrumentHandle,
                                                     ViString testPointName,
                                                     ViReal64* measuredVoltage);
ViStatus _VI_FUNC rssgt_SetRegister (ViSession instrumentHandle,
                                     ViInt32 registerGroup, ViInt32 registerType,
                                     ViInt32 value);
ViStatus _VI_FUNC rssgt_GetRegister (ViSession instrumentHandle,
                                     ViInt32 registerGroup, ViInt32 registerType,
                                     ViInt32* value);
ViStatus _VI_FUNC rssgt_STATusPRESet (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgt_SetDate (ViSession instrumentHandle, ViInt32 year,
                                 ViInt32 month, ViInt32 day);
ViStatus _VI_FUNC rssgt_GetDate (ViSession instrumentHandle, ViInt32* year,
                                 ViInt32* month, ViInt32* day);
ViStatus _VI_FUNC rssgt_SetTime (ViSession instrumentHandle, ViInt32 hour,
                                 ViInt32 minute, ViInt32 second);
ViStatus _VI_FUNC rssgt_GetTime (ViSession instrumentHandle, ViInt32* hour,
                                 ViInt32* minute, ViInt32* second);
ViStatus _VI_FUNC rssgt_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgt_revision_query (ViSession instrumentHandle,
                                        ViChar _VI_FAR instrumentDriverRevision[],
                                        ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rssgt_error_query (ViSession instrumentHandle, ViInt32* errorCode,
                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssgt_error_message (ViSession instrumentHandle,
                                       ViStatus errorCode,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssgt_enumerate_pcie_devices (ViInt32 vendorId, ViInt32 deviceId,
                                                ViInt32 _VI_FAR serialNumbers[],
                                                ViInt32* serialNumbersCount);
ViStatus _VI_FUNC rssgt_enumerate_socket_devices (ViPString* info,
                                                  ViInt32* infoCount);
ViStatus _VI_FUNC rssgt_ClearStatus (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgt_IDQueryResponse (ViSession instrumentHandle,
                                         ViChar _VI_FAR IDQueryResponse[]);
ViStatus _VI_FUNC rssgt_ProcessAllPreviousCommands (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgt_QueryOPC (ViSession instrumentHandle, ViInt32* OPC);
ViStatus _VI_FUNC rssgt_GetError (ViSession instrumentHandle, ViStatus* code,
                                  ViInt32 bufferSize, ViChar _VI_FAR description[]);
ViStatus _VI_FUNC rssgt_ClearError (ViSession instrumentHandle);
ViStatus _VI_FUNC rssgt_WriteInstrData (ViSession instrumentHandle,
                                        ViString writeBuffer);
ViStatus _VI_FUNC rssgt_ReadInstrData (ViSession instrumentHandle,
                                       ViInt32 numberOfBytesToRead,
                                       ViChar _VI_FAR readBuffer[],
                                       ViUInt32* numBytesRead);
ViStatus _VI_FUNC rssgt_SetAttributeViInt32 (ViSession instrumentHandle,
                                             ViString repeatedCapabilityName,
                                             ViAttr attributeID,
                                             ViInt32 attributeValue);
ViStatus _VI_FUNC rssgt_SetAttributeViInt64 (ViSession instrumentHandle,
                                             ViString repeatedCapabilityName,
                                             ViAttr attributeID,
                                             ViInt64 attributeValue);
ViStatus _VI_FUNC rssgt_SetAttributeViReal64 (ViSession instrumentHandle,
                                              ViString repeatedCapabilityName,
                                              ViAttr attributeID,
                                              ViReal64 attributeValue);
ViStatus _VI_FUNC rssgt_SetAttributeViString (ViSession instrumentHandle,
                                              ViString repeatedCapabilityName,
                                              ViAttr attributeID,
                                              ViString attributeValue);
ViStatus _VI_FUNC rssgt_SetAttributeViBoolean (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViAttr attributeID,
                                               ViBoolean attributeValue);
ViStatus _VI_FUNC rssgt_SetAttributeViSession (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViAttr attributeID,
                                               ViSession attributeValue);
ViStatus _VI_FUNC rssgt_SetAttributeFlags (ViSession instrumentHandle,
                                           ViAttr attributeID, ViInt32 flags);
ViStatus _VI_FUNC rssgt_GetAttributeViInt32 (ViSession instrumentHandle,
                                             ViString repeatedCapabilityName,
                                             ViAttr attributeID,
                                             ViInt32* attributeValue);
ViStatus _VI_FUNC rssgt_GetAttributeViInt64 (ViSession instrumentHandle,
                                             ViString repeatedCapabilityName,
                                             ViAttr attributeID,
                                             ViInt64* attributeValue);
ViStatus _VI_FUNC rssgt_GetAttributeViReal64 (ViSession instrumentHandle,
                                              ViString repeatedCapabilityName,
                                              ViAttr attributeID,
                                              ViReal64* attributeValue);
ViStatus _VI_FUNC rssgt_GetAttributeViString (ViSession instrumentHandle,
                                              ViString repeatedCapabilityName,
                                              ViAttr attributeID,
                                              ViInt32 bufferSize,
                                              ViChar _VI_FAR attributeValue[]);
ViStatus _VI_FUNC rssgt_GetAttributeViBoolean (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViAttr attributeID,
                                               ViBoolean* attributeValue);
ViStatus _VI_FUNC rssgt_GetAttributeViSession (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViAttr attributeID,
                                               ViSession* attributeValue);
ViStatus _VI_FUNC rssgt_GetAttributeFlags (ViSession instrumentHandle,
                                           ViAttr attributeID, ViInt32* flags);
ViStatus _VI_FUNC rssgt_CheckAttributeViInt32 (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViAttr attributeID,
                                               ViInt32 attributeValue);
ViStatus _VI_FUNC rssgt_CheckAttributeViReal64 (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViAttr attributeID,
                                                ViReal64 attributeValue);
ViStatus _VI_FUNC rssgt_CheckAttributeViString (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViAttr attributeID,
                                                ViString attributeValue);
ViStatus _VI_FUNC rssgt_CheckAttributeViBoolean (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViAttr attributeID,
                                                 ViBoolean attributeValue);
ViStatus _VI_FUNC rssgt_CheckAttributeViSession (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViAttr attributeID,
                                                 ViSession attributeValue);
ViStatus _VI_FUNC rssgt_close (ViSession instrumentHandle);

void _VI_FUNC rssgt_openLog(ViInt32 historydepth, ViBoolean enablewrap, ViBoolean stoponerror);
void _VI_FUNC rssgt_closeLog(void);
ViStatus _VI_FUNC rssgt_saveLog(const ViString filename);
void _VI_FUNC rssgt_setMaxLogCallDepth(ViUInt32 depth);
void _VI_FUNC rssgt_setLogWrapStartIndex(ViUInt32 wrapstartindex);


/****************************************************************************
 *------------------------ Instrument functions ----------------------------*
 ****************************************************************************/




/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSSGT_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSSGT_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSSGT_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSSGT_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSSGT_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)

#define RSSGT_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSSGT_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSSGT_ERRMSG_INCORRECT_STATE     "Instrument in incorrect state"
#define RSSGT_ERRMSG_INCORRECT_RESPONSE      "Response incorrect; report problem to R&S support!"
#define RSSGT_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"

#define RSSGT_WARNING_SMALL_BUFFER             (VI_WARNING_INSTR_OFFSET + 0xF1L)

#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_OFFSET                       (_VI_ERROR+0x3FFC0900L)
#define VI_WARNING_INSTR_OFFSET                     (0x3FFC0900L)


#define VI_ERROR_INSTR_FILE_OPEN                    (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE                   (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE        (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER8                   (_VI_ERROR+0x3FFC0808L)
#define VI_ERROR_INSTR_PARAMETER9                   (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10                  (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11                  (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12                  (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13                  (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14                  (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15                  (_VI_ERROR+0x3FFC080FL)

#define RSSGT_ERROR_INSTRUMENT_ERROR                (VI_ERROR_INSTR_OFFSET + 0xF0L)
/* Add instrument driver specific error codes here */

#define RSSGT_ERROR_INVALID_CONFIGURATION           (VI_ERROR_INSTR_OFFSET + 0xF1L)
#define RSSGT_ERROR_INSTRUMENT_OPTION               (VI_ERROR_INSTR_OFFSET + 0xF2L)
#define RSSGT_ERROR_INSTRUMENT_NSUP_MODEL           (VI_ERROR_INSTR_OFFSET + 0xF3L)
#define RSSGT_ERROR_SETTINGS_CONFLICT               (VI_ERROR_INSTR_OFFSET + 0xF4L)
#define RSSGT_ERROR_CALIBRATION_FAILED              (VI_ERROR_INSTR_OFFSET + 0xF5L)
#define RSSGT_ERROR_INSTRUMENT_DATA_NOT_AVAILABLE   (VI_ERROR_INSTR_OFFSET + 0xF6L)
/* Add instrument driver specific warning codes here */
#define RSSGS_WARNING_SMALL_BUFFER                  (VI_WARNING_INSTR_OFFSET + 0xF1L)


#define RSSGT_ERROR_CODES_AND_MSGS \
    {RSSGT_WARN_MEASURE_UNCALIBRATED,  RSSGT_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSSGT_WARN_OVER_RANGE,            RSSGT_WARNMSG_OVER_RANGE},\
    {RSSGT_ERROR_INCORRECT_STATE ,   RSSGT_ERRMSG_INCORRECT_STATE },\
    {RSSGT_ERROR_INCORRECT_RESPONSE,     RSSGT_ERRMSG_INCORRECT_RESPONSE},\
    {RSSGT_ERROR_MAX_TIME_EXCEEDED,    RSSGT_ERRMSG_MAX_TIME_EXCEEDED},\
    {VI_SUCCESS, "No Error"},\
    { VI_WARN_NSUP_ID_QUERY, "WARNING: ID Query not supported" },\
    { VI_WARN_NSUP_RESET, "WARNING: Reset not supported" },\
    { VI_WARN_NSUP_SELF_TEST, "WARNING: Self-test not supported" },\
    { VI_WARN_NSUP_ERROR_QUERY, "WARNING: Error Query not supported" },\
    { VI_WARN_NSUP_REV_QUERY, "WARNING: Revision Query not supported" },\
    { VI_ERROR_PARAMETER1, "ERROR: Parameter 1 out of range" },\
    { VI_ERROR_PARAMETER2, "ERROR: Parameter 2 out of range" },\
    { VI_ERROR_PARAMETER3, "ERROR: Parameter 3 out of range" },\
    { VI_ERROR_PARAMETER4, "ERROR: Parameter 4 out of range" },\
    { VI_ERROR_PARAMETER5, "ERROR: Parameter 5 out of range" },\
    { VI_ERROR_PARAMETER6, "ERROR: Parameter 6 out of range" },\
    { VI_ERROR_PARAMETER7, "ERROR: Parameter 7 out of range" },\
    { VI_ERROR_PARAMETER8, "ERROR: Parameter 8 out of range" },\
    { VI_ERROR_FAIL_ID_QUERY, "ERROR: Identification query failed" },\
    { VI_ERROR_INV_RESPONSE, "ERROR: Interpreting instrument response" },\
    { VI_ERROR_INSTR_FILE_OPEN, "ERROR: Opening the specified file" },\
    { VI_ERROR_INSTR_FILE_WRITE, "ERROR: Writing to the specified file" },\
    { VI_ERROR_INSTR_INTERPRETING_RESPONSE, "ERROR: Interpreting the instrument's response" },\
    { VI_ERROR_INSTR_PARAMETER8, "ERROR: Parameter 8 out of range" },\
    { VI_ERROR_INSTR_PARAMETER9, "ERROR: Parameter 9 out of range" },\
    { VI_ERROR_INSTR_PARAMETER10, "ERROR: Parameter 10 out of range" },\
    { VI_ERROR_INSTR_PARAMETER11, "ERROR: Parameter 11 out of range" },\
    { VI_ERROR_INSTR_PARAMETER12, "ERROR: Parameter 12 out of range" },\
    { VI_ERROR_INSTR_PARAMETER13, "ERROR: Parameter 13 out of range" },\
    { VI_ERROR_INSTR_PARAMETER14, "ERROR: Parameter 14 out of range" },\
    { VI_ERROR_INSTR_PARAMETER15, "ERROR: Parameter 15 out of range" },\
    \
    { VI_SUCCESS_EVENT_EN, "VI_SUCCESS_EVENT_EN" },\
    { VI_SUCCESS_EVENT_DIS, "VI_SUCCESS_EVENT_DIS" },\
    { VI_SUCCESS_QUEUE_EMPTY, "VI_SUCCESS_QUEUE_EMPTY" },\
    { VI_SUCCESS_TERM_CHAR, "VI_SUCCESS_TERM_CHAR" },\
    { VI_SUCCESS_MAX_CNT, "VI_SUCCESS_MAX_CNT" },\
    { VI_SUCCESS_DEV_NPRESENT, "VI_SUCCESS_DEV_NPRESENT" },\
    { VI_SUCCESS_TRIG_MAPPED, "VI_SUCCESS_TRIG_MAPPED" },\
    { VI_SUCCESS_QUEUE_NEMPTY, "VI_SUCCESS_QUEUE_NEMPTY" },\
    { VI_SUCCESS_NCHAIN, "VI_SUCCESS_NCHAIN" },\
    { VI_SUCCESS_NESTED_SHARED, "VI_SUCCESS_NESTED_SHARED" },\
    { VI_SUCCESS_NESTED_EXCLUSIVE, "VI_SUCCESS_NESTED_EXCLUSIVE" },\
    { VI_SUCCESS_SYNC, "VI_SUCCESS_SYNC" },\
    { VI_WARN_CONFIG_NLOADED, "VI_WARN_CONFIG_NLOADED" },\
    { VI_WARN_NULL_OBJECT, "VI_WARN_NULL_OBJECT" },\
    { VI_WARN_NSUP_ATTR_STATE, "VI_WARN_NSUP_ATTR_STATE" },\
    { VI_WARN_UNKNOWN_STATUS, "VI_WARN_UNKNOWN_STATUS" },\
    { VI_WARN_NSUP_BUF, "VI_WARN_NSUP_BUF" },\
    { VI_ERROR_SYSTEM_ERROR, "VI_ERROR_SYSTEM_ERROR" },\
    { VI_ERROR_INV_OBJECT, "VI_ERROR_INV_OBJECT" },\
    { VI_ERROR_RSRC_LOCKED, "VI_ERROR_RSRC_LOCKED" },\
    { VI_ERROR_INV_EXPR, "VI_ERROR_INV_EXPR" },\
    { VI_ERROR_RSRC_NFOUND, "VI_ERROR_RSRC_NFOUND" },\
    { VI_ERROR_INV_RSRC_NAME, "VI_ERROR_INV_RSRC_NAME" },\
    { VI_ERROR_INV_ACC_MODE, "VI_ERROR_INV_ACC_MODE" },\
    { VI_ERROR_TMO, "VI_ERROR_TMO" },\
    { VI_ERROR_CLOSING_FAILED, "VI_ERROR_CLOSING_FAILED" },\
    { VI_ERROR_INV_DEGREE, "VI_ERROR_INV_DEGREE" },\
    { VI_ERROR_INV_JOB_ID, "VI_ERROR_INV_JOB_ID" },\
    { VI_ERROR_NSUP_ATTR, "VI_ERROR_NSUP_ATTR" },\
    { VI_ERROR_NSUP_ATTR_STATE, "VI_ERROR_NSUP_ATTR_STATE" },\
    { VI_ERROR_ATTR_READONLY, "VI_ERROR_ATTR_READONLY" },\
    { VI_ERROR_INV_LOCK_TYPE, "VI_ERROR_INV_LOCK_TYPE" },\
    { VI_ERROR_INV_ACCESS_KEY, "VI_ERROR_INV_ACCESS_KEY" },\
    { VI_ERROR_INV_EVENT, "VI_ERROR_INV_EVENT" },\
    { VI_ERROR_INV_MECH, "VI_ERROR_INV_MECH" },\
    { VI_ERROR_HNDLR_NINSTALLED, "VI_ERROR_HNDLR_NINSTALLED" },\
    { VI_ERROR_INV_HNDLR_REF, "VI_ERROR_INV_HNDLR_REF" },\
    { VI_ERROR_INV_CONTEXT, "VI_ERROR_INV_CONTEXT" },\
    { VI_ERROR_QUEUE_OVERFLOW, "VI_ERROR_QUEUE_OVERFLOW" },\
    { VI_ERROR_NENABLED, "VI_ERROR_NENABLED" },\
    { VI_ERROR_ABORT, "VI_ERROR_ABORT" },\
    { VI_ERROR_RAW_WR_PROT_VIOL, "VI_ERROR_RAW_WR_PROT_VIOL" },\
    { VI_ERROR_RAW_RD_PROT_VIOL, "VI_ERROR_RAW_RD_PROT_VIOL" },\
    { VI_ERROR_OUTP_PROT_VIOL, "VI_ERROR_OUTP_PROT_VIOL" },\
    { VI_ERROR_INP_PROT_VIOL, "VI_ERROR_INP_PROT_VIOL" },\
    { VI_ERROR_BERR, "VI_ERROR_BERR" },\
    { VI_ERROR_IN_PROGRESS, "VI_ERROR_IN_PROGRESS" },\
    { VI_ERROR_INV_SETUP, "VI_ERROR_INV_SETUP" },\
    { VI_ERROR_QUEUE_ERROR, "VI_ERROR_QUEUE_ERROR" },\
    { VI_ERROR_ALLOC, "VI_ERROR_ALLOC" },\
    { VI_ERROR_INV_MASK, "VI_ERROR_INV_MASK" },\
    { VI_ERROR_IO, "VI_ERROR_IO" },\
    { VI_ERROR_INV_FMT, "VI_ERROR_INV_FMT" },\
    { VI_ERROR_NSUP_FMT, "VI_ERROR_NSUP_FMT" },\
    { VI_ERROR_LINE_IN_USE, "VI_ERROR_LINE_IN_USE" },\
    { VI_ERROR_NSUP_MODE, "VI_ERROR_NSUP_MODE" },\
    { VI_ERROR_SRQ_NOCCURRED, "VI_ERROR_SRQ_NOCCURRED" },\
    { VI_ERROR_INV_SPACE, "VI_ERROR_INV_SPACE" },\
    { VI_ERROR_INV_OFFSET, "VI_ERROR_INV_OFFSET" },\
    { VI_ERROR_INV_WIDTH, "VI_ERROR_INV_WIDTH" },\
    { VI_ERROR_NSUP_OFFSET, "VI_ERROR_NSUP_OFFSET" },\
    { VI_ERROR_NSUP_VAR_WIDTH, "VI_ERROR_NSUP_VAR_WIDTH" },\
    { VI_ERROR_WINDOW_NMAPPED, "VI_ERROR_WINDOW_NMAPPED" },\
    { VI_ERROR_RESP_PENDING, "VI_ERROR_RESP_PENDING" },\
    { VI_ERROR_NLISTENERS, "VI_ERROR_NLISTENERS" },\
    { VI_ERROR_NCIC, "VI_ERROR_NCIC" },\
    { VI_ERROR_NSYS_CNTLR, "VI_ERROR_NSYS_CNTLR" },\
    { VI_ERROR_NSUP_OPER, "VI_ERROR_NSUP_OPER" },\
    { VI_ERROR_INTR_PENDING, "VI_ERROR_INTR_PENDING" },\
    { VI_ERROR_ASRL_PARITY, "VI_ERROR_ASRL_PARITY" },\
    { VI_ERROR_ASRL_FRAMING, "VI_ERROR_ASRL_FRAMING" },\
    { VI_ERROR_ASRL_OVERRUN, "VI_ERROR_ASRL_OVERRUN" },\
    { VI_ERROR_TRIG_NMAPPED, "VI_ERROR_TRIG_NMAPPED" },\
    { VI_ERROR_NSUP_ALIGN_OFFSET, "VI_ERROR_NSUP_ALIGN_OFFSET" },\
    { VI_ERROR_USER_BUF, "VI_ERROR_USER_BUF" },\
    { VI_ERROR_RSRC_BUSY, "VI_ERROR_RSRC_BUSY" },\
    { VI_ERROR_NSUP_WIDTH, "VI_ERROR_NSUP_WIDTH" },\
    { VI_ERROR_INV_PARAMETER, "VI_ERROR_INV_PARAMETER" },\
    { VI_ERROR_INV_PROT, "VI_ERROR_INV_PROT" },\
    { VI_ERROR_INV_SIZE, "VI_ERROR_INV_SIZE" },\
    { VI_ERROR_WINDOW_MAPPED, "VI_ERROR_WINDOW_MAPPED" },\
    { VI_ERROR_NIMPL_OPER, "VI_ERROR_NIMPL_OPER" },\
    { VI_ERROR_INV_LENGTH, "VI_ERROR_INV_LENGTH" },\
    { VI_ERROR_INV_MODE, "VI_ERROR_INV_MODE" },\
    { VI_ERROR_SESN_NLOCKED, "VI_ERROR_SESN_NLOCKED" },\
    { VI_ERROR_MEM_NSHARED, "VI_ERROR_MEM_NSHARED" },\
    { VI_ERROR_LIBRARY_NFOUND, "VI_ERROR_LIBRARY_NFOUND" },\
    { VI_ERROR_NSUP_INTR, "VI_ERROR_NSUP_INTR" },\
    { VI_ERROR_INV_LINE, "VI_ERROR_INV_LINE" },\
    { VI_ERROR_FILE_ACCESS, "VI_ERROR_FILE_ACCESS" },\
    { VI_ERROR_FILE_IO, "VI_ERROR_FILE_IO" },\
    { VI_ERROR_NSUP_LINE, "VI_ERROR_NSUP_LINE" },\
    { VI_ERROR_NSUP_MECH, "VI_ERROR_NSUP_MECH" },\
    { VI_ERROR_INTF_NUM_NCONFIG, "VI_ERROR_INTF_NUM_NCONFIG" },\
    { VI_ERROR_CONN_LOST, "VI_ERROR_CONN_LOST" },\
    { VI_ERROR_NPERMISSION, "VI_ERROR_NPERMISSION" },\
    \
    \
    /* --- Instrument specific error codes --- */\
    \
    { RSSGT_ERROR_INSTRUMENT_ERROR, "ERROR: Instrument status error" },\
    { RSSGT_ERROR_INVALID_CONFIGURATION, "ERROR: Instrument configuration error" },\
    { RSSGT_ERROR_INSTRUMENT_OPTION, "ERROR: Option not installed" },\
    { RSSGT_ERROR_INSTRUMENT_NSUP_MODEL, "ERROR: Required Instrument model is not available." },\
    { RSSGT_ERROR_SETTINGS_CONFLICT, "ERROR: Instrument settings conflict." },\
    { RSSGT_ERROR_CALIBRATION_FAILED, "ERROR: Calibration failed." },\
    { RSSGT_ERROR_INSTRUMENT_DATA_NOT_AVAILABLE, "ERROR: Data not available." },\
    \
    /* --- Instrument specific warnings --- */ \
    \
    { RSSGS_WARNING_SMALL_BUFFER, "WARNING: Buffer too small" }




/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSSGT_HEADER */
