/*****************************************************************************
 *------------------------ Utility  -----------------------------------------*
 *****************************************************************************/
#include <float.h>
#include <math.h>
#include "rssgt.h"

#define MAXPTRHANDLES 100
#define BUFFER_SIZE             2048L    /* File I/O buffer size */
static void* g_PointerList[MAXPTRHANDLES] = {0};


static unsigned int rssgt_FindNextFreePointerEntry()
{
  int i = 0;
  // leave position 0 empty
  for (i = 1; i < MAXPTRHANDLES; i++)
  {
    if (g_PointerList[i] == 0)
      return i;
  }
  return 0;
}

unsigned int rssgt_AddPointer(void* pPtr)
{
  unsigned int index = rssgt_FindNextFreePointerEntry();
  if (index)
  {
    g_PointerList[index] = pPtr;
  }
  else
  {
    printf ("Pointer list full\n");
  }
  return index;
}

void rssgt_RemovePointer(unsigned int handle)
{
  g_PointerList[handle] = 0;
}

void* rssgt_GetPointer(unsigned int handle)
{
  if (handle > 0 && handle < MAXPTRHANDLES)
    return g_PointerList[handle];

  return 0;
}

#if 0
/*===========================================================================*/
/* Function:  f2a*/
/* Purpose:  Convert a floating point value into an ASCII string             */
/*             value[in]: value to be converted                              */
/*             szOut[out]: pointer to character buffer allocated by caller   */
/*                         holds result                                      */
/*             value[in]: value to be converted                              */
/*===========================================================================*/

static void f2a(double value, char* szOut, int nCnt)
{
  char txt[100];
  char* p = 0;
  char* pStart = 0;
  char *pDpoint = 0;

  double  dExpo = log10(fabs(value));

  if( fabs (dExpo) < 32)
  {
    const int nMaxSignificantDigits = 15;
    char szFormat[100];

    int nLsDigit = (int)ceil (dExpo - nMaxSignificantDigits);
    if (nLsDigit < 0)
    {
      sprintf (szFormat, "%%1.%df", -nLsDigit);    
      sprintf(txt,szFormat, value);
    }
    else
    {
      char Zeros[] = {"00000000000000000000000000000000000000"};
      const double v = pow (10.0,nMaxSignificantDigits);

      double ll = floor(value / v + 0.5);

      strcpy (szFormat, "%f");    
      Zeros[nMaxSignificantDigits] = 0;
      sprintf(txt,szFormat, ll);
      p = strchr(txt,'.');
      if (p)
        *p= 0;
      strcat (txt,Zeros);

    }
  }
  else
  {
    sprintf(txt,"%g",value);
  }

  pStart = txt;
  while (*pStart == ' ') // skip leading blanks
    pStart++;

  pDpoint = strchr (pStart,'.');
  if (pDpoint)
  {
    char* pC = pStart+strlen(pStart)-1;
    while (*pC == '0') // truncate trailing zeros in the fractional part
    {
      *pC = 0;
      pC--;
    }  

    // kill trailing .
    pC = pDpoint+1; 
    if (*pC == '\0')
      *pDpoint=0;
  }

  strncpy (szOut, pStart, nCnt); 
}
#endif

/*****************************************************************************
 *- Callback Declarations ---------------------------------------------------*
 *****************************************************************************/
ViStatus rssgt_CheckStatusCallback (ViSession io);
ViStatus rssgt_WaitForOPCCallback (ViSession io);
ViStatus rssgt_doubleQuotedString_ReadCallback(ViSession instrSession, ViConstString repCapName, ViAttr attributeId, ViInt32 bufSize, void *value);
ViStatus rssgt_doubleQuotedString_WriteCallback(ViSession instrSession, ViConstString repCapName, ViAttr attributeId, void *value);

static ViString pathArr[] = {"","A","B", NULL};

/*****************************************************************************
 * Function: rssgt_InitAttributes
 * Purpose:  This function inits attributes to the desired values if needed.
 *****************************************************************************/
ViStatus rssgt_InitAttributes (ViSession instrSession)
{
    ViStatus    error           = VI_SUCCESS;
    ViInt32     p2value         = 0;
    void        *p2void;
    ViChar      buffer[RS_MAX_MESSAGE_BUF_SIZE],
                revision[RS_MAX_MESSAGE_BUF_SIZE],
                manufacturer[RS_MAX_MESSAGE_BUF_SIZE],
                model[RS_MAX_MESSAGE_BUF_SIZE],
                tmp_model[RS_MAX_MESSAGE_BUF_SIZE],
                idQ[RS_MAX_MESSAGE_BUF_SIZE],
                options_list[RS_MAX_MESSAGE_BUF_SIZE];

    buffer[RS_MAX_MESSAGE_BUF_SIZE -1] = 0;

    /*- Misc -*/

    if (!Rs_Simulating(instrSession))
        {
        /* Instrument identification */
        viCheckErr (rsQueryf (instrSession, "*IDN?\n", "%[^\r\n]", idQ));
        idQ[RS_MAX_MESSAGE_BUF_SIZE - 1] = 0;
        checkErr (Rs_SetAttribute (instrSession, "", RSSGT_ATTR_ID_QUERY_RESPONSE, 0, idQ));
        
        /* Option(s) string */
        viCheckErr (rsQueryf (instrSession, "*OPT?\n", "%[^\r\n]", options_list));
        options_list[RS_MAX_MESSAGE_BUF_SIZE - 1] = 0;
        }
    else /* Simulating */
        {
        /* Instrument identification */
        strncpy (idQ, RSSGT_SIMULATION_ID_QUERY, RS_MAX_MESSAGE_BUF_SIZE - 1);
        checkErr (Rs_SetAttribute (instrSession, "", RSSGT_ATTR_ID_QUERY_RESPONSE, 0, idQ));
        
        /* Option(s) string */
        strncpy (options_list, RSSGT_SIMULATION_OPT_QUERY, RS_MAX_MESSAGE_BUF_SIZE - 1);
        }

    /*- Inherent Instrument Specific Attributes ----------------------------*/

    /*- User Options -*/

    /*
    RS_ATTR_RANGE_CHECK             ... Rs_SpecificDriverNew
    RS_ATTR_QUERY_INSTRUMENT_STATUS ... Rs_SpecificDriverNew
    RS_ATTR_CACHE                   ... Rs_SpecificDriverNew
    RS_ATTR_SIMULATE                ... Rs_SpecificDriverNew
    RS_ATTR_RECORD_COERCIONS        ... not supported
    RS_ATTR_INTERCHANGE_CHECK       ... not supported
    RS_ATTR_SPY                     ... not supported
    RS_ATTR_USE_SPECIFIC_SIMULATION ... not supported
    */

    /*- Class Driver Identification -*/

    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CLASS_DRIVER_DESCRIPTION, 0, RSSGT_CLASS_DRIVER_DESCRIPTION));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CLASS_DRIVER_PREFIX, 0, RSSGT_CLASS_DRIVER_PREFIX));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CLASS_DRIVER_VENDOR, 0, RSSGT_CLASS_DRIVER_VENDOR));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CLASS_DRIVER_REVISION, 0, RSSGT_CLASS_DRIVER_REVISION));
    p2value = RSSGT_CLASS_SPEC_MAJOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION, 0, &p2value));
    p2value = RSSGT_CLASS_SPEC_MINOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION, 0, &p2value));

    /*- Driver Identification -*/
                                                        
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION, 0, RSSGT_SPECIFIC_DRIVER_DESCRIPTION));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_PREFIX, 0, RSSGT_SPECIFIC_DRIVER_PREFIX));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_LOCATOR, 0, RSSGT_SPECIFIC_DRIVER_LOCATOR));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_VENDOR, 0, RSSGT_SPECIFIC_DRIVER_VENDOR));

    sprintf (buffer, 
             "Driver: %s %ld.%ld.%ld, Compiler: %s %3.2f, "
             "Components: RSEngine %.2f, VISA-Spec %.2f",
             RSSGT_SPECIFIC_DRIVER_PREFIX,
             RSSGT_MAJOR_VERSION, RSSGT_MINOR_VERSION,RSSGT_MINOR_MINOR_VERSION,
             RS_COMPILER_NAME, RS_COMPILER_VER_NUM, 
             RS_ENGINE_MAJOR_VERSION + RS_ENGINE_MINOR_VERSION/10.0, 
             Rs_ConvertVISAVer(VI_SPEC_VERSION));

    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_REVISION, 0, buffer));
    p2value = RSSGT_CLASS_SPEC_MAJOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION, 0, &p2value));
    p2value = RSSGT_CLASS_SPEC_MINOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION, 0, &p2value));

    /*- Driver Capabilities -*/
                                   
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SUPPORTED_INSTRUMENT_MODELS, 0, RSSGT_SUPPORTED_INSTRUMENT_MODELS));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_GROUP_CAPABILITIES, 0, RSSGT_GROUP_CAPABILITIES));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_FUNCTION_CAPABILITIES, 0, RSSGT_FUNCTION_CAPABILITIES));
    /* RS_ATTR_CHANNEL_COUNT        ... Rs_BuildRepCapTable */

    /*- Driver Setup -*/

    /* RS_ATTR_DRIVER_SETUP         ... Rs_SpecificDriverNew */

    /*- Instrument Identification -*/

    checkErr (Rs_GetAttribute (instrSession, "", RSSGT_ATTR_ID_QUERY_RESPONSE, 0, RSSGT_IO_BUFFER_SIZE, idQ));
    sscanf (idQ, "%[^,],%[^,],%*[^,],%256[^\n]", manufacturer, tmp_model, revision);
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_INSTRUMENT_MANUFACTURER, 0, manufacturer));
    sscanf (tmp_model,"%[^-]",model);
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_INSTRUMENT_MODEL, 0, model));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_INSTRUMENT_FIRMWARE_REVISION, 0, revision));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_OPTIONS_LIST, 0, options_list));

    /*- Advanced Session Information -*/
                                  
    /*  
    RS_ATTR_IO_RESOURCE_DESCRIPTOR  ... rssgt_InitWithOptions
    RS_ATTR_LOGICAL_NAME            ... not supported
    */

    /*- Inherent Vendor Specific Attributes --------------------------------*/

    /*- Error Info -*/

    /*
    RS_ATTR_PRIMARY_ERROR           ... Rs_SetErrorInfo
    RS_ATTR_SECONDARY_ERROR         ... Rs_SetErrorInfo
    RS_ATTR_ERROR_ELABORATION       ... Rs_SetErrorInfo
    */

    /*- Session I/O -*/

    /*
    RS_ATTR_VISA_RM_SESSION         ... rssgt_RsInit
    RS_ATTR_IO_SESSION              ... Rs_UpdateIOSession
    RS_ATTR_IO_SESSION_TYPE         ... not supported
    */

    /*- Version Info -*/                     

    p2value = RSSGT_MAJOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION, 0, &p2value));
    p2value = RSSGT_MINOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_VERSION, 0, &p2value));
    p2value = RSSGT_MINOR_MINOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_MINOR_VERSION, 0, &p2value));
    p2value = RSSGT_CLASS_SPEC_MAJOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CLASS_DRIVER_MAJOR_VERSION, 0, &p2value));
    p2value = RSSGT_CLASS_SPEC_MINOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CLASS_DRIVER_MINOR_VERSION, 0, &p2value));
    p2value = RS_ENGINE_MAJOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_ENGINE_MAJOR_VERSION, 0, &p2value));
    p2value = RS_ENGINE_MINOR_VERSION;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_ENGINE_MINOR_VERSION, 0, &p2value));
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_ENGINE_REVISION, 0, RS_ENGINE_REVISION));

    /*- Session Callbacks -*/                

    p2void = rssgt_WaitForOPCCallback;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_OPC_CALLBACK, 0, &p2void));
    p2void = rssgt_CheckStatusCallback;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_CHECK_STATUS_CALLBACK, 0, &p2void));
    p2value = RSSGT_OPC_TIMEOUT;
    checkErr (Rs_SetAttribute (instrSession, "", RS_ATTR_OPC_TIMEOUT, 0, &p2value));

    /*----------------------------------------------------------------------*/

Error:
    return error;
}

/*****************************************************************************
 * Function: rssgt_DefaultInstrSetup
 * Purpose:  This function sends a default setup to the instrument. The
 *           rssgt_reset function calls this function. The
 *           rssgt_RsInit function calls this function when the
 *           user passes VI_FALSE for the reset parameter. This function is
 *           useful for configuring settings that other instrument driver
 *           functions require.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rssgt_DefaultInstrSetup (ViSession instrSession)
{
    ViStatus    error = VI_SUCCESS;

    /* Set all the attributes to the default state. Do not update inherent attributes! */
    checkErr (Rs_ApplyAttributeDefaults (instrSession, VI_FALSE));

    /* Init attributes */
    checkErr( rssgt_InitAttributes (instrSession));

    if (!Rs_Simulating(instrSession))
    {
        viCheckErr( rsPrintf (instrSession, "*CLS\n"));
		viCheckErr( rsPrintf (instrSession, "*ESE %hu\n", IEEE_488_2_ESE_MASK));
		viCheckErr( rsPrintf (instrSession, "*SRE 32\n"));
    }

Error:
    return error;
}

/*****************************************************************************
 * Function: rssgt_CheckStatus
 * Purpose:  This function checks the status of the instrument to detect
 *           whether the instrument has encountered an error. This function
 *           is called at the end of most exported driver functions. If the
 *           instrument reports an error, this function returns
 *           RS_ERROR_INSTRUMENT_SPECIFIC. The user can set the
 *           rssgt_ATTR_QUERY_INSTRUMENT_STATUS attribute to VI_FALSE to disable this
 *           check and increase execution speed.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rssgt_CheckStatus (ViSession instrSession)
{
    ViStatus    error = VI_SUCCESS;

    if (Rs_QueryInstrStatus (instrSession) && !Rs_Simulating (instrSession))
        {
        checkErr( rssgt_CheckStatusCallback (instrSession));
        }

Error:
    return error;
}

/*===========================================================================*/
/* Function: Long Signed Integer Value Out Of Range - ViInt32                */
/* Purpose:  This function checks a long signed integer value to see if it   */
/*           lies between a minimum and maximum value.  If the value is out  */
/*           of range, the return value is VI_TRUE, otherwise the return     */
/*           value is VI_FALSE.                                              */
/*===========================================================================*/
ViStatus rssgt_invalidViInt32Range (ViInt32 val, ViInt32 min, ViInt32 max)
{
    return (val < min || val > max) ? RS_ERROR_INVALID_PARAMETER : VI_SUCCESS;
}
/*===========================================================================*/
/* Function: Long Unsigned Integer Value Out Of Range - ViUInt32             */
/* Purpose:  This function checks a long unsigned integer value to see if it */
/*           lies between a minimum and maximum value.  If the value is out  */
/*           of range, the return value is VI_TRUE, otherwise the return     */
/*           value is VI_FALSE.                                              */
/*===========================================================================*/
ViStatus rssgt_invalidViUInt32Range (ViUInt32 val, ViUInt32 min, ViUInt32 max)
{
    return (val < min || val > max) ? RS_ERROR_INVALID_PARAMETER : VI_SUCCESS;
}
/*===========================================================================*/
/* Function: Real (Double) Value Out Of Range - ViReal64                     */
/* Purpose:  This function checks a real (double) value to see if it lies    */
/*           between a minimum and maximum value.  If the value is out of    */
/*           range, the return value is VI_TRUE, otherwise the return value  */
/*           is VI_FALSE.                                                    */
/*===========================================================================*/
ViStatus rssgt_invalidViReal64Range (ViReal64 val, ViReal64 min, ViReal64 max)
{
    return (val < min || val > max) ? RS_ERROR_INVALID_PARAMETER : VI_SUCCESS;
}
/*===========================================================================*/
/* Function: Boolean Value Out Of Range - ViBoolean                          */
/* Purpose:  This function checks a Boolean to see if it is equal to VI_TRUE */
/*           or VI_FALSE. If the value is out of range, the return value is  */
/*           VI_TRUE, otherwise the return value is VI_FALSE.                */
/*===========================================================================*/
ViStatus rssgt_invalidViBooleanRange (ViBoolean val)
{
    return (val != VI_FALSE && val != VI_TRUE) ? RS_ERROR_INVALID_PARAMETER : VI_SUCCESS;
}

/*===========================================================================*/
/* Function: Set OPC Timeout                                                 */
/* Purpose:  Sets new OPC timeout                                            */
/*===========================================================================*/
ViStatus rssgt_SetOPCTimeout(ViSession   instrSession, ViInt32 timeout)
{
    ViStatus    error = VI_SUCCESS; 
    
    checkErr( Rs_SetAttribute (instrSession, NULL, RS_ATTR_OPC_TIMEOUT, 0, &timeout));  
    
Error:    
    return error;
}

/*===========================================================================*/
/* Function: Get OPC Timeout                                                 */
/* Purpose:  Gets new OPC timeout                                            */
/*===========================================================================*/
ViStatus rssgt_GetOPCTimeout(ViSession   instrSession, ViInt32 *timeout)
{
    ViStatus    error = VI_SUCCESS; 
    
    checkErr( Rs_GetAttribute (instrSession, NULL, RS_ATTR_OPC_TIMEOUT, 0, sizeof(timeout), timeout));  
    
Error:    
    return error;
}

/*****************************************************************************
 * Function: rssgt_instanceRepCap
 * Purpose:  This function checks instance repeated capability and 
 *           creates proper string.
 *****************************************************************************/
ViStatus rssgt_pathRepCap (ViSession instrSession, ViInt32 path, ViChar rep_cap[])
{
    ViStatus    error   = VI_SUCCESS;
    
    viCheckParm (rssgt_invalidViInt32Range (path, 0, 2), 2, "Path");
    sprintf (rep_cap, "%s", pathArr[path]);
Error:    
    return error;
}

/*===========================================================================*/
/* Function: Read Data With Unknown length                                   */
/* Purpose:  This function allocates buffer and reads data from the          */
/*           instrument                                                      */
/* WARNING:  You must deallocate buffer, if any pointer has been returned.   */
/*           This function does not work correctly, when you read bin data   */
/*           via serial intf                                                 */
/*===========================================================================*/
ViStatus rssgt_readDataUnknownLength(ViSession instrSession,
                                     ViChar **outBuffer,
                                     ViUInt32 *count)
{
    ViStatus rssgt_status = VI_SUCCESS;
    ViUInt32 actSize, retCnt = 0;
    ViChar   *buffer = NULL, *p2buffer;

    *outBuffer = NULL;
    if (count) *count = 0;

    /* Allocate Buffer */
    actSize = BUFFER_SIZE;
    buffer = (ViChar *)calloc(actSize, sizeof(ViChar));
    if (buffer == NULL) return VI_ERROR_ALLOC;

    p2buffer = buffer;
    do
        {
        if ((rssgt_status = rsRead (instrSession, (ViPBuf)p2buffer, BUFFER_SIZE, &retCnt)) < 0)
            {
            free(buffer);
            *outBuffer = NULL;
            return rssgt_status;
            }
        if (retCnt == BUFFER_SIZE) /* Buffer was small, reallocate it */
        {
            actSize += BUFFER_SIZE;
            buffer = (ViChar *)realloc(buffer, actSize);
            if (buffer == NULL) return VI_ERROR_ALLOC;
            p2buffer = buffer + (actSize - BUFFER_SIZE); /* Set pointer to end of data in rallocated buffer */
        }
        else
        {
            *(p2buffer+retCnt) = '\0'; /* For sure set end of string at the end of data */
        }
       } while (rssgt_status == VI_SUCCESS_MAX_CNT); /* if buffer was small, continue with next read */

    *outBuffer = buffer;
    if (count) *count = (actSize - BUFFER_SIZE) + retCnt;

    return rssgt_status;
}
