@echo off

SETLOCAL EnableDelayedExpansion EnableExtensions  

ECHO === Setting up CMake ===

where cmake  2> nul && (
    echo Found CMake in PATH
) || (
  if EXIST "C:\Program Files (x86)\CMake" (
    ECHO "Found CMake in C:\Program Files (x86)\CMake"
    SET "PATH=C:\Program Files (x86)\CMake\bin;%PATH%"
  ) ELSE (
    if EXIST "C:\Program Files\CMake" (
      ECHO Found CMake in C:\Program Files\CMake
      SET "PATH=C:\Program Files\CMake\bin;%PATH%"
    ) ELSE (
        ECHO ERROR: CMake not found in Path
        exit /B 4
    )
  )
)

set CMAKE_ECHO=cmake -E cmake_echo_color
set CECHO=!CMAKE_ECHO! --normal --bold
set CECHO_=!CMAKE_ECHO! --normal --bold --no-newline
set CECHO_RED=!CMAKE_ECHO! --red --bold
set CECHO_RED_=!CMAKE_ECHO! --red --bold --no-newline
set CECHO_GREEN_=!CMAKE_ECHO! --green --bold
set CECHO_GREEN_=!CMAKE_ECHO! --green --bold --no-newline
set CECHO_BLUE=!CMAKE_ECHO! --blue --bold
set CECHO_BLUE_=!CMAKE_ECHO! --blue --bold --no-newline



ECHO.
if [%1]==[] (
  SET ARCH=x86
) ELSE (
  SET ARCH=x64
)


IF [!ARCH!]==[x64] (
    !CECHO_! "Building for the " && !CECHO_GREEN_! "64 bit" && !CECHO! " platform toolset"
    SET VCVARSARG=amd64
    SET "CMAKE_GENERATOR=Visual Studio 15 2017 Win64"
) ELSE (
    !CECHO_! "Building for the " && !CECHO_GREEN_! "x86 32 bit" && !CECHO! " platform toolset"
    SET VCVARSARG=x86
    SET "CMAKE_GENERATOR=Visual Studio 15 2017"
)

SET VS_PLATFORM_NAME=Win32


echo Building for arch !ARCH!

ECHO.
!CECHO! "Setting up !CMAKE_GENERATOR! command prompt"

IF NOT EXIST "%ProgramFiles(x86)%\Microsoft Visual Studio\Installer\vswhere.exe" (
  !CECHO_RED! "No vswhere.exe found, please install VS2017 version 15.3 or later"
  exit /B 3
)
SET _VSWHERE="%ProgramFiles(x86)%\Microsoft Visual Studio\Installer\vswhere"
SET _VSWHERE_ARGS=-products * -requires Microsoft.Component.MSBuild  -version [15.7^^,16.0^^) -property installationPath
ECHO Calling %_VSWHERE% %_VSWHERE_ARGS%
for /f "tokens=* delims=" %%G in ('%_VSWHERE% %_VSWHERE_ARGS%') DO (
    SET VSPATH=%%G
    goto :end
)
:end
SET _VSWHERE=
SET _VSWHERE_ARGS=

IF ["%VSPATH%"] EQU [""] (
    !CECHO_RED! "ERROR: No VS2017 build tools found"
    exit /B 2
) ELSE (
     !CECHO_GREEN! Found suitable VS2017 build tools. VSPATH="[32m%VSPATH%[0m"
)

SET "VSPATH=%VSPATH%"
if not defined VSINSTALLDIR call "%VSPATH%\VC\Auxiliary\Build\vcvarsall.bat" %VCVARSARG%!


ECHO.
!CECHO! "Generating project with cmake"

del CMakeCache.txt
SET cmake=cmake -G "%CMAKE_GENERATOR%" -Wdev -Wno-deprecated -Werror=dev -DCMAKE_SYSTEM_VERSION=10.0.17134.0 -DCMAKE_CONFIGURATION_TYPES:STRING=Debug;Release -DCMAKE_VERBOSE_MAKEFILE=ON -DCMAKE_SUPPRESS_REGENERATION:BOOL=OFF %CMAKE_EXTRA_ARGS%

ECHO Calling %CMAKE%
%cmake% CMakeLists.txt


REM Thanks https://stackoverflow.com/a/9422268/852531
echo %cmdcmdline% | find /i "%~0" >nul
if not errorlevel 1 set PAUSE=pause
!PAUSE!

