#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include "rssgt.h"
#include "SgmaCommandIds.h"


#ifdef __linux__
#include <termios.h>
#include <unistd.h>

#ifndef BOOL
typedef int BOOL;
#endif

#ifndef TRUE
#define TRUE 1    
#define FALSE 0    
#endif

typedef long long __int64;
#define _stricmp strcasecmp
#define Sleep(msec) usleep((msec)*1000)
#define __fastcall
typedef int HANDLE;
#define INVALID_HANDLE_VALUE -1

#else
#pragma comment(linker, "/SUBSYSTEM:CONSOLE")

#include "Windows.h"
#include <conio.h>
#include <intrin.h>
#pragma intrinsic(__rdtsc)
#endif

// Controlling the serial interface for test purposes
typedef HANDLE(__fastcall *FuncSerialOpen) (const char* i_port);
typedef void(__fastcall *FuncSerialClose)(HANDLE fd_);
typedef void(__fastcall *FuncSerialSetRTS) (HANDLE fd_, int level);
typedef void(__fastcall *FuncSerialSetDTR) (HANDLE fd_, int level);
FuncSerialOpen   SerialOpen = NULL;
FuncSerialClose  SerialClose = NULL;
FuncSerialSetRTS SerialSetRTS = NULL;
FuncSerialSetDTR SerialSetDTR = NULL;
HANDLE SerialHandle = INVALID_HANDLE_VALUE;

void InitControlSerial();
void SET_RTS();
void CLR_RTS();
void SET_DTR();
void CLR_DTR();
void INIT_SERIAL();
void CLOSE_SERIAL();


#define SIGGENTYPEUNKNOWN 0
#define SIGGENTYPESGT     1
#define MAXCMDSIZE 6

char g_szResourceString[1000] = { 0 };
typedef char COMMAND[MAXCMDSIZE][100];
ViBoolean useFastSettings = VI_TRUE;
ViBoolean enableAsynchronousFastSettings = VI_FALSE;
double g_dProcessorClockrate = -1.0;

void CommandLoop(ViSession instrumentHandle);
void TestExecutionTime(int instrumentHandle, int attribute, double* Values, int nValuesCount, BOOL selecttype, const char* szCaption, int nloops);
void TestPowerServoingTime(int instrumentHandle, int nloops);
BOOL determineProcessorClockrate();
double getClockInMicroSeconds(BOOL bIsToCalculate);

#define HWINDEX1 NULL


// ---------------------------------------------------------------------
//
// ---------------------------------------------------------------------
void PrintCommandList()
{
  printf("cmd:\n" \
    "\tf[?]\tFrequency\n" \
    "\tl[?]\tLevel\n" \
    "\tfl\tFrequency and Level\n" \
    "\tr[?]\tRF State\n" \
    "\tm[?]\tIQ Modulator State\n" \
    "\tw[?]\tIQ Wideband State\n" \
    "\td[?]\tDigital Attenuation\n" \
    "\tfo[?]\tFrequency Offset\n" \
    "\tpo[?]\tPhase Offset\n" \
    "\tt\tTrigger ARB\n" \
    "\tn\tTrigger Next Segment\n" \
    "\ti?\tIdn Query\n" \
    "\taf?\tAdjust Frequency\n" \
    "\tro[?]\tReference Oscillator Source\n" \
    "\ttt\tTest Execution Time\n" \
    "\tfm[?]\tFast Mode\n" \
    "\tscpi[?]\tWrite / Query SCPI\n" \
    "\tq\tQuit\n");
}


// ---------------------------------------------------------------------
//
// ---------------------------------------------------------------------
const char* DecodeVisaError(ViStatus i_stat)
{
  static char buffer[1000];
  ViStatus status = VI_SUCCESS;
  *buffer = 0;

  if (i_stat == VI_SUCCESS)
    return "VI_SUCCESS";

  status = rssgt_error_message(0, i_stat, buffer);
  if (status != VI_SUCCESS)
  {
    sprintf(buffer, "Unknown Visa Error 0x%x", (unsigned int)i_stat);
  }
  return buffer;
}

// ---------------------------------------------------------------------
//
// ---------------------------------------------------------------------
#ifdef __linux__

int _getch(void)
{
  struct termios oldattr, newattr;
  int ch;
  tcgetattr(STDIN_FILENO, &oldattr);
  newattr = oldattr;
  newattr.c_lflag &= ~(ICANON | ECHO);
  tcsetattr(STDIN_FILENO, TCSANOW, &newattr);
  ch = getchar();
  tcsetattr(STDIN_FILENO, TCSANOW, &oldattr);
  return ch;
}


#endif

// ---------------------------------------------------------------------
//
// ---------------------------------------------------------------------

ViStatus InterpretCommand(ViSession instrumentHandle, COMMAND szCommand)
{
  ViStatus status = VI_SUCCESS;
  double dValue = 0;
  ViInt32 nValue = 0;
  ViInt32 nValue1 = 0;
  ViBoolean bState = 0;
#define BUFFERSIZE 4000
  char buffer[BUFFERSIZE] = { 0 };

  if (!strcmp(szCommand[0], "?"))
  {
    PrintCommandList();
  }
  // Set / get frequency ------------------------- 
  else if (!strcmp(szCommand[0], "f"))
  {
    size_t len = strlen(szCommand[1]);
    double value = atof(szCommand[1]);
    if (len > 3 || *szCommand[2])
    {
      if (!_stricmp(szCommand[1] + len - 3, "mhz") || !_stricmp(szCommand[2], "mhz"))
        value *= 1e6;
      if (!_stricmp(szCommand[1] + len - 3, "ghz") || !_stricmp(szCommand[2], "ghz"))
        value *= 1e9;
    }

    SET_RTS();
    status = rssgt_SetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_RF_FREQUENCY, value);
    CLR_RTS();

  }

  else if (!strcmp(szCommand[0], "f?"))
  {
    status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_RF_FREQUENCY, &dValue);

    if (status >= VI_SUCCESS)
    {
      printf("Freq = %15.3f Hz ", dValue);
      if (dValue > 1e9)
        printf("(%f GHz)\n", dValue / 1e9);
      else if (dValue > 1e6)
        printf("(%f MHz)\n", dValue / 1e6);
      else
        printf("\n");
    }
  }

  //// Set / get frequency offset ------------------------- 
  else if (!strcmp(szCommand[0], "fo"))
  {
    size_t len = strlen(szCommand[1]);
    double value = atof(szCommand[1]);
    if (len > 3 || *szCommand[2])
    {
      if (!_stricmp(szCommand[1] + len - 3, "mhz") || !_stricmp(szCommand[2], "mhz"))
        value *= 1e6;
      if (!_stricmp(szCommand[1] + len - 3, "ghz") || !_stricmp(szCommand[2], "ghz"))
        value *= 1e9;
    }

    status = rssgt_SetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_RF_FREQUENCY_OFFSET, value);

  }

  else if (!strcmp(szCommand[0], "fo?"))
  {
    status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_RF_FREQUENCY_OFFSET, &dValue);

    if (status >= VI_SUCCESS)
    {
      printf("Offs = %15.3f Hz ", dValue);
      if (dValue > 1e9)
        printf("(%f GHz)\n", dValue / 1e9);
      else if (dValue > 1e6)
        printf("(%f MHz)\n", dValue / 1e6);
      else
        printf("\n");
    }
  }

  // Set / get level ------------------------- 
  else if (!strcmp(szCommand[0], "l"))
  {
    SET_RTS();
    status = rssgt_SetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_RF_AMPLITUDE, atof(szCommand[1]));
    CLR_RTS();

  }
  else if (!strcmp(szCommand[0], "l?"))
  {
    status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_RF_AMPLITUDE, &dValue);

    if (status >= VI_SUCCESS)
      printf("Level = %f dBm\n", dValue);
  }

  else if (!strcmp(szCommand[0], "ps"))
  {
    ViInt32 result;
    double executiontime;

    determineProcessorClockrate();

    status = rssgt_SetAttributeViBoolean(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_STATE, VI_TRUE);
    rssgt_FastSync(instrumentHandle);

    if (*szCommand[2])
      status = rssgt_SetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_RF_LEVEL_OFFSET, atof(szCommand[2]));
    else
    {
      status = rssgt_SetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_RF_LEVEL_OFFSET, -7);
      status = rssgt_SetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_RF_AMPLITUDE, 5);
    }
    Sleep(100);


    SET_RTS();
    getClockInMicroSeconds(0);
    status = rssgt_PowerServoingSet(instrumentHandle, atof(szCommand[1]), &result);
    executiontime = getClockInMicroSeconds(1);
    CLR_RTS();
    if (status >= VI_SUCCESS)
    {
      printf("Result: %s\n", result ? "FAIL" : "OK");
      if (result)
      {
        rssgt_GetAttributeViString(instrumentHandle, HWINDEX1, RSSGT_ATTR_SYSTEM_ERROR, BUFFERSIZE, buffer);
        printf("%s\n", buffer);
      }
      else
      {
        status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_RF_LEVEL_OFFSET, &dValue);
        printf("Offset: %5.2f dB\t(%5.1f ms)\n", dValue, executiontime / 1000);
      }
    }

  }

  // Set / get level offset ------------------------- 
  else if (!strcmp(szCommand[0], "lo"))
  {
    status = rssgt_SetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_RF_LEVEL_OFFSET, atof(szCommand[1]));
  }
  else if (!strcmp(szCommand[0], "l?"))
  {
    status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_RF_LEVEL_OFFSET, &dValue);

    if (status >= VI_SUCCESS)
      printf("Offset = %f dB\n", dValue);
  }

  // Set level and frequency ------------------------ 
  else if (!strcmp(szCommand[0], "fl"))
  {
    size_t len = 0;
    double value = 0;

    //    status = rssgt_SetTrigConnnectorOpMode(instrumentHandle, RSSgt_TRG_CON_OP_MODE_MEASLATENCY );
    //    rssgt_delay (instrumentHandle, 0.1);

    len = strlen(szCommand[1]);
    value = atof(szCommand[1]);
    if (len > 3)
    {
      if (!_stricmp(szCommand[1] + len - 3, "mhz"))
        value *= 1e6;
      if (!_stricmp(szCommand[1] + len - 3, "ghz"))
        value *= 1e9;
    }

    status |= rssgt_SetFrequencyAndLevel(instrumentHandle, value, atof(szCommand[2]));
  }

  // Set / get RF state ------------------------- 
  else if (!strcmp(szCommand[0], "r"))
  {
    bState = !_stricmp(szCommand[1], "ON") || !_stricmp(szCommand[1], "1");
    status = rssgt_SetAttributeViBoolean(instrumentHandle, HWINDEX1, RSSGT_ATTR_OUTPUT_ENABLED, bState);

  }
  else if (!strcmp(szCommand[0], "r?"))
  {
    status = rssgt_GetAttributeViBoolean(instrumentHandle, HWINDEX1, RSSGT_ATTR_OUTPUT_ENABLED, &bState);

    if (status >= VI_SUCCESS)
      printf("RF State = %s\n", bState ? "ON" : "OFF");
  }

  // Set / get IQ modulator state ------------------------- 
  else if (!strcmp(szCommand[0], "m"))
  {
    bState = !_stricmp(szCommand[1], "ON") || !_stricmp(szCommand[1], "1");
    status = rssgt_SetAttributeViBoolean(instrumentHandle, HWINDEX1, RSSGT_ATTR_IQ_ENABLED, bState);
  }
  else if (!strcmp(szCommand[0], "m?"))
  {
    status = rssgt_GetAttributeViBoolean(instrumentHandle, HWINDEX1, RSSGT_ATTR_IQ_ENABLED, &bState);

    if (status >= VI_SUCCESS)
      printf("IQ Modulator State = %s\n", bState ? "ON" : "OFF");
  }
  // Set / get IQ wideband state ------------------------- 
  else if (!strcmp(szCommand[0], "w"))
  {
    bState = !_stricmp(szCommand[1], "ON") || !_stricmp(szCommand[1], "1");
    status = rssgt_SetAttributeViBoolean(instrumentHandle, HWINDEX1, RSSGT_ATTR_IQ_WIDEBAND_ENABLED, bState);

  }
  else if (!strcmp(szCommand[0], "w?"))
  {
    status = rssgt_GetAttributeViBoolean(instrumentHandle, HWINDEX1, RSSGT_ATTR_IQ_WIDEBAND_ENABLED, &bState);
    if (status >= VI_SUCCESS)
      printf("IQ Wideband State = %s\n", bState ? "ON" : "OFF");
  }

  else if (!strcmp(szCommand[0], "i?"))
  {
    status = rssgt_GetAttributeViString(instrumentHandle, HWINDEX1, RSSGT_ATTR_ID_QUERY_RESPONSE, BUFFERSIZE, buffer);

    if (status >= VI_SUCCESS)
      printf("%s\n", buffer);
  }

  else if (!strcmp(szCommand[0], "af?"))
  {

    status = rssgt_GetAttributeViInt32(instrumentHandle, HWINDEX1, RS_ATTR_OPC_TIMEOUT, &nValue1);
    if (status >= VI_SUCCESS)
      status = rssgt_SetAttributeViInt32(instrumentHandle, HWINDEX1, RS_ATTR_OPC_TIMEOUT, 120000);

    if (status >= VI_SUCCESS)
      status = rssgt_GetAttributeViInt32(instrumentHandle, HWINDEX1, RSSGT_ATTR_CALIBRATION_FREQUENCY, &nValue);
    if (status >= VI_SUCCESS && nValue == 0)
      printf("OK\n");
    else
      printf("FAIL\n");

    rssgt_SetAttributeViInt32(instrumentHandle, HWINDEX1, RS_ATTR_OPC_TIMEOUT, nValue1);

  }
  // Set / get digital attenuation ------------------------- 
  else if (!strcmp(szCommand[0], "d"))
  {
    status = rssgt_SetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_RF_ATTENUATION_DIGITAL, atof(szCommand[1]));
  }
  else if (!strcmp(szCommand[0], "d?"))
  {
    status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_RF_ATTENUATION_DIGITAL, &dValue);

    if (status >= VI_SUCCESS)
      printf("Attenuation = %f dB\n", dValue);
  }
  // Set / get frequency offset ------------------------- 
  else if (!strcmp(szCommand[0], "fo"))
  {
    size_t len = strlen(szCommand[1]);
    double value = atof(szCommand[1]);
    if (len > 3 || *szCommand[2])
    {
      if (!_stricmp(szCommand[1] + len - 3, "mhz") || !_stricmp(szCommand[2], "mhz"))
        value *= 1e6;
    }
    status = rssgt_SetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_BB_FREQUENCY_OFFSET, value);

  }
  else if (!strcmp(szCommand[0], "fo?"))
  {
    status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_BB_FREQUENCY_OFFSET, &dValue);

    if (status >= VI_SUCCESS)
    {
      if (dValue > 1e6)
        printf("Frequency Offset = %f MHz\n", dValue / 1e6);
      else
        printf("Frequency Offset = %f Hz\n", dValue);
    }
  }
  // Set / get phase offset ------------------------- 
  else if (!strcmp(szCommand[0], "po"))
  {
    status = rssgt_SetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_BB_PHASE_OFFSET, atof(szCommand[1]));
  }
  else if (!strcmp(szCommand[0], "po?"))
  {
    status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_BB_PHASE_OFFSET, &dValue);

    if (status >= VI_SUCCESS)
      printf("Phase Offset  = %f\n", dValue);
  }

  // Trigger Arb -----------------
  else if (!strcmp(szCommand[0], "t"))
  {
    status = rssgt_SetAttributeViInt32(instrumentHandle, HWINDEX1, RSSGT_ATTR_ARB_EXECUTE_TRIGGER, 0);
  }

  // Set / get rosc source ------------------------- 
  else if (!strcmp(szCommand[0], "ro"))
  {
    nValue = -1;
    if (!_stricmp(szCommand[1], "INT"))
      nValue = RSSGT_VAL_ROSC_SOURCE_INTERNAL;
    else if (!_stricmp(szCommand[1], "EXT"))
      nValue = RSSGT_VAL_ROSC_SOURCE_EXTERNAL;

    status = rssgt_SetAttributeViInt32(instrumentHandle, HWINDEX1, RSSGT_ATTR_REFERENCE_OSCILLATOR_SOURCE, nValue);
    // default status checking was disabled. Check explicitly 
    if (status >= 0)
    {
      status = rssgt_CheckStatus(instrumentHandle);
      if (status == RS_ERROR_INSTRUMENT_STATUS)
      {
        rssgt_GetAttributeViString(instrumentHandle, HWINDEX1, RSSGT_ATTR_SYSTEM_ERROR, BUFFERSIZE, buffer);
        printf("%s\n", buffer);
        status = 0;
      }
    }
  }
  else if (!strcmp(szCommand[0], "ro?"))
  {
    status = rssgt_GetAttributeViInt32(instrumentHandle, HWINDEX1, RSSGT_ATTR_REFERENCE_OSCILLATOR_SOURCE, &nValue);
    if (status >= 0)
      printf("Rosc Source = %s\n", nValue ? "EXT" : "INT");
  }

  // Trigger Next Segment -----------------
  else if (!strcmp(szCommand[0], "n"))
  {
    SET_RTS();
    status = rssgt_SetAttributeViInt32(instrumentHandle, HWINDEX1, RSSGT_ATTR_ARB_MULTISEGMENT_EXECUTE_NEXT_SEGMENT, 0);
    CLR_RTS();
  }

  // Set / get next wseg ------------------------- 
  else if (!strcmp(szCommand[0], "ns"))
  {
    SET_RTS();
    status = rssgt_SetAttributeViReal64(instrumentHandle, "", RSSGT_ATTR_ARB_MULTISEGMENT_OUTPUT_SEGMENT, atof(szCommand[1]));
    CLR_RTS();
  }
  else if (!strcmp(szCommand[0], "ns?"))
  {
    status = rssgt_GetAttributeViReal64(instrumentHandle, "", RSSGT_ATTR_ARB_MULTISEGMENT_OUTPUT_SEGMENT, &dValue);

    if (status >= VI_SUCCESS)
      printf("Next Segment  = %3f\n", dValue);
  }

  // Set / get next wseg source ------------------------- 
  else if (!strcmp(szCommand[0], "nss"))
  {
    nValue = -1;
    if (!_stricmp(szCommand[1], "INT"))
      nValue = RSSGT_VAL_ROSC_SOURCE_INTERNAL;
    else if (!_stricmp(szCommand[1], "NEXT"))
      nValue = RSSGT_VAL_ROSC_SOURCE_EXTERNAL;

    status = rssgt_SetAttributeViInt32(instrumentHandle, HWINDEX1, RSSGT_ATTR_ARB_MULTISEGMENT_NEXT_SEGMENT_SOURCE, nValue);

  }

  else if (!strcmp(szCommand[0], "nss?"))
  {
    status = rssgt_GetAttributeViInt32(instrumentHandle, HWINDEX1, RSSGT_ATTR_ARB_MULTISEGMENT_NEXT_SEGMENT_SOURCE, &nValue);
    if (status >= 0)
      printf("Wseg Next Source = %s\n", nValue ? "NEXT" : "INT");
  }

  else if (!strcmp(szCommand[0], "tt"))
  {
    int nloops = *szCommand[2] ? atoi(szCommand[2]) : 100;


    double Frequencies[] = { 1e6, 2e9 };
    int nFrequenciesCount = sizeof(Frequencies) / sizeof(Frequencies[0]);

    double Levels[] = { 0,-2,-4,-6,-8,-10,-12,-14,-16,-18,-20 };
    int nLevelsCount = sizeof(Levels) / sizeof(Levels[0]);

    double DigAtts[] = { 0,2,4,6,8,10,12,14,16,18,20 };
    int nDigAttsCount = sizeof(DigAtts) / sizeof(DigAtts[0]);

    double OnOff[] = { 0,1 };
    int nOnOffCount = sizeof(OnOff) / sizeof(OnOff[0]);

    double Events[] = { 0,1 };
    int nEventsCount = sizeof(Events) / sizeof(Events[0]);

    double SegmentIndices[] = { 0,1 };
    int nSegmentIndicesCount = sizeof(SegmentIndices) / sizeof(SegmentIndices[0]);

    if (!_stricmp(szCommand[1], "f") || *szCommand[1] == 0)
      TestExecutionTime(instrumentHandle, RSSGT_ATTR_RF_FREQUENCY, Frequencies, nFrequenciesCount, FALSE, "Frequency", nloops);
    else if (!_stricmp(szCommand[1], "l"))
      TestExecutionTime(instrumentHandle, RSSGT_ATTR_RF_AMPLITUDE, Levels, nLevelsCount, FALSE, "Level", nloops);
    else if (!_stricmp(szCommand[1], "d"))
      TestExecutionTime(instrumentHandle, RSSGT_ATTR_RF_ATTENUATION_DIGITAL, DigAtts, nDigAttsCount, FALSE, "Digital Attenuation", nloops);

    else if (!_stricmp(szCommand[1], "r"))
      TestExecutionTime(instrumentHandle, RSSGT_ATTR_OUTPUT_ENABLED, OnOff, nOnOffCount, TRUE, "RF state", nloops);
    else if (!_stricmp(szCommand[1], "n"))
      TestExecutionTime(instrumentHandle, RSSGT_ATTR_ARB_MULTISEGMENT_EXECUTE_NEXT_SEGMENT, Events, nEventsCount, TRUE, "Next Segment", nloops);

    else if (!_stricmp(szCommand[1], "ns"))
      TestExecutionTime(instrumentHandle, RSSGT_ATTR_ARB_MULTISEGMENT_OUTPUT_SEGMENT, SegmentIndices, nSegmentIndicesCount, FALSE, "Next Segment Index", nloops);

    else if (!_stricmp(szCommand[1], "ps"))
      TestPowerServoingTime(instrumentHandle, nloops);


    else
      printf("Unknown argument. Use f,l,d,r,n,ns,ps\n");

  }
  else if (!strcmp(szCommand[0], "ws"))
  {
    char szArg[1000] = { 0 };
    int i = 1;
    while (*szCommand[i])
    {
      strcat(szArg, szCommand[i]);
      strcat(szArg, " ");
      i++;
    }
    status = rssgt_WriteInstrData(instrumentHandle, szArg);
  }

  // Set / get fast mode ------------------------- 
  else if (!strcmp(szCommand[0], "fm"))
  {
    useFastSettings = !_stricmp(szCommand[1], "ON") || !_stricmp(szCommand[1], "1");

    if (useFastSettings)
    {
      if (!_stricmp(szCommand[2], "ON") || !_stricmp(szCommand[2], "1"))
        enableAsynchronousFastSettings = VI_TRUE;

      else if (!_stricmp(szCommand[2], "OFF") || !_stricmp(szCommand[2], "0"))
        enableAsynchronousFastSettings = VI_FALSE;
    }

    status = rssgt_UseFastSettings(instrumentHandle, useFastSettings, enableAsynchronousFastSettings);

  }
  else if (!strcmp(szCommand[0], "fm?"))
  {
    status = rssgt_GetFastSettings(instrumentHandle, &useFastSettings, &enableAsynchronousFastSettings);

    printf("Fast Mode = %s\n", useFastSettings ? "ON" : "OFF");
    if (useFastSettings)
      printf("Async Settings = %s\n", enableAsynchronousFastSettings ? "ON" : "OFF");


  }
  else if (!strcmp(szCommand[0], "scpi"))
  {
    char szArg[1000] = { 0 };
    int i = 1;
    while (*szCommand[i])
    {
      strcat(szArg, szCommand[i]);
      strcat(szArg, " ");
      i++;
    }
    status = rssgt_WriteInstrData(instrumentHandle, szArg);
  }
  else if (!strcmp(szCommand[0], "scpi?"))
  {
    char szArg[1000] = { 0 };
    int i = 1;
    ViUInt32 nBytesRead = 0;
    while (*szCommand[i])
    {
      strcat(szArg, szCommand[i]);
      strcat(szArg, " ");
      i++;
    }
    status = rssgt_WriteInstrData(instrumentHandle, szArg);
    status = rssgt_ReadInstrData(instrumentHandle, 1000, szArg, &nBytesRead);
    szArg[nBytesRead] = 0;

    printf("%s", szArg);
  }


  // Test ------------------------- 
  else if (!strcmp(szCommand[0], "test"))
  {
    ViBoolean bValue;
    ViReal64 level_Peak;
    ViReal64 level_Average;
    ViChar binaryBlockData[1000];
    ViUInt32 bytesRead = 0;

    status = rssgt_MMEMoryBlockDataRead(instrumentHandle, "/var/instrument/100Bytes.bin",1000, binaryBlockData, &bytesRead);
    printf("status = 0x%x %s\n\n", status , DecodeVisaError(status));


    printf("bytes read = %d\n\n",bytesRead);
    for (unsigned int  i = 0; i < bytesRead; i++)
    {
      printf("%2x ",binaryBlockData[i]);
      if ((i % 8)== 0)
        printf("\n");
    }


    //status = rssgt_GetAttributeViInt32(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_SENSOR, &nValue);
    //status = rssgt_SetAttributeViInt32(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_SENSOR, RSSGT_VAL_POWER_CONTROL_SENSUNDEF);
    //status = rssgt_GetAttributeViInt32(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_SENSOR, &nValue);


    status = rssgt_SetAttributeViInt32(instrumentHandle, HWINDEX1, RSSGT_ATTR_CONNECTOR_OPERATION_MODE, RSSGT_VAL_CONN_OPMODE_MKR2);

    status = rssgt_SetAttributeViInt32(instrumentHandle, HWINDEX1, RSSGT_ATTR_CONNECTOR_OUTPUT, RSSGT_VAL_CONNECTOR_OUTPUT_OFF);

    status = rssgt_ReadPowerMeasurement(instrumentHandle, 2, &level_Peak, &level_Average);
    status = rssgt_ReadPowerMeasurement(instrumentHandle, 1, &level_Peak, &level_Average);

    status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_IQ_OUTPUT_IMPAIRMENTS_LEAKAGE_Q, &dValue);
    status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_IQ_OUTPUT_IMPAIRMENTS_PHASE_OFFSET, &dValue);
    status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_IQ_OUTPUT_IMPAIRMENTS_DELAY, &dValue);

    status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_POWER_READ_POWER, &dValue);

    status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_TARGET, &dValue);
    status = rssgt_SetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_TARGET, 1.23);
    status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_TARGET, &dValue);


    status = rssgt_GetAttributeViBoolean(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_STATE, &bValue);
    status = rssgt_SetAttributeViBoolean(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_STATE, VI_TRUE);
    status = rssgt_GetAttributeViBoolean(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_STATE, &bValue);

    status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_TOL, &dValue);
    status = rssgt_SetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_TOL, 0.15);
    status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_TOL, &dValue);

    status = rssgt_GetAttributeViInt32(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_TEST, &nValue);

    status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_APER, &dValue);
    status = rssgt_SetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_APER, 0.0015);
    status = rssgt_GetAttributeViReal64(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_APER, &dValue);


    status = rssgt_GetAttributeViBoolean(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_TRACK, &bValue);
    status = rssgt_SetAttributeViBoolean(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_TRACK, VI_TRUE);
    status = rssgt_GetAttributeViBoolean(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_TRACK, &bValue);



    status = rssgt_PowerServoingSet(instrumentHandle, 4, &nValue);

  }


  else
  {
    printf("Unknown command\n");
  }

  if (status < 0)
  {
    if (status == RS_ERROR_INSTRUMENT_STATUS)
    {
      rssgt_GetAttributeViString(instrumentHandle, HWINDEX1, RSSGT_ATTR_SYSTEM_ERROR, BUFFERSIZE, buffer);
      printf("%s\n", buffer);
    }
    else
    {
      printf("%s\n", DecodeVisaError(status));
    }

  }


  return status;
}


// ---------------------------------------------------------------------
//
// ---------------------------------------------------------------------

void WaitForEnterPressed()
{
#ifndef __linux__    
  printf("Press Enter ...");
  getchar();
#endif  

}

// ---------------------------------------------------------------------
//
// ---------------------------------------------------------------------

int main(int argc, char* argv[])
{
  ViBoolean idQuery = VI_FALSE;
  ViBoolean resetDevice = VI_FALSE;
  ViSession instrumentHandle = 0;
  char buffer[BUFFERSIZE] = { 0 };
  ViChar instrumentIdentification[BUFFERSIZE];
  ViStatus status = 0;
  ViInt32 errorCode = 0;
  ViBoolean WaitforKey = 0;


  if (argc < 2 || (argc == 2 && !strcmp(argv[1], "-?")))
  {
    printf("Usage: SgtDriverDemo resourcestring |-e|-?\n\n" \
      "resourcestring:\n" \
      "\tTCPIP::ipaddress::[hislip0::]INSTR\n" \
      "\tTCPIP::ipaddress::5025::SOCKET\n" \
      "\tUSB::0x0aad::0x0088::serialno::INSTR\n" \
      "\tPCIE::0x0162f::0x1336::serialno::INSTR\n" \
      "\ttcpip\n" \
      "\tpcie\n" \
    );

    WaitForEnterPressed();
    return 0;
  }

  InitControlSerial();

  INIT_SERIAL();


  rssgt_openLog(100, TRUE, FALSE);
  //  rssgs_setMaxLogCallDepth(1);
  rssgt_setLogWrapStartIndex(10);


  strcpy(buffer, argv[1]);
  strcpy(g_szResourceString, argv[1]);

  if (argc == 2 && !_stricmp(argv[1], "pcie"))
  {
    ViInt32 SerialNumbers[100] = { 0 };
    ViInt32 nSerialNumberCount = 100;

    status = rssgt_enumerate_pcie_devices(0x162f, 0x1336, SerialNumbers, &nSerialNumberCount);
    if (status >= VI_SUCCESS)
    {
      int nSelection = -1;
      int i = 0;
      printf("Found %d SGT device(s) on the PCIe bus:\n", (int)nSerialNumberCount);
      if (nSerialNumberCount == 0)
        return 0;

      for (i = 0; i < nSerialNumberCount; i++)
        printf("%d\n", (int)SerialNumbers[i]);
      printf("\n");

      if (nSerialNumberCount == 1)
      {
        nSelection = 0;
      }
      else
      {
        int c = 0;
        printf("Select serial number (1...%d or hit ESC) ", (int)nSerialNumberCount);
        do
        {
          c = _getch();
          if (c - '0' >= 1 && c - '0' <= nSerialNumberCount)
          {
            nSelection = c - '0' - 1;
            printf("%c\n", c);
            break;
          }
        } while (c != 27); // ESC
      }
      if (nSelection < 0)
      {
        printf("\n");
        return 0;
      }
      sprintf(buffer, "PCIe::0x162f::0x1336::%d::INSTR", (int)SerialNumbers[nSelection]);
      printf("Connecting to device %d\n", (int)SerialNumbers[nSelection]);
    }
  }
  else if (argc == 2 && !_stricmp(argv[1], "tcpip"))
  {
    int i;
    ViInt32 infoCount = 0;
    typedef char INFOTEXT[64]; // reserve 64 chars for IP address, type , serial no


    // get number of devices first
    status = rssgt_enumerate_socket_devices(NULL, &infoCount);
    if (infoCount > 0)
    {
      // allocate enough space for device info texts
      INFOTEXT** infoList = calloc(infoCount, sizeof(INFOTEXT*));
      for (i = 0; i < infoCount; i++)
        infoList[i] = calloc(1, sizeof(INFOTEXT));

      // get device info 
      status = rssgt_enumerate_socket_devices((ViPString *)infoList, &infoCount);
      if (status >= VI_SUCCESS)
      {
        int nSelection = -1;
        char* p = 0;
        printf("Found %d device(s):\n", (int)infoCount);
        if (infoCount == 0)
          return 0;

        for (i = 0; i < infoCount; i++)
          printf("%s\n", (char*)infoList[i]);
        printf("\n");

        if (infoCount == 1)
        {
          nSelection = 0;
        }
        else
        {
          int c = 0;
          printf("Select number (1...%d or hit ESC) ", (int)infoCount);
          do
          {

            c = _getch();
            if (c - '0' >= 1 && c - '0' <= (int)infoCount)
            {
              nSelection = c - '0' - 1;
              printf("%c\n", c);
              break;
            }
          } while (c != 27); // ESC
        }
        if (nSelection < 0)
        {
          printf("\n");
          return 0;
        }

        p = strrchr((const char*)infoList[nSelection], (int)',');
        if (p)
        {
          printf("Connecting to %s\n", p + 1);
          sprintf(buffer, "TCPIP::%s::5025::SOCKET", p + 1);
        }
        for (i = 0; i < infoCount; i++)
          free(infoList[i]);
        free(infoList);
      }
    }
    else
    {
      printf("No devices found\n");
    }
  }

  // dummy do-while provides structured exit point in case of errors
  do
  {
    status = rssgt_init(buffer, idQuery, resetDevice, &instrumentHandle);
    if (status)
    {
      rssgt_error_message(instrumentHandle, status, buffer);

      if (status < 0)
      {
        printf("open FAILED status = 0x%x (%s)\n", (int)status, buffer);
        WaitforKey = 1;
        break;
      }
    }

    status = rssgt_error_query(instrumentHandle, &errorCode, buffer);
    if (errorCode)
      printf("\n%s", buffer);
    if (status < 0)
    {
      WaitforKey = 1;
      break;
    }

    status = rssgt_GetAttributeViString(instrumentHandle, HWINDEX1, RSSGT_ATTR_ID_QUERY_RESPONSE, BUFFERSIZE, instrumentIdentification);
    if (status < 0)
    {
      rssgt_error_message(instrumentHandle, status, buffer);
      printf("rsSgt_IdentificationQuery failed %s\n", buffer);
      WaitforKey = 1;
      break;
    }
    else
    {
      if (strstr(instrumentIdentification, "SGT"))
      {
      }
      else
      {
        printf("Unknown Device Type\n");
        //WaitforKey = 1; 
        //break;
      }
    }


    status = rssgt_UseFastSettings(instrumentHandle, useFastSettings, enableAsynchronousFastSettings);
    if (status < 0)
    {
      WaitforKey = 1;
      break;
    }
    status = rssgt_error_query(instrumentHandle, &errorCode, buffer);
    if (errorCode)
      printf("\n%s", buffer);
    if (status < 0)
    {
      WaitforKey = 1;
      break;
    }

    // turn off default status checking      
    status = rssgt_SetAttributeViBoolean(instrumentHandle, 0, RS_ATTR_QUERY_INSTRUMENT_STATUS, VI_FALSE);

    // turn off status checking for one specific attribute only     
    //Rs_GetAttributeFlags (instrumentHandle, RSSGT_ATTR_REFERENCE_OSCILLATOR_SOURCE, &flags);   
    //flags |= RS_VAL_DONT_CHECK_STATUS;
    //status = Rs_SetAttributeFlags (instrumentHandle, RSSGT_ATTR_REFERENCE_OSCILLATOR_SOURCE,flags);   
    //if (status < 0)   
    //{
    //  WaitforKey = 1; 
    //  break;
    //}

    // turn on *OPC? for specific command
    //Rs_GetAttributeFlags (instrumentHandle, RSSGT_ATTR_RF_FREQUENCY, &flags);   
    //flags |= RS_VAL_WAIT_FOR_OPC_AFTER_WRITES;
    //status = Rs_SetAttributeFlags (instrumentHandle, RSSGT_ATTR_RF_FREQUENCY,flags);   
    //if (status < 0)   
    //{
    //  WaitforKey = 1; 
    //  break;
    //}


    CommandLoop(instrumentHandle);
  } while (0);

  if (status < 0)
  {
    rssgt_error_message(instrumentHandle, status, buffer);
    printf("VisaError: %s\n", buffer);
  }

  rssgt_GetAttributeViString(instrumentHandle, HWINDEX1, RSSGT_ATTR_SYSTEM_ERROR_QUEUE_ALL, BUFFERSIZE, buffer);
  if (status >= VI_SUCCESS && buffer[0] != '0')
    printf("\nError queue = %s\n", buffer);


  rssgt_close(instrumentHandle);

  printf("\n");

  if (argc == 2 || WaitforKey)
    WaitForEnterPressed();

#ifndef __linux__
  rssgt_saveLog("C:\\Temp\\SgtLog.xml");
#else
  rssgt_saveLog("~/SgtLog.xml");
#endif


  return 0;
}

// ---------------------------------------------------------------------
//
// ---------------------------------------------------------------------


// Enter commands on the command line
void CommandLoop(ViSession instrumentHandle)
{
  char buffer[1000];
  COMMAND Command;
  int i = 0;
  int c = 0;

  sprintf(Command[0], "?");


  printf("SgtDriverDemo %s\n", g_szResourceString);
  printf("-------------\n");

  printf("Instrument driver version ");
  printf("Sgt: %d", SgtDriverVersion);
  printf("\n\n");

  do
  {
    if (!strcmp(Command[0], "q"))
    {
      break;
    }
    else
    {
      InterpretCommand(instrumentHandle, Command);
    }


    c = 0;
    for (i = 0; i < MAXCMDSIZE; i++)
      Command[i][0] = 0;

    printf("Enter command >");
    for (i = 0; i < 1000 - 1 && c != '\n'; )
    {
      c = getchar();
      if (c != '\n')
      {
        buffer[i++] = (char)c;
      }
      buffer[i] = 0;
    }
    sscanf(buffer, "%s%s%s%s%s%s", (char*)(Command + 0), (char*)(Command + 1), (char*)(Command + 2), (char*)(Command + 3), (char*)(Command + 4), (char*)(Command + 5));

  } while (1);

  CLOSE_SERIAL();
}

// ---------------------------------------------------------------------
//
// ---------------------------------------------------------------------

void TestExecutionTime(int instrumentHandle, int attribute, double* Values, int nValuesCount, BOOL selecttype, const char* szCaption, int nloops)
{
  int nValueIndex = 0;
  double dTInstructionAvg = 0;
  int i = 0;
  int* timearray = calloc(nloops, sizeof(int));
  if (timearray == 0)
  {
    printf("Cannot allocate array\n");
    exit(1);
  }

  determineProcessorClockrate();

  for (i = 0; i < nloops; i++)
  {
    double executiontime = 0;
    double dValue = Values[nValueIndex];
    nValueIndex++;
    if (nValueIndex >= nValuesCount)
      nValueIndex = 0;

    SET_RTS();

    getClockInMicroSeconds(0);
    if (selecttype)
      rssgt_SetAttributeViInt32(instrumentHandle, HWINDEX1, attribute, (int)dValue);
    else
      rssgt_SetAttributeViReal64(instrumentHandle, HWINDEX1, attribute, dValue);

    if (useFastSettings == VI_FALSE)
      rssgt_FastSync(instrumentHandle);
    executiontime = getClockInMicroSeconds(1);
    dTInstructionAvg += executiontime;
    timearray[i] = (int)executiontime;

    CLR_RTS();
    //    Sleep (1);

  }

  dTInstructionAvg /= nloops;
  printf("Avg. round trip time (%s) = %5.0f us\n", szCaption, dTInstructionAvg);
  {
    const char* szFileName = "executiontimes.csv";
    FILE* f = fopen(szFileName, "w");
    if (f)
    {
      for (i = 0; i < nloops; i++)
        fprintf(f, "%d\n", timearray[i]);
      fclose(f);
      printf("Saved execution time array to %s\n", szFileName);
    }

  }
  free(timearray);
}


// ---------------------------------------------------------------------
//
// ---------------------------------------------------------------------

void TestPowerServoingTime(int instrumentHandle, int nloops)
{
  int nValueIndex = 0;
  ViInt32 result;
  double dTInstructionAvg = 0;
  double dTInstructionMin = 1e37;
  double dTInstructionMax = 0;

  int i = 0;
  int j = 0;
  double Values[] = { -10, -5, 0, 5, 10, 14,5 }; // , 5};
//  double Values[] = { 10, 12, 13, 14, 14.25, 14.5 }; 
  int nValuesCount = sizeof(Values) / sizeof(Values[0]);
  int* timearray = calloc(nloops, sizeof(int));
  const char* szCaption = "Power Servoing";



  if (timearray == 0)
  {
    printf("Cannot allocate array\n");
    exit(1);
  }

  rssgt_SetAttributeViBoolean(instrumentHandle, HWINDEX1, RSSGT_ATTR_PSER_STATE, VI_TRUE);

  determineProcessorClockrate();

  for (i = 0; i < nloops; i++)
  {
    double executiontime = 0;


    //nValueIndex = rand() % nValuesCount;
    double dValue = Values[nValueIndex];
    nValueIndex++;
    if (nValueIndex >= nValuesCount)
      nValueIndex = 0;




    SET_RTS();
    getClockInMicroSeconds(0);

    rssgt_PowerServoingSet(instrumentHandle, dValue, &result);
    if (result)
    {
      char buffer[BUFFERSIZE];
      printf("Fail\n");
      rssgt_GetAttributeViString(instrumentHandle, HWINDEX1, RSSGT_ATTR_SYSTEM_ERROR, BUFFERSIZE, buffer);
      printf("%s\n", buffer);
      break;
    }

    if (useFastSettings == VI_FALSE)
      rssgt_FastSync(instrumentHandle);

    CLR_RTS();

    executiontime = getClockInMicroSeconds(1);
    if (executiontime < 1000000)
    {
      dTInstructionAvg += executiontime;
      timearray[j] = (int)executiontime;
      j++;
      if (executiontime > dTInstructionMax)
        dTInstructionMax = executiontime;

      if (executiontime < dTInstructionMin)
        dTInstructionMin = executiontime;
    }
    else
    {
      printf("long execution %6.0f ms @ %3.0f dBm\n", executiontime / 1e3, dValue);
    }

    //    Sleep (1);

    //dValue += dValueStep;
    //if (dValue > dValueStop)
    //  dValue = dValueStart;

  }

  dTInstructionAvg /= j;
  printf("Avg. round trip time (%s) = %5.1f ms, (Min = %5.1f ms, Max = %5.1f ms)\n", szCaption, dTInstructionAvg / 1e3, dTInstructionMin / 1e3, dTInstructionMax / 1e3);
  {
    const char* szFileName = "executiontimes.csv";
    FILE* f = fopen(szFileName, "w");
    if (f)
    {
      for (i = 0; i < j; i++)
        fprintf(f, "%d\n", timearray[i]);
      fclose(f);
      printf("Saved execution time array to %s\n", szFileName);
    }

  }
  free(timearray);
}



// #################################################################


/* METHOD ********************************************************************/
/**
Initializes static variable (g_dProcessorClockrate).
*
@precondition
@postcondition
@side_effects
*
@param
*
@return true when OK
@exception
******************************************************************************/
BOOL determineProcessorClockrate()
{
  if (g_dProcessorClockrate < 0)
  {

#ifdef __linux__
    // Read clockrate from /proc
# ifdef __powerpc__
    const char* tag[] = { "clock" };
    std::ifstream f;
    f.open("/proc/cpuinfo");
    if (f.is_open()) for (std::string str; !f.eof();)
    {
      f >> str;
      if (str == tag[0])
      {
        f >> str;
        f >> str;
        g_dProcessorClockrate = 1E6 * atof(str.c_str());
        break;
      }
    }
#else
    const char* tag[] = { "cpu", "MHz" };
    FILE* file = fopen("/proc/cpuinfo", "r");
    if (file)
    {
      char str[1000];
      int rc = 0;
      do
      {
        rc = fscanf(file, "%s", str);
        if (rc != 1)
          break;
        if (!strcmp(str, tag[0]))
        {
          rc = fscanf(file, "%s", str);
          if (!strcmp(str, tag[1]))
          {
            rc = fscanf(file, "%s", str);
            rc = fscanf(file, "%s", str);
            g_dProcessorClockrate = 1E6 * atof(str);

            break;
          }
        }
      } while (rc == 1);
    } // file
#endif // !power PC
#else
    // Read clockrate from registry
    HKEY hKey;
    if (ERROR_SUCCESS == RegOpenKeyEx(HKEY_LOCAL_MACHINE, L"HARDWARE\\DESCRIPTION\\System\\CentralProcessor\\0", 0, KEY_READ, &hKey)) //lint !e1924
    {
      DWORD valType;
      DWORD valSize = sizeof(DWORD);
      DWORD val;
      const BOOL ok = (ERROR_SUCCESS == RegQueryValueEx(hKey, L"~MHz", 0, &valType, (BYTE*)&val, &valSize)); //lint !e1924
      RegCloseKey(hKey);
      if (ok && REG_DWORD == valType)
      {
        g_dProcessorClockrate = 1E6 * val;
      }
    }
#endif // Windows
  }
  // Plausibility test
  return g_dProcessorClockrate > 1E7;
}

// ---------------------------------------------------------------------
//
// ---------------------------------------------------------------------
double getProcessorClockrate()
{
  return g_dProcessorClockrate;
}

// ---------------------------------------------------------------------
//
// ---------------------------------------------------------------------
#ifndef __linux__
#  pragma warning(disable:4035)
#endif
__int64 readProcessorClock()
{
#ifdef __linux__
# ifdef __powerpc__
  unsigned long int upper, lower, tmp;
  __asm__ __volatile__(
    "1:\n\t"
    "mftbu %0\n\t"
    "mftb  %1\n\t"
    "mftbu %2\n\t"
    "cmpw  %2,%0\n\t"
    "bne   1b\n"
    : "=r"(upper), "=r"(lower), "=r"(tmp)
  );
  unsigned long long result(upper);
  return ((result << 32) | lower) * 6;
# else
  __int64 val; __asm__ __volatile__("rdtsc" : "=&A" (val)); return val;
# endif
#else
  return __rdtsc();
  //   __asm { RDTSC }
#endif
}


// ---------------------------------------------------------------------
//
// ---------------------------------------------------------------------
double readSeconds()
{
  return readProcessorClock() / g_dProcessorClockrate;
}

// ---------------------------------------------------------------------
//
// ---------------------------------------------------------------------
double getClockInMicroSeconds(BOOL bIsToCalculate)
{
  static long long sliClockTicksActual = 0;
  if (bIsToCalculate == 1)
  {
    long long liClockTicksPrev = sliClockTicksActual;
    sliClockTicksActual = readProcessorClock();
    if (sliClockTicksActual < liClockTicksPrev)
    {
      //case with type long long overflow
      return ((double)((LLONG_MAX - liClockTicksPrev + 1 + sliClockTicksActual)) /
        (getProcessorClockrate() /*[Hz]*/ * 1.e-6 /*[micro-seconds]*/));
    }
    else
    {
      //normal case
      return ((double)((sliClockTicksActual - liClockTicksPrev)) /
        (getProcessorClockrate() /*[Hz]*/ * 1.e-6) /*[micro-seconds]*/);
    }
  }
  else
  {
    //initial case
    sliClockTicksActual = readProcessorClock();
    return (0. /*[micro-seconds]*/);
  }
}


// ---------------------------------------------------------------------
// Functions for controlling the pins of a serial interface
// using an external DLL
// ---------------------------------------------------------------------

void InitControlSerial()
{
#ifndef __linux__

  void* handle = LoadLibraryA("ControlSerial.dll");
  if (handle)
  {
    SerialOpen = (FuncSerialOpen)GetProcAddress(handle, "SerialOpen");
    SerialClose = (FuncSerialClose)GetProcAddress(handle, "SerialClose");
    SerialSetRTS = (FuncSerialSetRTS)GetProcAddress(handle, "SerialSetRTS");
    SerialSetDTR = (FuncSerialSetDTR)GetProcAddress(handle, "SerialSetDTR");
  }
#endif
}

void SET_RTS()
{
  if (SerialSetRTS)
    SerialSetRTS(SerialHandle, 1);
}

void CLR_RTS()
{
  if (SerialSetRTS)
    SerialSetRTS(SerialHandle, 0);
}

void SET_DTR()
{
  if (SerialSetDTR)
    SerialSetDTR(SerialHandle, 1);
}

void CLR_DTR()
{
  if (SerialSetDTR)
    SerialSetDTR(SerialHandle, 0);
}

void INIT_SERIAL()
{
  if (SerialOpen)
    SerialHandle = SerialOpen("COM1");
}

void CLOSE_SERIAL()
{
  if (SerialClose)
    SerialClose(SerialHandle);
}


