''' install binary archive from zip file to site-package folder'''

import site
import os
import shutil
import zipfile
import sys

if __name__ == "__main__":

    if len(sys.argv) < 2:
        print ("Syntax: Python Install.py zipfile [targetfolder]")
        sys.exit(-1)

    src = sys.argv[1]
    if not os.path.isfile(src):
        print ("file not found")
        sys.exit(-1)

    targetfolder = None
    if len(sys.argv) == 3:
        targetfolder = sys.argv[2]
    else:
        entries = site.getsitepackages()
        for entry in entries:
            if entry.endswith("site-packages"):
                targetfolder = entry
                break

    print ("installing <%s> to folder <%s>" %(src, targetfolder))

    if targetfolder:
        if not os.path.isdir(targetfolder):
            os.makedirs(targetfolder)

        with zipfile.ZipFile(src) as zip_file:
            for member in zip_file.namelist():
                filename = os.path.basename(member)
                if not filename:
                    continue

                source = zip_file.open(member)
                filepath = os.path.join(targetfolder, filename)

                if member.find(".egg-info") >=0:
                    lastfolder =  member.split("/")[-2]       
                    folder = os.path.join(targetfolder, lastfolder)
                    if not os.path.isdir(folder):
                        os.makedirs(folder)
                    filepath = os.path.join(folder, filename)
                elif not member.endswith (".pyd"):
                    print("%s is not a valid binary archive" % src)
                    sys.exit(-1)

                target = open(filepath, "wb")

                with source, target:
                    shutil.copyfileobj(source, target)
    else:
        print("Cannot find site-package folder")


