import rssgtpy as rssgt

rc, list = rssgt.enumerate_socket_devices()
print ("Socket devices: {}".format(list))

resourceString = "tcpip::172.29.0.47::instr"

sgt1 = rssgt.Instrument(resourceString)
if sgt1.status == 0:
    try:
        # print *IDN
        print(sgt1.IDQueryResponse())

        # set / get RF frequency
        f1 = 4.56e9
        print ("Setting frequency to %10.2f GHz" % (f1/1e9))
        sgt1.SetAttributeViReal64(rssgt.ATTR_RF_FREQUENCY, f1)
        f = sgt1.GetAttributeViReal64(rssgt.ATTR_RF_FREQUENCY)
        print ("Read: %10.2f Ghz" % (f/1e9))

        f2 = 1.23e9
        print ("Setting frequency to %10.2f GHz" % (f2/1e9))
        sgt1.SetAttributeViReal64(rssgt.ATTR_RF_FREQUENCY, f2)
        f = sgt1.GetAttributeViReal64(rssgt.ATTR_RF_FREQUENCY)
        print ("Read: %10.2f Ghz" % (f/1e9))

        # error handling
        print ("Error handling:")
        sgt1.SetAttributeViReal64(rssgt.ATTR_RF_FREQUENCY, 888e9)
        if sgt1.status:
            print("Status = %d, %s\n" % (sgt1.status, sgt1.statusMessage()))
        else:        
            print ("Error status expected!") 

        # provoke exception
        print ("Test exception:")
        sgt1.exceptionhandling = rssgt.EXCEPTION_HANDLING.WARNING
        sgt1.SetAttributeViReal64(rssgt.ATTR_RF_FREQUENCY, 999e9)
        print ("Exception expected!")
        
    except RuntimeError:
        print ("Exception occurred: %s" % sgt1.statusMessage())

    finally:
        sgt1.close()

else:
    print("cannot open %s" % resourceString)

