#include <pybind11/pybind11.h>
#include <pybind11/stl.h>
#include <pybind11/numpy.h>
#include "InstrumentDriver/rssgt.h" 


namespace py = pybind11;

static std::vector<std::string> MakeStringlist(std::string& CommaSeparatedList, bool hasQuotationmarks)
{
  std::vector<std::string> list;
  char * pch;
  pch = strtok((char*)CommaSeparatedList.data(), ",");
  while (pch != NULL)
  {
    std::string entry = std::string(pch);
    if (hasQuotationmarks)
    {
      entry.erase(0, 1);
      entry.erase(entry.size() - 1, 1);
    }
    if (!entry.empty())
      list.push_back(entry);
    pch = strtok(NULL, ",");
  }
  return list;
}

// ################### C++ Interface ########################

#define QUERYFILLSTRING(fname) .def(#fname, [](Instr &instr)\
{\
  ViChar resource[2048] = { 0 };\
  instr.status = rssgt_##fname(instr.instrumentHandle, resource);\
  instr.checkstatus();\
  return std::string(resource);\
}, "")

#define QUERYFILLSTRINGINTARG(fname, intarg) .def(#fname, [](Instr &instr, ViInt32 intarg)\
{\
  ViChar resource[2048] = { 0 };\
  instr.status = rssgt_##fname(instr.instrumentHandle, intarg, resource);\
  instr.checkstatus();\
  return std::string(resource);\
}, "", py::arg(#intarg))



#define QUERYSTRING(fname, defaultsize) .def(#fname, [](Instr &instr, ViInt32 arraySize)\
{\
  std::string Data;\
  Data.resize(arraySize,'\0');\
  instr.status = rssgt_##fname(instr.instrumentHandle, arraySize, (ViChar*)Data.data());\
  instr.checkstatus();\
  Data.erase(strlen(Data.c_str()));\
  return Data;\
},"", py::arg("arraySize") = defaultsize)

#define QUERYSTRING_INTARG(fname, intarg, defaultsize) .def(#fname, [](Instr &instr, ViInt32 intarg, ViInt32 arraySize)\
{\
  std::string Data;\
  Data.resize(arraySize,'\0');\
  instr.status = rssgt_##fname(instr.instrumentHandle, intarg, arraySize, (ViChar*)Data.data());\
  instr.checkstatus();\
  Data.erase(strlen(Data.c_str()));\
  return Data;\
},"",  py::arg(#intarg), py::arg("arraySize") = defaultsize)

#define QUERYSTRING_STRINGARG(fname, defaultsize, strarg) .def(#fname, [](Instr &instr, ViString strarg, ViInt32 arraySize)\
{\
  std::string Data;\
  Data.resize(arraySize,'\0');\
  instr.status = rssgt_##fname(instr.instrumentHandle, strarg, arraySize, (ViChar*)Data.data());\
  instr.checkstatus();\
  Data.erase(strlen(Data.c_str()));\
  return Data;\
},"",  py::arg(#strarg), py::arg("arraySize")=defaultsize)

#define QUERYSTRINGLIST(fname, defaultsize) .def(#fname, [](Instr &instr, ViInt32 arraySize)\
{\
  std::string Data;\
  Data.resize(arraySize,'\0');\
  instr.status = rssgt_##fname(instr.instrumentHandle, arraySize, (ViChar*)Data.data());\
  instr.checkstatus();\
  Data.erase(strlen(Data.c_str()));\
  std::vector<std::string> list = MakeStringlist(Data, false);\
  return list;\
},"",  py::arg("arraySize")=defaultsize)


#define QUERYSTRINGLIST_STRINGARG(fname, strarg, defaultsize) .def(#fname, [](Instr &instr, ViString strarg, ViInt32 arraySize)\
{\
  std::string Data;\
  Data.resize(arraySize,'\0');\
  instr.status = rssgt_##fname(instr.instrumentHandle, strarg, arraySize, (ViChar*)Data.data());\
  instr.checkstatus();\
  Data.erase(strlen(Data.c_str()));\
  std::vector<std::string> list = MakeStringlist(Data, false);\
  return list;\
},"",  py::arg(#strarg), py::arg("arraySize")=defaultsize)

#define QUERYSTRINGLIST_INTARG(fname,  intarg, defaultsize) .def(#fname, [](Instr &instr, ViInt32 intarg, ViInt32 arraySize)\
{\
  std::string Data;\
  Data.resize(arraySize,'\0');\
  instr.status = rssgt_##fname(instr.instrumentHandle, intarg, arraySize, (ViChar*)Data.data());\
  instr.checkstatus();\
  Data.erase(strlen(Data.c_str()));\
  std::vector<std::string> list = MakeStringlist(Data, false);\
  return list;\
},"",  py::arg(#intarg), py::arg("arraySize")=defaultsize)


struct Instr {
  enum ExceptionHandlingLevel
  {
    NOEXCEPTIONS,
    WARNING,
    ERROR,
  };

  Instr(const std::string &resource, ViBoolean IDQuery = false,  ViBoolean resetDevice = false)
  : instrumentHandle(0)
  , status (VI_SUCCESS)
  , resourceString(resource)
  , exceptionhandling(NOEXCEPTIONS)
  {
    status = rssgt_init((ViRsrc) resource.c_str(), IDQuery, resetDevice, &instrumentHandle);
  }

  Instr(const std::string &resource, ViBoolean IDQuery, ViBoolean resetDevice, ViString optionString)
  : instrumentHandle(0)
  , status(VI_SUCCESS)
  , resourceString(resource)
  , exceptionhandling(NOEXCEPTIONS)
  {
    ViSession instrumentHandle = 0;
    status = rssgt_InitWithOptions((ViRsrc)resource.c_str(),
      IDQuery,  resetDevice, optionString,  &instrumentHandle);
  }

  void checkstatus()
  {
    switch (exceptionhandling)
    {
      case NOEXCEPTIONS:
        break;
      
      case WARNING:
        if (status)
          throw(std::exception());
        break;

      case ERROR:
        if (status < 0)
          throw(std::exception());
        break;

    }
  }
  
  std::string statusMessage()
  {
    char errorMessage[2048];
    rssgt_error_message(instrumentHandle,status, errorMessage);
    return std::string(errorMessage);
  }


  ViSession instrumentHandle;
  ViStatus status;
  std::string resourceString;
  ExceptionHandlingLevel exceptionhandling;
};

void init_ex2(py::module &);


PYBIND11_MODULE(rssgtpy, m) {
    m.doc() = "Python wrapper for rssgt instrument driver";

    init_ex2(m);

    py::enum_<Instr::ExceptionHandlingLevel>(m, "EXCEPTION_HANDLING", "enum for exception handling")
      .value("NOEXCEPTIONS", Instr::NOEXCEPTIONS)
      .value("WARNING", Instr::WARNING)
      .value("ERROR", Instr::ERROR)
      ;


    m.def("enumerate_pcie_devices", [](ViInt32 vendorId, ViInt32 deviceId)
    {
      py::list serialNumbersList;
      ViInt32 serialNumbers[1000];
      ViInt32 serialNumbersCount = 0;

      ViStatus status = rssgt_enumerate_pcie_devices(vendorId,
        deviceId,
        serialNumbers,
        &serialNumbersCount);

      if (status == VI_SUCCESS && serialNumbersCount)
      {
        for (int i = 0; i < serialNumbersCount; i++)
          serialNumbersList.append(serialNumbers[i]);
      }
      return std::make_tuple(status, serialNumbersList);
    }, "", py::arg("vendorId") = 0x162f, py::arg("deviceId") = 0x1336);


    m.def("enumerate_socket_devices", []()
    {
      ViInt32 infoCount = 0;

      ViStatus status = rssgt_enumerate_socket_devices(nullptr, &infoCount);
      py::list li;

      if (status == VI_SUCCESS && infoCount)
      {
        ViPString *info = new  ViPString[infoCount];
        for (int i = 0; i < infoCount; i++)
          info[i] = new ViChar[64];

        status = rssgt_enumerate_socket_devices(info, &infoCount);
        if (status == VI_SUCCESS && infoCount)
        {
          for (int i = 0; i < infoCount; i++)
            li.append(std::string(info[i]));
        }
        for (int i = 0; i < infoCount; i++)
          delete[] info[i];
        delete[] info;
      }
      return std::make_tuple(status, li);
    }, "");





    py::class_<Instr>(m, "Instrument")
    .def(py::init<const std::string &>())
    .def(py::init<const std::string &, ViBoolean, ViBoolean>())
    .def_readwrite("exceptionhandling", &Instr::exceptionhandling)
    .def_readonly("status", &Instr::status)
    .def("statusMessage",&Instr::statusMessage)
    .def("__repr__",
        [](Instr &instr) {
            return std::string("Resource:\t") + instr.resourceString\
            + std::string("\nStatus:\t") + instr.statusMessage();
        })


 // REAL64
    .def("GetAttributeViReal64", [](Instr& instr, ViString repeatedCapabilityName, ViAttr attributeID)
    {
      ViReal64 answer = 0;
      instr.status = rssgt_GetAttributeViReal64(instr.instrumentHandle, repeatedCapabilityName, attributeID, &answer);
      instr.checkstatus();
      return answer;
    },"", py::arg("repeatedCapabilityName"),py::arg("attributeID"))

    .def("GetAttributeViReal64", [](Instr& instr, ViAttr attributeID)
    {
      ViReal64 answer = 0;
      char repeatedCapabilityName[] = "";
      instr.status = rssgt_GetAttributeViReal64(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, &answer);
      instr.checkstatus();
      return answer;
    },"", py::arg("attributeID"))

    .def("SetAttributeViReal64", []( Instr& instr, ViString repeatedCapabilityName, ViAttr attributeID, ViReal64 value)
    {
      instr.status = rssgt_SetAttributeViReal64(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, value);
      instr.checkstatus();
    }, "", py::arg("repeatedCapabilityName"),py::arg("attributeID"), py::arg("value"))

    .def("SetAttributeViReal64", [](Instr& instr, ViAttr attributeID, ViReal64 value)
    {
      char repeatedCapabilityName[] = "";  
      instr.status = rssgt_SetAttributeViReal64(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, value);
      instr.checkstatus();
    }, "", py::arg("attributeID"), py::arg("value"))

// INT32
    .def("GetAttributeViInt32", [](Instr& instr, ViString repeatedCapabilityName, ViAttr attributeID)
    {
      ViInt32 answer = 0;
      instr.status = rssgt_GetAttributeViInt32(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, &answer);
      instr.checkstatus();
      return answer;
    }, "", py::arg("repeatedCapabilityName"),py::arg("attributeID"))

    .def("GetAttributeViInt32", [](Instr& instr, ViAttr attributeID)
    {
      ViInt32 answer = 0;
      char repeatedCapabilityName[] = "";
      instr.status = rssgt_GetAttributeViInt32(instr.instrumentHandle, 
        repeatedCapabilityName, attributeID, &answer);
      instr.checkstatus();
      return answer;
    }, "", py::arg("attributeID"))

    .def("SetAttributeViInt32", [](Instr& instr, ViString repeatedCapabilityName, ViAttr attributeID, ViInt32 value)
    {
      instr.status = rssgt_SetAttributeViInt32(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, value);
      instr.checkstatus();
    }, "", py::arg("repeatedCapabilityName"),py::arg("attributeID"), py::arg("value"))

    .def("SetAttributeViInt32", [](Instr& instr, ViAttr attributeID, ViInt32 value)
    {
      char repeatedCapabilityName[] = "";  
      instr.status = rssgt_SetAttributeViInt32(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, value);
      instr.checkstatus();
    }, "", py::arg("attributeID"), py::arg("value"))
    
// Boolean
    .def("GetAttributeViBoolean", [](Instr& instr, ViString repeatedCapabilityName, ViAttr attributeID)
    {
      ViBoolean answer = 0;
      instr.status = rssgt_GetAttributeViBoolean(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, &answer);
      instr.checkstatus();
      return answer;
    }, "", py::arg("repeatedCapabilityName"),py::arg("attributeID"))

    .def("GetAttributeViBoolean", [](Instr& instr, ViAttr attributeID)
    {
      ViBoolean answer = 0;
      char repeatedCapabilityName[] = "";
      instr.status = rssgt_GetAttributeViBoolean(instr.instrumentHandle, 
        repeatedCapabilityName, attributeID, &answer);
      instr.checkstatus();
      return answer;
    }, "", py::arg("attributeID"))

    .def("SetAttributeViBoolean", [](Instr& instr, ViString repeatedCapabilityName, ViAttr attributeID, ViBoolean value)
    {
      instr.status = rssgt_SetAttributeViBoolean(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, value);
      instr.checkstatus();
    }, "", py::arg("repeatedCapabilityName"),py::arg("attributeID"), py::arg("value"))

    .def("SetAttributeViBoolean", [](Instr& instr, ViAttr attributeID, ViBoolean value)
    {
      char repeatedCapabilityName[] = "";  
      instr.status = rssgt_SetAttributeViBoolean(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, value);
      instr.checkstatus();
    }, "", py::arg("attributeID"), py::arg("value"))


// INT64
    .def("GetAttributeViInt64", [](Instr& instr, ViString repeatedCapabilityName, ViAttr attributeID)
    {
      ViInt64 answer = 0;
      instr.status = rssgt_GetAttributeViInt64(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, &answer);
      instr.checkstatus();
      return answer;
    }, "", py::arg("repeatedCapabilityName"),py::arg("attributeID"))

    .def("GetAttributeViInt64", [](Instr& instr, ViAttr attributeID)
    {
      ViInt64 answer = 0;
      char repeatedCapabilityName[] = "";
      instr.status = rssgt_GetAttributeViInt64(instr.instrumentHandle, 
        repeatedCapabilityName, attributeID, &answer);
      instr.checkstatus();
      return answer;
    }, "", py::arg("attributeID"))


    .def("SetAttributeViInt64", [](Instr& instr, ViString repeatedCapabilityName, ViAttr attributeID, ViInt64 value)
    {
      instr.status = rssgt_SetAttributeViInt64(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, value);
      instr.checkstatus();
    }, "", py::arg("repeatedCapabilityName"),py::arg("attributeID"), py::arg("value"))
    
    .def("SetAttributeViInt64", [](Instr& instr, ViAttr attributeID, ViInt64 value)
    {
      char repeatedCapabilityName[] = "";  
      instr.status = rssgt_SetAttributeViInt64(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, value);
      instr.checkstatus();
    }, "", py::arg("attributeID"), py::arg("value"))

// Session
    .def("GetAttributeViSession", [](Instr& instr, ViString repeatedCapabilityName, ViAttr attributeID)
    {
      ViSession answer = 0;
      instr.status = rssgt_GetAttributeViSession(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, &answer);
      instr.checkstatus();
      return answer;
    }, "", py::arg("repeatedCapabilityName"),py::arg("attributeID"))

    .def("GetAttributeViSession", [](Instr& instr, ViAttr attributeID)
    {
      ViSession answer = 0;
      char repeatedCapabilityName[] = "";
      instr.status = rssgt_GetAttributeViSession(instr.instrumentHandle, 
        repeatedCapabilityName, attributeID, &answer);
      instr.checkstatus();
      return answer;
    }, "", py::arg("attributeID"))

    .def("SetAttributeViSession", [](Instr& instr, ViString repeatedCapabilityName, ViAttr attributeID, ViSession value)
    {
      instr.status = rssgt_SetAttributeViSession(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, value);
      instr.checkstatus();
    }, "", py::arg("repeatedCapabilityName"),py::arg("attributeID"), py::arg("value"))

    .def("SetAttributeViSession", [](Instr& instr, ViAttr attributeID, ViSession value)
    {
      char repeatedCapabilityName[] = "";  
      instr.status = rssgt_SetAttributeViSession(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, value);
      instr.checkstatus();
    }, "", py::arg("attributeID"), py::arg("value"))

// String
    .def("GetAttributeViString", [](Instr& instr, ViString repeatedCapabilityName, ViAttr attributeID, ViInt32 bufSize)
    {
      std::string Data; \
      Data.resize(bufSize, '\0'); \
      instr.status = rssgt_GetAttributeViString(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, bufSize, (ViChar*)Data.data());
      instr.checkstatus();
      Data.erase(strlen(Data.c_str())); \
      return Data; \
    }, "", py::arg("repeatedCapabilityName"),py::arg("attributeID"), py::arg("bufSize") = 2048)

    .def("GetAttributeViString", [](Instr& instr, ViAttr attributeID, ViInt32 bufSize)
    {
      std::string Data; \
      Data.resize(bufSize, '\0'); \
      char repeatedCapabilityName[] = "";
      instr.status = rssgt_GetAttributeViString(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, bufSize, (ViChar*)Data.data());
      instr.checkstatus();
      Data.erase(strlen(Data.c_str())); \
      return Data; \
      }, "", py::arg("attributeID"), py::arg("bufSize") = 2048)


    .def("SetAttributeViString", [](Instr& instr, ViString repeatedCapabilityName, ViAttr attributeID, ViString value)
    {
      instr.status = rssgt_SetAttributeViString(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, value);
      instr.checkstatus();
    }, "", py::arg("repeatedCapabilityName"),py::arg("attributeID"), py::arg("value"))

    .def("SetAttributeViString", [](Instr& instr, ViAttr attributeID, ViString value)
    {
      char repeatedCapabilityName[] = "";  
      instr.status = rssgt_SetAttributeViString(instr.instrumentHandle,
        repeatedCapabilityName, attributeID, value);
      instr.checkstatus();
    }, "", py::arg("attributeID"), py::arg("value"))
      
// Other
    .def("IDQueryResponse", [](Instr &instr)
    {
      ViChar IDQueryResponse[1024];
      instr.status = rssgt_IDQueryResponse(instr.instrumentHandle, IDQueryResponse);
      instr.checkstatus();
      return std::string(IDQueryResponse);
    }, "")


    .def("error_query", [](Instr &instr)
    {
      ViInt32 errorCode = 0;
      ViChar errorMessage[1024] = {0};
      instr.status = rssgt_error_query(instr.instrumentHandle, &errorCode, errorMessage);
      instr.checkstatus();
      return std::make_tuple(errorCode, std::string(errorMessage));
    }, "")

    .def("error_message", [](Instr &instr, ViStatus errorCode)
    {
      ViChar errorMessage[1024] = { 0 };
      instr.status = rssgt_error_message(instr.instrumentHandle, errorCode, errorMessage);
      instr.checkstatus();
      return std::string(errorMessage);
    }, "", py::arg("errorCode"))

    .def("revision_query", [](Instr &instr)
    {
      ViChar instrumentDriverRevision[1024] = { 0 };
      ViChar firmwareRevision[1024] = { 0 };
      instr.status = rssgt_revision_query(instr.instrumentHandle, instrumentDriverRevision, firmwareRevision);
      instr.checkstatus();
      return std::make_tuple(std::string(instrumentDriverRevision), std::string(firmwareRevision));
    }, "")

    .def("GetError", [](Instr &instr)
    {
      ViStatus code = 0;
      ViChar dummy[100];
      int reqiredSize = (int)rssgt_GetError(instr.instrumentHandle, &code, 0, dummy);
      if (reqiredSize > 0)
      {
        std::vector<ViChar> description(reqiredSize);
        instr.status = rssgt_GetError(instr.instrumentHandle, &code, reqiredSize, description.data());
        instr.checkstatus();
        return std::make_tuple(code,std::string(description.data()));
      }
      else
      {
        instr.status = reqiredSize;
        instr.checkstatus();
        return std::make_tuple(code, std::string(""));
      }
    }, "")


// Place your methods here

    QUERYSTRINGLIST_STRINGARG(MMEMoryDirectoryCatalog, directoryPath, 2048)

    QUERYSTRINGLIST_STRINGARG(MMEMoryCatalog, directoryPath, 2048)

    .def("MMEMoryBlockDataRead", [](Instr &instr, ViString fileName, ViInt32 binaryBlockLength)
    {
      ViUInt32 bytesRead = 0;
      ViChar* binaryBlockData = new ViChar[binaryBlockLength];
      instr.status = rssgt_MMEMoryBlockDataRead(instr.instrumentHandle, fileName, binaryBlockLength, binaryBlockData, &bytesRead);
      instr.checkstatus();

      py::capsule free_when_done(binaryBlockData, [](void *f) {
        ViChar *foo = reinterpret_cast<ViChar *>(f);
        delete[] foo;
      });

      return py::array_t<ViChar>(
        { bytesRead }, // shape
        { sizeof(ViChar) }, // C-style contiguous strides for double
        binaryBlockData, // the data pointer
        free_when_done);
    }, "", py::arg("fileName"), py::arg("binaryBlockLength"))


    .def("MMEMoryBlockDataWrite", [](Instr &instr, ViString fileName, ViInt32 binaryBlockLength, ViChar binaryBlockData[])
    {
      instr.status = rssgt_MMEMoryBlockDataWrite(instr.instrumentHandle, fileName, binaryBlockLength, binaryBlockData);
      instr.checkstatus();
    }, "", py::arg("fileName"), py::arg("binaryBlockLength"), py::arg("binaryBlockData"))


    .def("ReadInstrData", [](Instr &instr, ViInt32 binaryBlockLength)
    {    
      ViUInt32 bytesRead = 0;
      ViChar* binaryBlockData = new ViChar[binaryBlockLength];
      instr.status = rssgt_ReadInstrData(instr.instrumentHandle, binaryBlockLength, binaryBlockData, &bytesRead);
      instr.checkstatus();

      py::capsule free_when_done(binaryBlockData, [](void *f) {
        ViChar *foo = reinterpret_cast<ViChar *>(f);
        delete[] foo;
      });

      return py::array_t<ViChar>(
        { bytesRead }, // shape
        { sizeof(ViChar) }, // C-style contiguous strides for double
        binaryBlockData, // the data pointer
        free_when_done);

    },"",py::arg("numberOfBytesToRead"))


     QUERYSTRINGLIST(ARBMultisegmentCatalog, 2048)
     QUERYSTRINGLIST(ARBMultisegmentSegmentCatalog, 2048)
     QUERYSTRINGLIST(ARBMultiCarrierFileCatalog, 2048)


    .def("CreateNewEnvelopeTrackingShapingTable", [](Instr &instr, ViString filename, std::vector<double>& vinVmax, std::vector<double>& vccVmax)
    {
      instr.status = rssgt_CreateNewEnvelopeTrackingShapingTable(instr.instrumentHandle, filename, (ViInt32)vinVmax.size(), vinVmax.data(), vccVmax.data());
      instr.checkstatus();
    }, "", py::arg("filename"), py::arg("vinVmax"), py::arg("vccVmax"))


      
    .def("ConfigureEnvelopeTrackingShapingTableData", [](Instr &instr, std::vector<ViReal64>& vinVmax, std::vector<ViReal64>& vccVmax)
    {
      instr.status = rssgt_ConfigureEnvelopeTrackingShapingTableData(instr.instrumentHandle, (ViInt32)vinVmax.size(), vinVmax.data(), vccVmax.data());
      instr.checkstatus();
    }, "", py::arg("vinVmax"), py::arg("vccVmax"))

    .def("ConfigureEnvelopeTrackingPolynomialCoefficients", [](Instr &instr, std::vector<ViReal64>& polynomialCoefficients)
    {
      instr.status = rssgt_ConfigureEnvelopeTrackingPolynomialCoefficients(instr.instrumentHandle, (ViInt32)polynomialCoefficients.size(), polynomialCoefficients.data());
      instr.checkstatus();
    }, "",  py::arg("polynomialCoefficients"))

    .def("CreateNewDigitalPredistortionShapingTable", [](Instr &instr, ViInt32 distortionType, ViString filename,  std::vector<ViReal64>& pin, std::vector<ViReal64>& delta)
    {
      instr.status = rssgt_CreateNewDigitalPredistortionShapingTable(instr.instrumentHandle, distortionType, filename, (ViInt32)pin.size(), pin.data(), delta.data());
      instr.checkstatus();
    }, "", py::arg("distortionType"), py::arg("filename"), py::arg("pin"), py::arg("delta"))

    .def("ConfigureDigitalPredistortionShapingTableData", [](Instr &instr, ViInt32 distortionType, std::vector<ViReal64>& pin, std::vector<ViReal64>& delta)
    {
      instr.status = rssgt_ConfigureDigitalPredistortionShapingTableData(instr.instrumentHandle, distortionType, (ViInt32)pin.size(), pin.data(), delta.data());
      instr.checkstatus();
    }, "", py::arg("distortionType"), py::arg("pin"), py::arg("delta"))

    .def("ConfigureDigitalPredistortionPolynomialCoefficients", [](Instr &instr, std::vector<ViReal64>& real, std::vector<ViReal64>& imaginary)
    {
      instr.status = rssgt_ConfigureDigitalPredistortionPolynomialCoefficients(instr.instrumentHandle, (ViInt32)real.size(), real.data(), imaginary.data());
      instr.checkstatus();
    }, "", py::arg("real"), py::arg("imaginary"))


    .def("WriteARBData", [](Instr &instr, ViString waveformFilename, ViInt32 binaryBlockLength, ViChar data[])
    {
      instr.status = rssgt_WriteARBData(instr.instrumentHandle, waveformFilename, binaryBlockLength, data);
      instr.checkstatus();
    }, "", py::arg("waveformFilename"), py::arg("binaryBlockLength"), py::arg("data"))

    
    QUERYSTRING_STRINGARG(ReadARBTag, 2048, tag)

    .def("ReadARBFileTag", [](Instr &instr, ViString waveformFilename, ViString tag, ViInt32 arraySize)
    {
      std::string Data;
      Data.resize(arraySize, '0');
      instr.status = rssgt_ReadARBFileTag(instr.instrumentHandle, waveformFilename, tag, arraySize, (ViChar*)Data.data());
      instr.checkstatus();
      Data.erase(strlen(Data.c_str()));
      return Data;
    }, "", py::arg("waveformFilename"), py::arg("tag"), py::arg("arraySize") = 2048)




    .def("ConfigureUserCorrectionFrequencies", [](Instr &instr, std::vector<ViReal64>& frequencies)
    {
      instr.status = rssgt_ConfigureUserCorrectionFrequencies(instr.instrumentHandle, (ViInt32)frequencies.size(), frequencies.data());
      instr.checkstatus();
    },"", py::arg("frequencies"))

    .def("ConfigureUserCorrectionPowers", [](Instr &instr, std::vector<ViReal64>& powers)
    {
      instr.status = rssgt_ConfigureUserCorrectionPowers(instr.instrumentHandle, (ViInt32)powers.size(), powers.data());
      instr.checkstatus();
    },"", py::arg("powers"))




// GeneratedMethodsStart

    .def("UseFastSettings", [](Instr &instr, ViBoolean enableFast, ViBoolean enableAsynchronous)
    {    
      instr.status = rssgt_UseFastSettings(instr.instrumentHandle, enableFast, enableAsynchronous);
      instr.checkstatus();
    },"",py::arg("enableFast"), py::arg("enableAsynchronous"))

    .def("GetFastSettings", [](Instr &instr)
    {    
      ViBoolean enableFast = 0;
      ViBoolean enableAsynchronous = 0;
      instr.status = rssgt_GetFastSettings(instr.instrumentHandle, &enableFast, &enableAsynchronous);
      instr.checkstatus();
      return std::make_tuple(enableFast,enableAsynchronous);
    },"")

    .def("FastSync", [](Instr &instr)
    {    
      instr.status = rssgt_FastSync(instr.instrumentHandle);
      instr.checkstatus();
    },"")

    .def("ConfigureOperationMode", [](Instr &instr, ViInt32 operationMode)
    {    
      instr.status = rssgt_ConfigureOperationMode(instr.instrumentHandle, operationMode);
      instr.checkstatus();
    },"",py::arg("operationMode"))

    .def("SetFrequencyAndLevel", [](Instr &instr, ViReal64 frequency, ViReal64 level)
    {    
      instr.status = rssgt_SetFrequencyAndLevel(instr.instrumentHandle, frequency, level);
      instr.checkstatus();
    },"",py::arg("frequency"), py::arg("level"))

    .def("PowerServoingSet", [](Instr &instr, ViReal64 targetPow)
    {    
      ViInt32 result = 0;
      instr.status = rssgt_PowerServoingSet(instr.instrumentHandle, targetPow, &result);
      instr.checkstatus();
      return result;
    },"",py::arg("targetPow"))

    .def("SelectActivePath", [](Instr &instr, ViInt32 path)
    {    
      instr.status = rssgt_SelectActivePath(instr.instrumentHandle, path);
      instr.checkstatus();
    },"",py::arg("path"))

    .def("ConfigureARB", [](Instr &instr, ViString waveform, ViReal64 clockFrequency, ViBoolean ARBEnabled)
    {    
      instr.status = rssgt_ConfigureARB(instr.instrumentHandle, waveform, clockFrequency, ARBEnabled);
      instr.checkstatus();
    },"",py::arg("waveform"), py::arg("clockFrequency"), py::arg("ARBEnabled"))

    .def("ConfigureARBOffsets", [](Instr &instr, ViReal64 frequencyOffset, ViReal64 phaseOffset)
    {    
      instr.status = rssgt_ConfigureARBOffsets(instr.instrumentHandle, frequencyOffset, phaseOffset);
      instr.checkstatus();
    },"",py::arg("frequencyOffset"), py::arg("phaseOffset"))

    .def("ARBSetToDefault", [](Instr &instr)
    {    
      instr.status = rssgt_ARBSetToDefault(instr.instrumentHandle);
      instr.checkstatus();
    },"")

    .def("ConfigureARBFileClock", [](Instr &instr, ViString waveformFilename, ViReal64 clock)
    {    
      instr.status = rssgt_ConfigureARBFileClock(instr.instrumentHandle, waveformFilename, clock);
      instr.checkstatus();
    },"",py::arg("waveformFilename"), py::arg("clock"))

    .def("ConfigureARBMultisegmentBlank", [](Instr &instr, ViReal64 sampleCount, ViReal64 clockRate)
    {    
      instr.status = rssgt_ConfigureARBMultisegmentBlank(instr.instrumentHandle, sampleCount, clockRate);
      instr.checkstatus();
    },"",py::arg("sampleCount"), py::arg("clockRate"))

    .def("ConfigureARBMultisegmentLevelClockMarker", [](Instr &instr, ViInt32 level, ViInt32 clock, ViReal64 userClockRate)
    {    
      instr.status = rssgt_ConfigureARBMultisegmentLevelClockMarker(instr.instrumentHandle, level, clock, userClockRate);
      instr.checkstatus();
    },"",py::arg("level"), py::arg("clock"), py::arg("userClockRate"))

    .def("ARBMultisegmentAppendSegmentToPlayList", [](Instr &instr, ViBoolean state, ViInt32 segment, ViInt32 repetition, ViInt32 next)
    {    
      instr.status = rssgt_ARBMultisegmentAppendSegmentToPlayList(instr.instrumentHandle, state, segment, repetition, next);
      instr.checkstatus();
    },"",py::arg("state"), py::arg("segment"), py::arg("repetition"), py::arg("next"))

    .def("ARBMultisegmentFileComment", [](Instr &instr, ViString comment)
    {    
      instr.status = rssgt_ARBMultisegmentFileComment(instr.instrumentHandle, comment);
      instr.checkstatus();
    },"",py::arg("comment"))

    .def("ARBMultisegmentCreate", [](Instr &instr, ViString file)
    {    
      instr.status = rssgt_ARBMultisegmentCreate(instr.instrumentHandle, file);
      instr.checkstatus();
    },"",py::arg("file"))

    .def("ARBMultisegmentLoadFromConfigurationFile", [](Instr &instr, ViString file)
    {    
      instr.status = rssgt_ARBMultisegmentLoadFromConfigurationFile(instr.instrumentHandle, file);
      instr.checkstatus();
    },"",py::arg("file"))

    .def("ARBMultisegmentConfigurationFile", [](Instr &instr, ViString file)
    {    
      instr.status = rssgt_ARBMultisegmentConfigurationFile(instr.instrumentHandle, file);
      instr.checkstatus();
    },"",py::arg("file"))

    .def("ARBMultisegmentConfigurationFileDelete", [](Instr &instr, ViString file)
    {    
      instr.status = rssgt_ARBMultisegmentConfigurationFileDelete(instr.instrumentHandle, file);
      instr.checkstatus();
    },"",py::arg("file"))

    .def("ARBMultisegmentConfigurationFileAppend", [](Instr &instr, ViString file)
    {    
      instr.status = rssgt_ARBMultisegmentConfigurationFileAppend(instr.instrumentHandle, file);
      instr.checkstatus();
    },"",py::arg("file"))

    .def("ARBMultiCarrierSetToDefault", [](Instr &instr)
    {    
      instr.status = rssgt_ARBMultiCarrierSetToDefault(instr.instrumentHandle);
      instr.checkstatus();
    },"")

    .def("ConfigureARBMultiCarrier", [](Instr &instr, ViInt32 mode, ViInt32 numberOfCarriers, ViReal64 carrierSpacing, ViInt32 crestFactorMode, ViInt32 signalPeriodMode, ViReal64 signalPeriod, ViInt32 powerReference)
    {    
      instr.status = rssgt_ConfigureARBMultiCarrier(instr.instrumentHandle, mode, numberOfCarriers, carrierSpacing, crestFactorMode, signalPeriodMode, signalPeriod, powerReference);
      instr.checkstatus();
    },"",py::arg("mode"), py::arg("numberOfCarriers"), py::arg("carrierSpacing"), py::arg("crestFactorMode"), py::arg("signalPeriodMode"), py::arg("signalPeriod"), py::arg("powerReference"))

    .def("ConfigureARBMultiCarrierClipping", [](Instr &instr, ViBoolean clipping, ViReal64 targetCrestFactor, ViReal64 filterCutOffFrequency)
    {    
      instr.status = rssgt_ConfigureARBMultiCarrierClipping(instr.instrumentHandle, clipping, targetCrestFactor, filterCutOffFrequency);
      instr.checkstatus();
    },"",py::arg("clipping"), py::arg("targetCrestFactor"), py::arg("filterCutOffFrequency"))

    .def("ARBMultiCarrierTableNumberOfCarriers", [](Instr &instr, ViInt32 numberOfCarriers)
    {    
      instr.status = rssgt_ARBMultiCarrierTableNumberOfCarriers(instr.instrumentHandle, numberOfCarriers);
      instr.checkstatus();
    },"",py::arg("numberOfCarriers"))

    .def("ARBMultiCarrierTableInputWaveformFile", [](Instr &instr, ViString file)
    {    
      instr.status = rssgt_ARBMultiCarrierTableInputWaveformFile(instr.instrumentHandle, file);
      instr.checkstatus();
    },"",py::arg("file"))

    .def("ARBMultiCarrierTableApply", [](Instr &instr)
    {    
      instr.status = rssgt_ARBMultiCarrierTableApply(instr.instrumentHandle);
      instr.checkstatus();
    },"")

    .def("ConfigureARBMultiCarrierTableCarrier", [](Instr &instr, ViInt32 carrierStart, ViInt32 carrierStop, ViBoolean carrierState)
    {    
      instr.status = rssgt_ConfigureARBMultiCarrierTableCarrier(instr.instrumentHandle, carrierStart, carrierStop, carrierState);
      instr.checkstatus();
    },"",py::arg("carrierStart"), py::arg("carrierStop"), py::arg("carrierState"))

    .def("ConfigureARBMultiCarrierTable", [](Instr &instr, ViReal64 gainStart, ViReal64 gainStep, ViReal64 phaseStart, ViReal64 phaseStep, ViReal64 delayStart, ViReal64 delayStep)
    {    
      instr.status = rssgt_ConfigureARBMultiCarrierTable(instr.instrumentHandle, gainStart, gainStep, phaseStart, phaseStep, delayStart, delayStep);
      instr.checkstatus();
    },"",py::arg("gainStart"), py::arg("gainStep"), py::arg("phaseStart"), py::arg("phaseStep"), py::arg("delayStart"), py::arg("delayStep"))

    .def("ConfigureARBMultiCarr", [](Instr &instr, ViInt32 carrier, ViBoolean state, ViReal64 frequency, ViReal64 gain, ViReal64 phase, ViReal64 delay, ViString file)
    {    
      instr.status = rssgt_ConfigureARBMultiCarr(instr.instrumentHandle, carrier, state, frequency, gain, phase, delay, file);
      instr.checkstatus();
    },"",py::arg("carrier"), py::arg("state"), py::arg("frequency"), py::arg("gain"), py::arg("phase"), py::arg("delay"), py::arg("file"))

    .def("ConfigureARBMultiCarrierStoreFast", [](Instr &instr, ViBoolean storeFast)
    {    
      instr.status = rssgt_ConfigureARBMultiCarrierStoreFast(instr.instrumentHandle, storeFast);
      instr.checkstatus();
    },"",py::arg("storeFast"))

    .def("ARBMultiCarrierFileLoad", [](Instr &instr, ViString file)
    {    
      instr.status = rssgt_ARBMultiCarrierFileLoad(instr.instrumentHandle, file);
      instr.checkstatus();
    },"",py::arg("file"))

    .def("ARBMultiCarrierFileStore", [](Instr &instr, ViString file)
    {    
      instr.status = rssgt_ARBMultiCarrierFileStore(instr.instrumentHandle, file);
      instr.checkstatus();
    },"",py::arg("file"))

    .def("ConfigureARBSineTestSignal", [](Instr &instr, ViReal64 frequency, ViInt32 samples, ViReal64 phaseOffset)
    {    
      instr.status = rssgt_ConfigureARBSineTestSignal(instr.instrumentHandle, frequency, samples, phaseOffset);
      instr.checkstatus();
    },"",py::arg("frequency"), py::arg("samples"), py::arg("phaseOffset"))

    .def("ConfigureARBSineTestSignalName", [](Instr &instr, ViString fileName)
    {    
      instr.status = rssgt_ConfigureARBSineTestSignalName(instr.instrumentHandle, fileName);
      instr.checkstatus();
    },"",py::arg("fileName"))

    .def("ARBSineTestSignalGenerate", [](Instr &instr)
    {    
      instr.status = rssgt_ARBSineTestSignalGenerate(instr.instrumentHandle);
      instr.checkstatus();
    },"")

    .def("ConfigureARBRectTestSignal", [](Instr &instr, ViReal64 frequency, ViInt32 samples, ViReal64 amplitude, ViReal64 offsetDC)
    {    
      instr.status = rssgt_ConfigureARBRectTestSignal(instr.instrumentHandle, frequency, samples, amplitude, offsetDC);
      instr.checkstatus();
    },"",py::arg("frequency"), py::arg("samples"), py::arg("amplitude"), py::arg("offsetDC"))

    .def("ConfigureARBRectTestSignalName", [](Instr &instr, ViString fileName)
    {    
      instr.status = rssgt_ConfigureARBRectTestSignalName(instr.instrumentHandle, fileName);
      instr.checkstatus();
    },"",py::arg("fileName"))

    .def("ARBRectTestSignalGenerate", [](Instr &instr)
    {    
      instr.status = rssgt_ARBRectTestSignalGenerate(instr.instrumentHandle);
      instr.checkstatus();
    },"")

    .def("ConfigureARBCIQTestSignal", [](Instr &instr, ViReal64 iValue, ViReal64 qValue)
    {    
      instr.status = rssgt_ConfigureARBCIQTestSignal(instr.instrumentHandle, iValue, qValue);
      instr.checkstatus();
    },"",py::arg("iValue"), py::arg("qValue"))

    .def("ConfigureARBCIQTestSignalName", [](Instr &instr, ViString fileName)
    {    
      instr.status = rssgt_ConfigureARBCIQTestSignalName(instr.instrumentHandle, fileName);
      instr.checkstatus();
    },"",py::arg("fileName"))

    .def("ARBCIQTestSignalGenerate", [](Instr &instr)
    {    
      instr.status = rssgt_ARBCIQTestSignalGenerate(instr.instrumentHandle);
      instr.checkstatus();
    },"")

    .def("ARBExecuteTrigger", [](Instr &instr)
    {    
      instr.status = rssgt_ARBExecuteTrigger(instr.instrumentHandle);
      instr.checkstatus();
    },"")

    .def("ARBTriggerStatus", [](Instr &instr, std::vector<ViChar>& status, ViInt32 arraySize)
    {    
      instr.status = rssgt_ARBTriggerStatus(instr.instrumentHandle, status.data(), arraySize);
      instr.checkstatus();
    },"",py::arg("status"), py::arg("arraySize"))

    .def("ConfigureARBTriggerMode", [](Instr &instr, ViInt32 mode)
    {    
      instr.status = rssgt_ConfigureARBTriggerMode(instr.instrumentHandle, mode);
      instr.checkstatus();
    },"",py::arg("mode"))

    .def("ConfigureARBTriggerSource", [](Instr &instr, ViInt32 source)
    {    
      instr.status = rssgt_ConfigureARBTriggerSource(instr.instrumentHandle, source);
      instr.checkstatus();
    },"",py::arg("source"))

    .def("ConfigureARBTriggerSingle", [](Instr &instr, ViInt32 signalDurationUnit, ViInt32 signalDuration)
    {    
      instr.status = rssgt_ConfigureARBTriggerSingle(instr.instrumentHandle, signalDurationUnit, signalDuration);
      instr.checkstatus();
    },"",py::arg("signalDurationUnit"), py::arg("signalDuration"))

    .def("ConfigureARBMarkerMode", [](Instr &instr, ViInt32 marker, ViInt32 mode)
    {    
      instr.status = rssgt_ConfigureARBMarkerMode(instr.instrumentHandle, marker, mode);
      instr.checkstatus();
    },"",py::arg("marker"), py::arg("mode"))

    .def("ConfigureARBMarkerDivider", [](Instr &instr, ViInt32 marker, ViInt32 divider)
    {    
      instr.status = rssgt_ConfigureARBMarkerDivider(instr.instrumentHandle, marker, divider);
      instr.checkstatus();
    },"",py::arg("marker"), py::arg("divider"))

    .def("ConfigureARBMarkerDelay", [](Instr &instr, ViInt32 marker, ViInt32 delay, ViBoolean fixMarkerDelay)
    {    
      instr.status = rssgt_ConfigureARBMarkerDelay(instr.instrumentHandle, marker, delay, fixMarkerDelay);
      instr.checkstatus();
    },"",py::arg("marker"), py::arg("delay"), py::arg("fixMarkerDelay"))

    .def("ConfigureARBClockSource", [](Instr &instr, ViInt32 source)
    {    
      instr.status = rssgt_ConfigureARBClockSource(instr.instrumentHandle, source);
      instr.checkstatus();
    },"",py::arg("source"))

    .def("ConfigureAWGNEnabled", [](Instr &instr, ViBoolean AWGNEnabled)
    {    
      instr.status = rssgt_ConfigureAWGNEnabled(instr.instrumentHandle, AWGNEnabled);
      instr.checkstatus();
    },"",py::arg("AWGNEnabled"))

    .def("ConfigureAWGNMode", [](Instr &instr, ViInt32 mode)
    {    
      instr.status = rssgt_ConfigureAWGNMode(instr.instrumentHandle, mode);
      instr.checkstatus();
    },"",py::arg("mode"))

    .def("ConfigureAWGNNoiseOnly", [](Instr &instr, ViReal64 systemBandwidth, ViReal64 bandwidthRatio)
    {    
      instr.status = rssgt_ConfigureAWGNNoiseOnly(instr.instrumentHandle, systemBandwidth, bandwidthRatio);
      instr.checkstatus();
    },"",py::arg("systemBandwidth"), py::arg("bandwidthRatio"))

    .def("ConfigureAWGNAdditiveNoiseDisplayMode", [](Instr &instr, ViInt32 displayMode)
    {    
      instr.status = rssgt_ConfigureAWGNAdditiveNoiseDisplayMode(instr.instrumentHandle, displayMode);
      instr.checkstatus();
    },"",py::arg("displayMode"))

    .def("ConfigureFrequencyPhase", [](Instr &instr, ViReal64 frequency, ViReal64 deltaPhase)
    {    
      instr.status = rssgt_ConfigureFrequencyPhase(instr.instrumentHandle, frequency, deltaPhase);
      instr.checkstatus();
    },"",py::arg("frequency"), py::arg("deltaPhase"))

    .def("ResetDeltaPhaseDisplay", [](Instr &instr)
    {    
      instr.status = rssgt_ResetDeltaPhaseDisplay(instr.instrumentHandle);
      instr.checkstatus();
    },"")

    .def("ConfigureLocalOscillatorSource", [](Instr &instr, ViInt32 source)
    {    
      instr.status = rssgt_ConfigureLocalOscillatorSource(instr.instrumentHandle, source);
      instr.checkstatus();
    },"",py::arg("source"))

    .def("ConfigureReferenceOscillatorSource", [](Instr &instr, ViInt32 source)
    {    
      instr.status = rssgt_ConfigureReferenceOscillatorSource(instr.instrumentHandle, source);
      instr.checkstatus();
    },"",py::arg("source"))

    .def("ConfigureReferenceOscillatorExternal", [](Instr &instr, ViInt32 referenceInputFrequency, ViInt32 synchronisationBandwidth)
    {    
      instr.status = rssgt_ConfigureReferenceOscillatorExternal(instr.instrumentHandle, referenceInputFrequency, synchronisationBandwidth);
      instr.checkstatus();
    },"",py::arg("referenceInputFrequency"), py::arg("synchronisationBandwidth"))

    .def("ConfigureReferenceOscillatorAdjustment", [](Instr &instr, ViBoolean active, ViInt32 smallShift)
    {    
      instr.status = rssgt_ConfigureReferenceOscillatorAdjustment(instr.instrumentHandle, active, smallShift);
      instr.checkstatus();
    },"",py::arg("active"), py::arg("smallShift"))

    .def("ConfigureLevelState", [](Instr &instr, ViBoolean state)
    {    
      instr.status = rssgt_ConfigureLevelState(instr.instrumentHandle, state);
      instr.checkstatus();
    },"",py::arg("state"))

    .def("ConfigureLevelSettings", [](Instr &instr, ViInt32 mode, ViInt32 settingCharacteristic, ViReal64 level, ViReal64 limit)
    {    
      instr.status = rssgt_ConfigureLevelSettings(instr.instrumentHandle, mode, settingCharacteristic, level, limit);
      instr.checkstatus();
    },"",py::arg("mode"), py::arg("settingCharacteristic"), py::arg("level"), py::arg("limit"))

    .def("QueryLevelRange", [](Instr &instr)
    {    
      ViReal64 minimum = 0;
      ViReal64 maximum = 0;
      instr.status = rssgt_QueryLevelRange(instr.instrumentHandle, &minimum, &maximum);
      instr.checkstatus();
      return std::make_tuple(minimum,maximum);
    },"")

    .def("ConfigureLevelPowerOn", [](Instr &instr, ViInt32 state)
    {    
      instr.status = rssgt_ConfigureLevelPowerOn(instr.instrumentHandle, state);
      instr.checkstatus();
    },"",py::arg("state"))

    .def("ConfigureLevelALC", [](Instr &instr, ViInt32 state, ViInt32 detectorSensitivity)
    {    
      instr.status = rssgt_ConfigureLevelALC(instr.instrumentHandle, state, detectorSensitivity);
      instr.checkstatus();
    },"",py::arg("state"), py::arg("detectorSensitivity"))

    .def("QueryLevelAttenuatorRange", [](Instr &instr)
    {    
      ViReal64 minimum = 0;
      ViReal64 maximum = 0;
      instr.status = rssgt_QueryLevelAttenuatorRange(instr.instrumentHandle, &minimum, &maximum);
      instr.checkstatus();
      return std::make_tuple(minimum,maximum);
    },"")

    .def("ConfigureLevelAttenuatorSettings", [](Instr &instr, ViInt32 mode, ViReal64 SATT, ViInt32 RFOffMode)
    {    
      instr.status = rssgt_ConfigureLevelAttenuatorSettings(instr.instrumentHandle, mode, SATT, RFOffMode);
      instr.checkstatus();
    },"",py::arg("mode"), py::arg("SATT"), py::arg("RFOffMode"))

    .def("ConfigureIQEnabled", [](Instr &instr, ViBoolean enabled)
    {    
      instr.status = rssgt_ConfigureIQEnabled(instr.instrumentHandle, enabled);
      instr.checkstatus();
    },"",py::arg("enabled"))

    .def("ConfigureIQImpairments", [](Instr &instr, ViBoolean enabled, ViReal64 iOffset, ViReal64 qOffset, ViReal64 gainImbalance, ViReal64 quadratureOffset)
    {    
      instr.status = rssgt_ConfigureIQImpairments(instr.instrumentHandle, enabled, iOffset, qOffset, gainImbalance, quadratureOffset);
      instr.checkstatus();
    },"",py::arg("enabled"), py::arg("iOffset"), py::arg("qOffset"), py::arg("gainImbalance"), py::arg("quadratureOffset"))

    .def("ConfigurePULMEnabled", [](Instr &instr, ViBoolean enabled)
    {    
      instr.status = rssgt_ConfigurePULMEnabled(instr.instrumentHandle, enabled);
      instr.checkstatus();
    },"",py::arg("enabled"))

    .def("ConfigurePULMSource", [](Instr &instr, ViInt32 source)
    {    
      instr.status = rssgt_ConfigurePULMSource(instr.instrumentHandle, source);
      instr.checkstatus();
    },"",py::arg("source"))

    .def("ConfigurePULM", [](Instr &instr, ViInt32 pulseMode, ViReal64 pulsePeriod, ViReal64 pulseWidth, ViReal64 doublePulseWidth, ViReal64 doublePulseDelay)
    {    
      instr.status = rssgt_ConfigurePULM(instr.instrumentHandle, pulseMode, pulsePeriod, pulseWidth, doublePulseWidth, doublePulseDelay);
      instr.checkstatus();
    },"",py::arg("pulseMode"), py::arg("pulsePeriod"), py::arg("pulseWidth"), py::arg("doublePulseWidth"), py::arg("doublePulseDelay"))

    .def("ConfigurePowerMeasurementDisplay", [](Instr &instr, ViInt32 sensor, ViBoolean permanent, ViInt32 priority)
    {    
      instr.status = rssgt_ConfigurePowerMeasurementDisplay(instr.instrumentHandle, sensor, permanent, priority);
      instr.checkstatus();
    },"",py::arg("sensor"), py::arg("permanent"), py::arg("priority"))

    .def("ConfigurePowerMeasurementZero", [](Instr &instr, ViInt32 sensor)
    {    
      instr.status = rssgt_ConfigurePowerMeasurementZero(instr.instrumentHandle, sensor);
      instr.checkstatus();
    },"",py::arg("sensor"))

    .def("ConfigurePowerMeasurementSource", [](Instr &instr, ViInt32 sensor, ViInt32 source)
    {    
      instr.status = rssgt_ConfigurePowerMeasurementSource(instr.instrumentHandle, sensor, source);
      instr.checkstatus();
    },"",py::arg("sensor"), py::arg("source"))

    .def("ConfigurePowerMeasurement", [](Instr &instr, ViInt32 sensor, ViBoolean levelOffsetState, ViReal64 levelOffset, ViInt32 filter, ViBoolean SParameter, ViBoolean logging)
    {    
      instr.status = rssgt_ConfigurePowerMeasurement(instr.instrumentHandle, sensor, levelOffsetState, levelOffset, filter, SParameter, logging);
      instr.checkstatus();
    },"",py::arg("sensor"), py::arg("levelOffsetState"), py::arg("levelOffset"), py::arg("filter"), py::arg("SParameter"), py::arg("logging"))

    .def("ConfigurePowerMeasurementApertureTime", [](Instr &instr, ViInt32 sensor, ViBoolean defaultTime, ViReal64 apertureTime)
    {    
      instr.status = rssgt_ConfigurePowerMeasurementApertureTime(instr.instrumentHandle, sensor, defaultTime, apertureTime);
      instr.checkstatus();
    },"",py::arg("sensor"), py::arg("defaultTime"), py::arg("apertureTime"))

    .def("ReadPowerMeasurement", [](Instr &instr, ViInt32 sensor)
    {    
      ViReal64 level_Peak = 0;
      ViReal64 level_Average = 0;
      instr.status = rssgt_ReadPowerMeasurement(instr.instrumentHandle, sensor, &level_Peak, &level_Average);
      instr.checkstatus();
      return std::make_tuple(level_Peak,level_Average);
    },"",py::arg("sensor"))

    .def("SendSoftwareTrigger", [](Instr &instr)
    {    
      instr.status = rssgt_SendSoftwareTrigger(instr.instrumentHandle);
      instr.checkstatus();
    },"")

    .def("Lock", [](Instr &instr, ViInt32 requestID)
    {    
      ViInt32 requestResult = 0;
      instr.status = rssgt_Lock(instr.instrumentHandle, requestID, &requestResult);
      instr.checkstatus();
      return requestResult;
    },"",py::arg("requestID"))

    .def("SystemProtect", [](Instr &instr, ViInt32 level, ViBoolean enabled, ViInt32 key)
    {    
      instr.status = rssgt_SystemProtect(instr.instrumentHandle, level, enabled, key);
      instr.checkstatus();
    },"",py::arg("level"), py::arg("enabled"), py::arg("key"))

    .def("GetMemoryInformation", [](Instr &instr)
    {    
      ViInt32 totalPhysicalMemory = 0;
      ViInt32 applicationMemory = 0;
      ViInt32 usedHeapMemory = 0;
      ViInt32 availableHeapMemory = 0;
      instr.status = rssgt_GetMemoryInformation(instr.instrumentHandle, &totalPhysicalMemory, &applicationMemory, &usedHeapMemory, &availableHeapMemory);
      instr.checkstatus();
      return std::make_tuple(totalPhysicalMemory,applicationMemory,usedHeapMemory,availableHeapMemory);
    },"")

    .def("MMEMoryCatalogLength", [](Instr &instr, ViString directoryPath)
    {    
      ViInt32 catalogLength = 0;
      instr.status = rssgt_MMEMoryCatalogLength(instr.instrumentHandle, directoryPath, &catalogLength);
      instr.checkstatus();
      return catalogLength;
    },"",py::arg("directoryPath"))

    .def("MMEMoryChangeDirectory", [](Instr &instr, ViString directoryName)
    {    
      instr.status = rssgt_MMEMoryChangeDirectory(instr.instrumentHandle, directoryName);
      instr.checkstatus();
    },"",py::arg("directoryName"))

    .def("MMEMoryCopy", [](Instr &instr, ViString sourcePath, ViString destinationPath)
    {    
      instr.status = rssgt_MMEMoryCopy(instr.instrumentHandle, sourcePath, destinationPath);
      instr.checkstatus();
    },"",py::arg("sourcePath"), py::arg("destinationPath"))

    .def("MMEMoryReadToFileFromInstrument", [](Instr &instr, ViString source, ViString destination)
    {    
      instr.status = rssgt_MMEMoryReadToFileFromInstrument(instr.instrumentHandle, source, destination);
      instr.checkstatus();
    },"",py::arg("source"), py::arg("destination"))

    .def("MMEMoryWriteFromFileToInstrument", [](Instr &instr, ViString source, ViString destination)
    {    
      instr.status = rssgt_MMEMoryWriteFromFileToInstrument(instr.instrumentHandle, source, destination);
      instr.checkstatus();
    },"",py::arg("source"), py::arg("destination"))

    .def("MMEMoryDirectoryCatalogLength", [](Instr &instr, ViString directoryPath)
    {    
      ViInt32 catalogLength = 0;
      instr.status = rssgt_MMEMoryDirectoryCatalogLength(instr.instrumentHandle, directoryPath, &catalogLength);
      instr.checkstatus();
      return catalogLength;
    },"",py::arg("directoryPath"))

    .def("MMEMoryDelete", [](Instr &instr, ViString fileName)
    {    
      instr.status = rssgt_MMEMoryDelete(instr.instrumentHandle, fileName);
      instr.checkstatus();
    },"",py::arg("fileName"))

    .def("MMEMoryLoad", [](Instr &instr, ViInt32 instrumentSetting, ViString fileName)
    {    
      instr.status = rssgt_MMEMoryLoad(instr.instrumentHandle, instrumentSetting, fileName);
      instr.checkstatus();
    },"",py::arg("instrumentSetting"), py::arg("fileName"))

    .def("MMEMoryMakeDirectory", [](Instr &instr, ViString directoryName)
    {    
      instr.status = rssgt_MMEMoryMakeDirectory(instr.instrumentHandle, directoryName);
      instr.checkstatus();
    },"",py::arg("directoryName"))

    .def("MMEMoryMove", [](Instr &instr, ViString fileSource, ViString fileDestination)
    {    
      instr.status = rssgt_MMEMoryMove(instr.instrumentHandle, fileSource, fileDestination);
      instr.checkstatus();
    },"",py::arg("fileSource"), py::arg("fileDestination"))

    .def("MMEMoryRemoveDirectory", [](Instr &instr, ViString directoryName)
    {    
      instr.status = rssgt_MMEMoryRemoveDirectory(instr.instrumentHandle, directoryName);
      instr.checkstatus();
    },"",py::arg("directoryName"))

    .def("MMEMoryStore", [](Instr &instr, ViInt32 instrumentSetting, ViString fileName)
    {    
      instr.status = rssgt_MMEMoryStore(instr.instrumentHandle, instrumentSetting, fileName);
      instr.checkstatus();
    },"",py::arg("instrumentSetting"), py::arg("fileName"))

    .def("DiagnosticTestPointVoltages", [](Instr &instr, ViString testPointName)
    {    
      ViReal64 measuredVoltage = 0;
      instr.status = rssgt_DiagnosticTestPointVoltages(instr.instrumentHandle, testPointName, &measuredVoltage);
      instr.checkstatus();
      return measuredVoltage;
    },"",py::arg("testPointName"))

    .def("SetRegister", [](Instr &instr, ViInt32 registerGroup, ViInt32 registerType, ViInt32 value)
    {    
      instr.status = rssgt_SetRegister(instr.instrumentHandle, registerGroup, registerType, value);
      instr.checkstatus();
    },"",py::arg("registerGroup"), py::arg("registerType"), py::arg("value"))

    .def("GetRegister", [](Instr &instr, ViInt32 registerGroup, ViInt32 registerType)
    {    
      ViInt32 value = 0;
      instr.status = rssgt_GetRegister(instr.instrumentHandle, registerGroup, registerType, &value);
      instr.checkstatus();
      return value;
    },"",py::arg("registerGroup"), py::arg("registerType"))

    .def("STATusPRESet", [](Instr &instr)
    {    
      instr.status = rssgt_STATusPRESet(instr.instrumentHandle);
      instr.checkstatus();
    },"")

    .def("SetDate", [](Instr &instr, ViInt32 year, ViInt32 month, ViInt32 day)
    {    
      instr.status = rssgt_SetDate(instr.instrumentHandle, year, month, day);
      instr.checkstatus();
    },"",py::arg("year"), py::arg("month"), py::arg("day"))

    .def("GetDate", [](Instr &instr)
    {    
      ViInt32 year = 0;
      ViInt32 month = 0;
      ViInt32 day = 0;
      instr.status = rssgt_GetDate(instr.instrumentHandle, &year, &month, &day);
      instr.checkstatus();
      return std::make_tuple(year,month,day);
    },"")

    .def("SetTime", [](Instr &instr, ViInt32 hour, ViInt32 minute, ViInt32 second)
    {    
      instr.status = rssgt_SetTime(instr.instrumentHandle, hour, minute, second);
      instr.checkstatus();
    },"",py::arg("hour"), py::arg("minute"), py::arg("second"))

    .def("GetTime", [](Instr &instr)
    {    
      ViInt32 hour = 0;
      ViInt32 minute = 0;
      ViInt32 second = 0;
      instr.status = rssgt_GetTime(instr.instrumentHandle, &hour, &minute, &second);
      instr.checkstatus();
      return std::make_tuple(hour,minute,second);
    },"")

    .def("reset", [](Instr &instr)
    {    
      instr.status = rssgt_reset(instr.instrumentHandle);
      instr.checkstatus();
    },"")

    .def("ClearStatus", [](Instr &instr)
    {    
      instr.status = rssgt_ClearStatus(instr.instrumentHandle);
      instr.checkstatus();
    },"")

    .def("ProcessAllPreviousCommands", [](Instr &instr)
    {    
      instr.status = rssgt_ProcessAllPreviousCommands(instr.instrumentHandle);
      instr.checkstatus();
    },"")

    .def("QueryOPC", [](Instr &instr)
    {    
      ViInt32 OPC = 0;
      instr.status = rssgt_QueryOPC(instr.instrumentHandle, &OPC);
      instr.checkstatus();
      return OPC;
    },"")

    .def("ClearError", [](Instr &instr)
    {    
      instr.status = rssgt_ClearError(instr.instrumentHandle);
      instr.checkstatus();
    },"")

    .def("WriteInstrData", [](Instr &instr, ViString writeBuffer)
    {    
      instr.status = rssgt_WriteInstrData(instr.instrumentHandle, writeBuffer);
      instr.checkstatus();
    },"",py::arg("writeBuffer"))


    .def("SetAttributeFlags", [](Instr &instr, ViAttr attributeID, ViInt32 flags)
    {    
      instr.status = rssgt_SetAttributeFlags(instr.instrumentHandle, attributeID, flags);
      instr.checkstatus();
    },"",py::arg("attributeID"), py::arg("flags"))

    .def("GetAttributeFlags", [](Instr &instr, ViAttr attributeID)
    {    
      ViInt32 flags = 0;
      instr.status = rssgt_GetAttributeFlags(instr.instrumentHandle, attributeID, &flags);
      instr.checkstatus();
      return flags;
    },"",py::arg("attributeID"))

    .def("CheckAttributeViInt32", [](Instr &instr, ViString repeatedCapabilityName, ViAttr attributeID, ViInt32 attributeValue)
    {    
      instr.status = rssgt_CheckAttributeViInt32(instr.instrumentHandle, repeatedCapabilityName, attributeID, attributeValue);
      instr.checkstatus();
    },"",py::arg("repeatedCapabilityName"), py::arg("attributeID"), py::arg("attributeValue"))

    .def("CheckAttributeViReal64", [](Instr &instr, ViString repeatedCapabilityName, ViAttr attributeID, ViReal64 attributeValue)
    {    
      instr.status = rssgt_CheckAttributeViReal64(instr.instrumentHandle, repeatedCapabilityName, attributeID, attributeValue);
      instr.checkstatus();
    },"",py::arg("repeatedCapabilityName"), py::arg("attributeID"), py::arg("attributeValue"))

    .def("CheckAttributeViString", [](Instr &instr, ViString repeatedCapabilityName, ViAttr attributeID, ViString attributeValue)
    {    
      instr.status = rssgt_CheckAttributeViString(instr.instrumentHandle, repeatedCapabilityName, attributeID, attributeValue);
      instr.checkstatus();
    },"",py::arg("repeatedCapabilityName"), py::arg("attributeID"), py::arg("attributeValue"))

    .def("CheckAttributeViBoolean", [](Instr &instr, ViString repeatedCapabilityName, ViAttr attributeID, ViBoolean attributeValue)
    {    
      instr.status = rssgt_CheckAttributeViBoolean(instr.instrumentHandle, repeatedCapabilityName, attributeID, attributeValue);
      instr.checkstatus();
    },"",py::arg("repeatedCapabilityName"), py::arg("attributeID"), py::arg("attributeValue"))

    .def("CheckAttributeViSession", [](Instr &instr, ViString repeatedCapabilityName, ViAttr attributeID, ViSession attributeValue)
    {    
      instr.status = rssgt_CheckAttributeViSession(instr.instrumentHandle, repeatedCapabilityName, attributeID, attributeValue);
      instr.checkstatus();
    },"",py::arg("repeatedCapabilityName"), py::arg("attributeID"), py::arg("attributeValue"))

    .def("close", [](Instr &instr)
    {    
      instr.status = rssgt_close(instr.instrumentHandle);
      instr.checkstatus();
    },"")

// GeneratedMethodsEnd

;

}


